function rc(e) {
  return e && e.__esModule && Object.prototype.hasOwnProperty.call(e, "default") ? e.default : e;
}
var Wu = { exports: {} }, T = {};
/**
 * @license React
 * react.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var Gn = Symbol.for("react.element"), lc = Symbol.for("react.portal"), oc = Symbol.for("react.fragment"), ic = Symbol.for("react.strict_mode"), uc = Symbol.for("react.profiler"), sc = Symbol.for("react.provider"), ac = Symbol.for("react.context"), cc = Symbol.for("react.forward_ref"), fc = Symbol.for("react.suspense"), dc = Symbol.for("react.memo"), pc = Symbol.for("react.lazy"), Di = Symbol.iterator;
function mc(e) {
  return e === null || typeof e != "object" ? null : (e = Di && e[Di] || e["@@iterator"], typeof e == "function" ? e : null);
}
var Hu = { isMounted: function() {
  return !1;
}, enqueueForceUpdate: function() {
}, enqueueReplaceState: function() {
}, enqueueSetState: function() {
} }, Qu = Object.assign, Ku = {};
function on(e, t, n) {
  this.props = e, this.context = t, this.refs = Ku, this.updater = n || Hu;
}
on.prototype.isReactComponent = {};
on.prototype.setState = function(e, t) {
  if (typeof e != "object" && typeof e != "function" && e != null) throw Error("setState(...): takes an object of state variables to update or a function which returns an object of state variables.");
  this.updater.enqueueSetState(this, e, t, "setState");
};
on.prototype.forceUpdate = function(e) {
  this.updater.enqueueForceUpdate(this, e, "forceUpdate");
};
function Yu() {
}
Yu.prototype = on.prototype;
function Uo(e, t, n) {
  this.props = e, this.context = t, this.refs = Ku, this.updater = n || Hu;
}
var $o = Uo.prototype = new Yu();
$o.constructor = Uo;
Qu($o, on.prototype);
$o.isPureReactComponent = !0;
var Oi = Array.isArray, Xu = Object.prototype.hasOwnProperty, Vo = { current: null }, Gu = { key: !0, ref: !0, __self: !0, __source: !0 };
function Zu(e, t, n) {
  var r, l = {}, o = null, i = null;
  if (t != null) for (r in t.ref !== void 0 && (i = t.ref), t.key !== void 0 && (o = "" + t.key), t) Xu.call(t, r) && !Gu.hasOwnProperty(r) && (l[r] = t[r]);
  var u = arguments.length - 2;
  if (u === 1) l.children = n;
  else if (1 < u) {
    for (var s = Array(u), f = 0; f < u; f++) s[f] = arguments[f + 2];
    l.children = s;
  }
  if (e && e.defaultProps) for (r in u = e.defaultProps, u) l[r] === void 0 && (l[r] = u[r]);
  return { $$typeof: Gn, type: e, key: o, ref: i, props: l, _owner: Vo.current };
}
function vc(e, t) {
  return { $$typeof: Gn, type: e.type, key: t, ref: e.ref, props: e.props, _owner: e._owner };
}
function Ao(e) {
  return typeof e == "object" && e !== null && e.$$typeof === Gn;
}
function hc(e) {
  var t = { "=": "=0", ":": "=2" };
  return "$" + e.replace(/[=:]/g, function(n) {
    return t[n];
  });
}
var ji = /\/+/g;
function wl(e, t) {
  return typeof e == "object" && e !== null && e.key != null ? hc("" + e.key) : t.toString(36);
}
function wr(e, t, n, r, l) {
  var o = typeof e;
  (o === "undefined" || o === "boolean") && (e = null);
  var i = !1;
  if (e === null) i = !0;
  else switch (o) {
    case "string":
    case "number":
      i = !0;
      break;
    case "object":
      switch (e.$$typeof) {
        case Gn:
        case lc:
          i = !0;
      }
  }
  if (i) return i = e, l = l(i), e = r === "" ? "." + wl(i, 0) : r, Oi(l) ? (n = "", e != null && (n = e.replace(ji, "$&/") + "/"), wr(l, t, n, "", function(f) {
    return f;
  })) : l != null && (Ao(l) && (l = vc(l, n + (!l.key || i && i.key === l.key ? "" : ("" + l.key).replace(ji, "$&/") + "/") + e)), t.push(l)), 1;
  if (i = 0, r = r === "" ? "." : r + ":", Oi(e)) for (var u = 0; u < e.length; u++) {
    o = e[u];
    var s = r + wl(o, u);
    i += wr(o, t, n, s, l);
  }
  else if (s = mc(e), typeof s == "function") for (e = s.call(e), u = 0; !(o = e.next()).done; ) o = o.value, s = r + wl(o, u++), i += wr(o, t, n, s, l);
  else if (o === "object") throw t = String(e), Error("Objects are not valid as a React child (found: " + (t === "[object Object]" ? "object with keys {" + Object.keys(e).join(", ") + "}" : t) + "). If you meant to render a collection of children, use an array instead.");
  return i;
}
function nr(e, t, n) {
  if (e == null) return e;
  var r = [], l = 0;
  return wr(e, r, "", "", function(o) {
    return t.call(n, o, l++);
  }), r;
}
function yc(e) {
  if (e._status === -1) {
    var t = e._result;
    t = t(), t.then(function(n) {
      (e._status === 0 || e._status === -1) && (e._status = 1, e._result = n);
    }, function(n) {
      (e._status === 0 || e._status === -1) && (e._status = 2, e._result = n);
    }), e._status === -1 && (e._status = 0, e._result = t);
  }
  if (e._status === 1) return e._result.default;
  throw e._result;
}
var se = { current: null }, Sr = { transition: null }, gc = { ReactCurrentDispatcher: se, ReactCurrentBatchConfig: Sr, ReactCurrentOwner: Vo };
function Ju() {
  throw Error("act(...) is not supported in production builds of React.");
}
T.Children = { map: nr, forEach: function(e, t, n) {
  nr(e, function() {
    t.apply(this, arguments);
  }, n);
}, count: function(e) {
  var t = 0;
  return nr(e, function() {
    t++;
  }), t;
}, toArray: function(e) {
  return nr(e, function(t) {
    return t;
  }) || [];
}, only: function(e) {
  if (!Ao(e)) throw Error("React.Children.only expected to receive a single React element child.");
  return e;
} };
T.Component = on;
T.Fragment = oc;
T.Profiler = uc;
T.PureComponent = Uo;
T.StrictMode = ic;
T.Suspense = fc;
T.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED = gc;
T.act = Ju;
T.cloneElement = function(e, t, n) {
  if (e == null) throw Error("React.cloneElement(...): The argument must be a React element, but you passed " + e + ".");
  var r = Qu({}, e.props), l = e.key, o = e.ref, i = e._owner;
  if (t != null) {
    if (t.ref !== void 0 && (o = t.ref, i = Vo.current), t.key !== void 0 && (l = "" + t.key), e.type && e.type.defaultProps) var u = e.type.defaultProps;
    for (s in t) Xu.call(t, s) && !Gu.hasOwnProperty(s) && (r[s] = t[s] === void 0 && u !== void 0 ? u[s] : t[s]);
  }
  var s = arguments.length - 2;
  if (s === 1) r.children = n;
  else if (1 < s) {
    u = Array(s);
    for (var f = 0; f < s; f++) u[f] = arguments[f + 2];
    r.children = u;
  }
  return { $$typeof: Gn, type: e.type, key: l, ref: o, props: r, _owner: i };
};
T.createContext = function(e) {
  return e = { $$typeof: ac, _currentValue: e, _currentValue2: e, _threadCount: 0, Provider: null, Consumer: null, _defaultValue: null, _globalName: null }, e.Provider = { $$typeof: sc, _context: e }, e.Consumer = e;
};
T.createElement = Zu;
T.createFactory = function(e) {
  var t = Zu.bind(null, e);
  return t.type = e, t;
};
T.createRef = function() {
  return { current: null };
};
T.forwardRef = function(e) {
  return { $$typeof: cc, render: e };
};
T.isValidElement = Ao;
T.lazy = function(e) {
  return { $$typeof: pc, _payload: { _status: -1, _result: e }, _init: yc };
};
T.memo = function(e, t) {
  return { $$typeof: dc, type: e, compare: t === void 0 ? null : t };
};
T.startTransition = function(e) {
  var t = Sr.transition;
  Sr.transition = {};
  try {
    e();
  } finally {
    Sr.transition = t;
  }
};
T.unstable_act = Ju;
T.useCallback = function(e, t) {
  return se.current.useCallback(e, t);
};
T.useContext = function(e) {
  return se.current.useContext(e);
};
T.useDebugValue = function() {
};
T.useDeferredValue = function(e) {
  return se.current.useDeferredValue(e);
};
T.useEffect = function(e, t) {
  return se.current.useEffect(e, t);
};
T.useId = function() {
  return se.current.useId();
};
T.useImperativeHandle = function(e, t, n) {
  return se.current.useImperativeHandle(e, t, n);
};
T.useInsertionEffect = function(e, t) {
  return se.current.useInsertionEffect(e, t);
};
T.useLayoutEffect = function(e, t) {
  return se.current.useLayoutEffect(e, t);
};
T.useMemo = function(e, t) {
  return se.current.useMemo(e, t);
};
T.useReducer = function(e, t, n) {
  return se.current.useReducer(e, t, n);
};
T.useRef = function(e) {
  return se.current.useRef(e);
};
T.useState = function(e) {
  return se.current.useState(e);
};
T.useSyncExternalStore = function(e, t, n) {
  return se.current.useSyncExternalStore(e, t, n);
};
T.useTransition = function() {
  return se.current.useTransition();
};
T.version = "18.3.1";
Wu.exports = T;
var J = Wu.exports;
const k = /* @__PURE__ */ rc(J);
var qu = { exports: {} }, we = {}, bu = { exports: {} }, es = {};
/**
 * @license React
 * scheduler.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
(function(e) {
  function t(C, z) {
    var L = C.length;
    C.push(z);
    e: for (; 0 < L; ) {
      var H = L - 1 >>> 1, G = C[H];
      if (0 < l(G, z)) C[H] = z, C[L] = G, L = H;
      else break e;
    }
  }
  function n(C) {
    return C.length === 0 ? null : C[0];
  }
  function r(C) {
    if (C.length === 0) return null;
    var z = C[0], L = C.pop();
    if (L !== z) {
      C[0] = L;
      e: for (var H = 0, G = C.length, er = G >>> 1; H < er; ) {
        var ht = 2 * (H + 1) - 1, gl = C[ht], yt = ht + 1, tr = C[yt];
        if (0 > l(gl, L)) yt < G && 0 > l(tr, gl) ? (C[H] = tr, C[yt] = L, H = yt) : (C[H] = gl, C[ht] = L, H = ht);
        else if (yt < G && 0 > l(tr, L)) C[H] = tr, C[yt] = L, H = yt;
        else break e;
      }
    }
    return z;
  }
  function l(C, z) {
    var L = C.sortIndex - z.sortIndex;
    return L !== 0 ? L : C.id - z.id;
  }
  if (typeof performance == "object" && typeof performance.now == "function") {
    var o = performance;
    e.unstable_now = function() {
      return o.now();
    };
  } else {
    var i = Date, u = i.now();
    e.unstable_now = function() {
      return i.now() - u;
    };
  }
  var s = [], f = [], v = 1, m = null, p = 3, w = !1, S = !1, g = !1, D = typeof setTimeout == "function" ? setTimeout : null, c = typeof clearTimeout == "function" ? clearTimeout : null, a = typeof setImmediate < "u" ? setImmediate : null;
  typeof navigator < "u" && navigator.scheduling !== void 0 && navigator.scheduling.isInputPending !== void 0 && navigator.scheduling.isInputPending.bind(navigator.scheduling);
  function d(C) {
    for (var z = n(f); z !== null; ) {
      if (z.callback === null) r(f);
      else if (z.startTime <= C) r(f), z.sortIndex = z.expirationTime, t(s, z);
      else break;
      z = n(f);
    }
  }
  function h(C) {
    if (g = !1, d(C), !S) if (n(s) !== null) S = !0, hl(E);
    else {
      var z = n(f);
      z !== null && yl(h, z.startTime - C);
    }
  }
  function E(C, z) {
    S = !1, g && (g = !1, c(P), P = -1), w = !0;
    var L = p;
    try {
      for (d(z), m = n(s); m !== null && (!(m.expirationTime > z) || C && !Pe()); ) {
        var H = m.callback;
        if (typeof H == "function") {
          m.callback = null, p = m.priorityLevel;
          var G = H(m.expirationTime <= z);
          z = e.unstable_now(), typeof G == "function" ? m.callback = G : m === n(s) && r(s), d(z);
        } else r(s);
        m = n(s);
      }
      if (m !== null) var er = !0;
      else {
        var ht = n(f);
        ht !== null && yl(h, ht.startTime - z), er = !1;
      }
      return er;
    } finally {
      m = null, p = L, w = !1;
    }
  }
  var N = !1, _ = null, P = -1, W = 5, M = -1;
  function Pe() {
    return !(e.unstable_now() - M < W);
  }
  function an() {
    if (_ !== null) {
      var C = e.unstable_now();
      M = C;
      var z = !0;
      try {
        z = _(!0, C);
      } finally {
        z ? cn() : (N = !1, _ = null);
      }
    } else N = !1;
  }
  var cn;
  if (typeof a == "function") cn = function() {
    a(an);
  };
  else if (typeof MessageChannel < "u") {
    var Ri = new MessageChannel(), nc = Ri.port2;
    Ri.port1.onmessage = an, cn = function() {
      nc.postMessage(null);
    };
  } else cn = function() {
    D(an, 0);
  };
  function hl(C) {
    _ = C, N || (N = !0, cn());
  }
  function yl(C, z) {
    P = D(function() {
      C(e.unstable_now());
    }, z);
  }
  e.unstable_IdlePriority = 5, e.unstable_ImmediatePriority = 1, e.unstable_LowPriority = 4, e.unstable_NormalPriority = 3, e.unstable_Profiling = null, e.unstable_UserBlockingPriority = 2, e.unstable_cancelCallback = function(C) {
    C.callback = null;
  }, e.unstable_continueExecution = function() {
    S || w || (S = !0, hl(E));
  }, e.unstable_forceFrameRate = function(C) {
    0 > C || 125 < C ? console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported") : W = 0 < C ? Math.floor(1e3 / C) : 5;
  }, e.unstable_getCurrentPriorityLevel = function() {
    return p;
  }, e.unstable_getFirstCallbackNode = function() {
    return n(s);
  }, e.unstable_next = function(C) {
    switch (p) {
      case 1:
      case 2:
      case 3:
        var z = 3;
        break;
      default:
        z = p;
    }
    var L = p;
    p = z;
    try {
      return C();
    } finally {
      p = L;
    }
  }, e.unstable_pauseExecution = function() {
  }, e.unstable_requestPaint = function() {
  }, e.unstable_runWithPriority = function(C, z) {
    switch (C) {
      case 1:
      case 2:
      case 3:
      case 4:
      case 5:
        break;
      default:
        C = 3;
    }
    var L = p;
    p = C;
    try {
      return z();
    } finally {
      p = L;
    }
  }, e.unstable_scheduleCallback = function(C, z, L) {
    var H = e.unstable_now();
    switch (typeof L == "object" && L !== null ? (L = L.delay, L = typeof L == "number" && 0 < L ? H + L : H) : L = H, C) {
      case 1:
        var G = -1;
        break;
      case 2:
        G = 250;
        break;
      case 5:
        G = 1073741823;
        break;
      case 4:
        G = 1e4;
        break;
      default:
        G = 5e3;
    }
    return G = L + G, C = { id: v++, callback: z, priorityLevel: C, startTime: L, expirationTime: G, sortIndex: -1 }, L > H ? (C.sortIndex = L, t(f, C), n(s) === null && C === n(f) && (g ? (c(P), P = -1) : g = !0, yl(h, L - H))) : (C.sortIndex = G, t(s, C), S || w || (S = !0, hl(E))), C;
  }, e.unstable_shouldYield = Pe, e.unstable_wrapCallback = function(C) {
    var z = p;
    return function() {
      var L = p;
      p = z;
      try {
        return C.apply(this, arguments);
      } finally {
        p = L;
      }
    };
  };
})(es);
bu.exports = es;
var wc = bu.exports;
/**
 * @license React
 * react-dom.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var Sc = J, ge = wc;
function y(e) {
  for (var t = "https://reactjs.org/docs/error-decoder.html?invariant=" + e, n = 1; n < arguments.length; n++) t += "&args[]=" + encodeURIComponent(arguments[n]);
  return "Minified React error #" + e + "; visit " + t + " for the full message or use the non-minified dev environment for full errors and additional helpful warnings.";
}
var ts = /* @__PURE__ */ new Set(), Rn = {};
function Tt(e, t) {
  qt(e, t), qt(e + "Capture", t);
}
function qt(e, t) {
  for (Rn[e] = t, e = 0; e < t.length; e++) ts.add(t[e]);
}
var Qe = !(typeof window > "u" || typeof window.document > "u" || typeof window.document.createElement > "u"), Ql = Object.prototype.hasOwnProperty, kc = /^[:A-Z_a-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD][:A-Z_a-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\-.0-9\u00B7\u0300-\u036F\u203F-\u2040]*$/, Ii = {}, Fi = {};
function Ec(e) {
  return Ql.call(Fi, e) ? !0 : Ql.call(Ii, e) ? !1 : kc.test(e) ? Fi[e] = !0 : (Ii[e] = !0, !1);
}
function xc(e, t, n, r) {
  if (n !== null && n.type === 0) return !1;
  switch (typeof t) {
    case "function":
    case "symbol":
      return !0;
    case "boolean":
      return r ? !1 : n !== null ? !n.acceptsBooleans : (e = e.toLowerCase().slice(0, 5), e !== "data-" && e !== "aria-");
    default:
      return !1;
  }
}
function Cc(e, t, n, r) {
  if (t === null || typeof t > "u" || xc(e, t, n, r)) return !0;
  if (r) return !1;
  if (n !== null) switch (n.type) {
    case 3:
      return !t;
    case 4:
      return t === !1;
    case 5:
      return isNaN(t);
    case 6:
      return isNaN(t) || 1 > t;
  }
  return !1;
}
function ae(e, t, n, r, l, o, i) {
  this.acceptsBooleans = t === 2 || t === 3 || t === 4, this.attributeName = r, this.attributeNamespace = l, this.mustUseProperty = n, this.propertyName = e, this.type = t, this.sanitizeURL = o, this.removeEmptyString = i;
}
var te = {};
"children dangerouslySetInnerHTML defaultValue defaultChecked innerHTML suppressContentEditableWarning suppressHydrationWarning style".split(" ").forEach(function(e) {
  te[e] = new ae(e, 0, !1, e, null, !1, !1);
});
[["acceptCharset", "accept-charset"], ["className", "class"], ["htmlFor", "for"], ["httpEquiv", "http-equiv"]].forEach(function(e) {
  var t = e[0];
  te[t] = new ae(t, 1, !1, e[1], null, !1, !1);
});
["contentEditable", "draggable", "spellCheck", "value"].forEach(function(e) {
  te[e] = new ae(e, 2, !1, e.toLowerCase(), null, !1, !1);
});
["autoReverse", "externalResourcesRequired", "focusable", "preserveAlpha"].forEach(function(e) {
  te[e] = new ae(e, 2, !1, e, null, !1, !1);
});
"allowFullScreen async autoFocus autoPlay controls default defer disabled disablePictureInPicture disableRemotePlayback formNoValidate hidden loop noModule noValidate open playsInline readOnly required reversed scoped seamless itemScope".split(" ").forEach(function(e) {
  te[e] = new ae(e, 3, !1, e.toLowerCase(), null, !1, !1);
});
["checked", "multiple", "muted", "selected"].forEach(function(e) {
  te[e] = new ae(e, 3, !0, e, null, !1, !1);
});
["capture", "download"].forEach(function(e) {
  te[e] = new ae(e, 4, !1, e, null, !1, !1);
});
["cols", "rows", "size", "span"].forEach(function(e) {
  te[e] = new ae(e, 6, !1, e, null, !1, !1);
});
["rowSpan", "start"].forEach(function(e) {
  te[e] = new ae(e, 5, !1, e.toLowerCase(), null, !1, !1);
});
var Bo = /[\-:]([a-z])/g;
function Wo(e) {
  return e[1].toUpperCase();
}
"accent-height alignment-baseline arabic-form baseline-shift cap-height clip-path clip-rule color-interpolation color-interpolation-filters color-profile color-rendering dominant-baseline enable-background fill-opacity fill-rule flood-color flood-opacity font-family font-size font-size-adjust font-stretch font-style font-variant font-weight glyph-name glyph-orientation-horizontal glyph-orientation-vertical horiz-adv-x horiz-origin-x image-rendering letter-spacing lighting-color marker-end marker-mid marker-start overline-position overline-thickness paint-order panose-1 pointer-events rendering-intent shape-rendering stop-color stop-opacity strikethrough-position strikethrough-thickness stroke-dasharray stroke-dashoffset stroke-linecap stroke-linejoin stroke-miterlimit stroke-opacity stroke-width text-anchor text-decoration text-rendering underline-position underline-thickness unicode-bidi unicode-range units-per-em v-alphabetic v-hanging v-ideographic v-mathematical vector-effect vert-adv-y vert-origin-x vert-origin-y word-spacing writing-mode xmlns:xlink x-height".split(" ").forEach(function(e) {
  var t = e.replace(
    Bo,
    Wo
  );
  te[t] = new ae(t, 1, !1, e, null, !1, !1);
});
"xlink:actuate xlink:arcrole xlink:role xlink:show xlink:title xlink:type".split(" ").forEach(function(e) {
  var t = e.replace(Bo, Wo);
  te[t] = new ae(t, 1, !1, e, "http://www.w3.org/1999/xlink", !1, !1);
});
["xml:base", "xml:lang", "xml:space"].forEach(function(e) {
  var t = e.replace(Bo, Wo);
  te[t] = new ae(t, 1, !1, e, "http://www.w3.org/XML/1998/namespace", !1, !1);
});
["tabIndex", "crossOrigin"].forEach(function(e) {
  te[e] = new ae(e, 1, !1, e.toLowerCase(), null, !1, !1);
});
te.xlinkHref = new ae("xlinkHref", 1, !1, "xlink:href", "http://www.w3.org/1999/xlink", !0, !1);
["src", "href", "action", "formAction"].forEach(function(e) {
  te[e] = new ae(e, 1, !1, e.toLowerCase(), null, !0, !0);
});
function Ho(e, t, n, r) {
  var l = te.hasOwnProperty(t) ? te[t] : null;
  (l !== null ? l.type !== 0 : r || !(2 < t.length) || t[0] !== "o" && t[0] !== "O" || t[1] !== "n" && t[1] !== "N") && (Cc(t, n, l, r) && (n = null), r || l === null ? Ec(t) && (n === null ? e.removeAttribute(t) : e.setAttribute(t, "" + n)) : l.mustUseProperty ? e[l.propertyName] = n === null ? l.type === 3 ? !1 : "" : n : (t = l.attributeName, r = l.attributeNamespace, n === null ? e.removeAttribute(t) : (l = l.type, n = l === 3 || l === 4 && n === !0 ? "" : "" + n, r ? e.setAttributeNS(r, t, n) : e.setAttribute(t, n))));
}
var Ge = Sc.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED, rr = Symbol.for("react.element"), Ot = Symbol.for("react.portal"), jt = Symbol.for("react.fragment"), Qo = Symbol.for("react.strict_mode"), Kl = Symbol.for("react.profiler"), ns = Symbol.for("react.provider"), rs = Symbol.for("react.context"), Ko = Symbol.for("react.forward_ref"), Yl = Symbol.for("react.suspense"), Xl = Symbol.for("react.suspense_list"), Yo = Symbol.for("react.memo"), Je = Symbol.for("react.lazy"), ls = Symbol.for("react.offscreen"), Ui = Symbol.iterator;
function fn(e) {
  return e === null || typeof e != "object" ? null : (e = Ui && e[Ui] || e["@@iterator"], typeof e == "function" ? e : null);
}
var A = Object.assign, Sl;
function wn(e) {
  if (Sl === void 0) try {
    throw Error();
  } catch (n) {
    var t = n.stack.trim().match(/\n( *(at )?)/);
    Sl = t && t[1] || "";
  }
  return `
` + Sl + e;
}
var kl = !1;
function El(e, t) {
  if (!e || kl) return "";
  kl = !0;
  var n = Error.prepareStackTrace;
  Error.prepareStackTrace = void 0;
  try {
    if (t) if (t = function() {
      throw Error();
    }, Object.defineProperty(t.prototype, "props", { set: function() {
      throw Error();
    } }), typeof Reflect == "object" && Reflect.construct) {
      try {
        Reflect.construct(t, []);
      } catch (f) {
        var r = f;
      }
      Reflect.construct(e, [], t);
    } else {
      try {
        t.call();
      } catch (f) {
        r = f;
      }
      e.call(t.prototype);
    }
    else {
      try {
        throw Error();
      } catch (f) {
        r = f;
      }
      e();
    }
  } catch (f) {
    if (f && r && typeof f.stack == "string") {
      for (var l = f.stack.split(`
`), o = r.stack.split(`
`), i = l.length - 1, u = o.length - 1; 1 <= i && 0 <= u && l[i] !== o[u]; ) u--;
      for (; 1 <= i && 0 <= u; i--, u--) if (l[i] !== o[u]) {
        if (i !== 1 || u !== 1)
          do
            if (i--, u--, 0 > u || l[i] !== o[u]) {
              var s = `
` + l[i].replace(" at new ", " at ");
              return e.displayName && s.includes("<anonymous>") && (s = s.replace("<anonymous>", e.displayName)), s;
            }
          while (1 <= i && 0 <= u);
        break;
      }
    }
  } finally {
    kl = !1, Error.prepareStackTrace = n;
  }
  return (e = e ? e.displayName || e.name : "") ? wn(e) : "";
}
function Nc(e) {
  switch (e.tag) {
    case 5:
      return wn(e.type);
    case 16:
      return wn("Lazy");
    case 13:
      return wn("Suspense");
    case 19:
      return wn("SuspenseList");
    case 0:
    case 2:
    case 15:
      return e = El(e.type, !1), e;
    case 11:
      return e = El(e.type.render, !1), e;
    case 1:
      return e = El(e.type, !0), e;
    default:
      return "";
  }
}
function Gl(e) {
  if (e == null) return null;
  if (typeof e == "function") return e.displayName || e.name || null;
  if (typeof e == "string") return e;
  switch (e) {
    case jt:
      return "Fragment";
    case Ot:
      return "Portal";
    case Kl:
      return "Profiler";
    case Qo:
      return "StrictMode";
    case Yl:
      return "Suspense";
    case Xl:
      return "SuspenseList";
  }
  if (typeof e == "object") switch (e.$$typeof) {
    case rs:
      return (e.displayName || "Context") + ".Consumer";
    case ns:
      return (e._context.displayName || "Context") + ".Provider";
    case Ko:
      var t = e.render;
      return e = e.displayName, e || (e = t.displayName || t.name || "", e = e !== "" ? "ForwardRef(" + e + ")" : "ForwardRef"), e;
    case Yo:
      return t = e.displayName || null, t !== null ? t : Gl(e.type) || "Memo";
    case Je:
      t = e._payload, e = e._init;
      try {
        return Gl(e(t));
      } catch {
      }
  }
  return null;
}
function _c(e) {
  var t = e.type;
  switch (e.tag) {
    case 24:
      return "Cache";
    case 9:
      return (t.displayName || "Context") + ".Consumer";
    case 10:
      return (t._context.displayName || "Context") + ".Provider";
    case 18:
      return "DehydratedFragment";
    case 11:
      return e = t.render, e = e.displayName || e.name || "", t.displayName || (e !== "" ? "ForwardRef(" + e + ")" : "ForwardRef");
    case 7:
      return "Fragment";
    case 5:
      return t;
    case 4:
      return "Portal";
    case 3:
      return "Root";
    case 6:
      return "Text";
    case 16:
      return Gl(t);
    case 8:
      return t === Qo ? "StrictMode" : "Mode";
    case 22:
      return "Offscreen";
    case 12:
      return "Profiler";
    case 21:
      return "Scope";
    case 13:
      return "Suspense";
    case 19:
      return "SuspenseList";
    case 25:
      return "TracingMarker";
    case 1:
    case 0:
    case 17:
    case 2:
    case 14:
    case 15:
      if (typeof t == "function") return t.displayName || t.name || null;
      if (typeof t == "string") return t;
  }
  return null;
}
function ft(e) {
  switch (typeof e) {
    case "boolean":
    case "number":
    case "string":
    case "undefined":
      return e;
    case "object":
      return e;
    default:
      return "";
  }
}
function os(e) {
  var t = e.type;
  return (e = e.nodeName) && e.toLowerCase() === "input" && (t === "checkbox" || t === "radio");
}
function Pc(e) {
  var t = os(e) ? "checked" : "value", n = Object.getOwnPropertyDescriptor(e.constructor.prototype, t), r = "" + e[t];
  if (!e.hasOwnProperty(t) && typeof n < "u" && typeof n.get == "function" && typeof n.set == "function") {
    var l = n.get, o = n.set;
    return Object.defineProperty(e, t, { configurable: !0, get: function() {
      return l.call(this);
    }, set: function(i) {
      r = "" + i, o.call(this, i);
    } }), Object.defineProperty(e, t, { enumerable: n.enumerable }), { getValue: function() {
      return r;
    }, setValue: function(i) {
      r = "" + i;
    }, stopTracking: function() {
      e._valueTracker = null, delete e[t];
    } };
  }
}
function lr(e) {
  e._valueTracker || (e._valueTracker = Pc(e));
}
function is(e) {
  if (!e) return !1;
  var t = e._valueTracker;
  if (!t) return !0;
  var n = t.getValue(), r = "";
  return e && (r = os(e) ? e.checked ? "true" : "false" : e.value), e = r, e !== n ? (t.setValue(e), !0) : !1;
}
function Mr(e) {
  if (e = e || (typeof document < "u" ? document : void 0), typeof e > "u") return null;
  try {
    return e.activeElement || e.body;
  } catch {
    return e.body;
  }
}
function Zl(e, t) {
  var n = t.checked;
  return A({}, t, { defaultChecked: void 0, defaultValue: void 0, value: void 0, checked: n ?? e._wrapperState.initialChecked });
}
function $i(e, t) {
  var n = t.defaultValue == null ? "" : t.defaultValue, r = t.checked != null ? t.checked : t.defaultChecked;
  n = ft(t.value != null ? t.value : n), e._wrapperState = { initialChecked: r, initialValue: n, controlled: t.type === "checkbox" || t.type === "radio" ? t.checked != null : t.value != null };
}
function us(e, t) {
  t = t.checked, t != null && Ho(e, "checked", t, !1);
}
function Jl(e, t) {
  us(e, t);
  var n = ft(t.value), r = t.type;
  if (n != null) r === "number" ? (n === 0 && e.value === "" || e.value != n) && (e.value = "" + n) : e.value !== "" + n && (e.value = "" + n);
  else if (r === "submit" || r === "reset") {
    e.removeAttribute("value");
    return;
  }
  t.hasOwnProperty("value") ? ql(e, t.type, n) : t.hasOwnProperty("defaultValue") && ql(e, t.type, ft(t.defaultValue)), t.checked == null && t.defaultChecked != null && (e.defaultChecked = !!t.defaultChecked);
}
function Vi(e, t, n) {
  if (t.hasOwnProperty("value") || t.hasOwnProperty("defaultValue")) {
    var r = t.type;
    if (!(r !== "submit" && r !== "reset" || t.value !== void 0 && t.value !== null)) return;
    t = "" + e._wrapperState.initialValue, n || t === e.value || (e.value = t), e.defaultValue = t;
  }
  n = e.name, n !== "" && (e.name = ""), e.defaultChecked = !!e._wrapperState.initialChecked, n !== "" && (e.name = n);
}
function ql(e, t, n) {
  (t !== "number" || Mr(e.ownerDocument) !== e) && (n == null ? e.defaultValue = "" + e._wrapperState.initialValue : e.defaultValue !== "" + n && (e.defaultValue = "" + n));
}
var Sn = Array.isArray;
function Kt(e, t, n, r) {
  if (e = e.options, t) {
    t = {};
    for (var l = 0; l < n.length; l++) t["$" + n[l]] = !0;
    for (n = 0; n < e.length; n++) l = t.hasOwnProperty("$" + e[n].value), e[n].selected !== l && (e[n].selected = l), l && r && (e[n].defaultSelected = !0);
  } else {
    for (n = "" + ft(n), t = null, l = 0; l < e.length; l++) {
      if (e[l].value === n) {
        e[l].selected = !0, r && (e[l].defaultSelected = !0);
        return;
      }
      t !== null || e[l].disabled || (t = e[l]);
    }
    t !== null && (t.selected = !0);
  }
}
function bl(e, t) {
  if (t.dangerouslySetInnerHTML != null) throw Error(y(91));
  return A({}, t, { value: void 0, defaultValue: void 0, children: "" + e._wrapperState.initialValue });
}
function Ai(e, t) {
  var n = t.value;
  if (n == null) {
    if (n = t.children, t = t.defaultValue, n != null) {
      if (t != null) throw Error(y(92));
      if (Sn(n)) {
        if (1 < n.length) throw Error(y(93));
        n = n[0];
      }
      t = n;
    }
    t == null && (t = ""), n = t;
  }
  e._wrapperState = { initialValue: ft(n) };
}
function ss(e, t) {
  var n = ft(t.value), r = ft(t.defaultValue);
  n != null && (n = "" + n, n !== e.value && (e.value = n), t.defaultValue == null && e.defaultValue !== n && (e.defaultValue = n)), r != null && (e.defaultValue = "" + r);
}
function Bi(e) {
  var t = e.textContent;
  t === e._wrapperState.initialValue && t !== "" && t !== null && (e.value = t);
}
function as(e) {
  switch (e) {
    case "svg":
      return "http://www.w3.org/2000/svg";
    case "math":
      return "http://www.w3.org/1998/Math/MathML";
    default:
      return "http://www.w3.org/1999/xhtml";
  }
}
function eo(e, t) {
  return e == null || e === "http://www.w3.org/1999/xhtml" ? as(t) : e === "http://www.w3.org/2000/svg" && t === "foreignObject" ? "http://www.w3.org/1999/xhtml" : e;
}
var or, cs = function(e) {
  return typeof MSApp < "u" && MSApp.execUnsafeLocalFunction ? function(t, n, r, l) {
    MSApp.execUnsafeLocalFunction(function() {
      return e(t, n, r, l);
    });
  } : e;
}(function(e, t) {
  if (e.namespaceURI !== "http://www.w3.org/2000/svg" || "innerHTML" in e) e.innerHTML = t;
  else {
    for (or = or || document.createElement("div"), or.innerHTML = "<svg>" + t.valueOf().toString() + "</svg>", t = or.firstChild; e.firstChild; ) e.removeChild(e.firstChild);
    for (; t.firstChild; ) e.appendChild(t.firstChild);
  }
});
function Dn(e, t) {
  if (t) {
    var n = e.firstChild;
    if (n && n === e.lastChild && n.nodeType === 3) {
      n.nodeValue = t;
      return;
    }
  }
  e.textContent = t;
}
var xn = {
  animationIterationCount: !0,
  aspectRatio: !0,
  borderImageOutset: !0,
  borderImageSlice: !0,
  borderImageWidth: !0,
  boxFlex: !0,
  boxFlexGroup: !0,
  boxOrdinalGroup: !0,
  columnCount: !0,
  columns: !0,
  flex: !0,
  flexGrow: !0,
  flexPositive: !0,
  flexShrink: !0,
  flexNegative: !0,
  flexOrder: !0,
  gridArea: !0,
  gridRow: !0,
  gridRowEnd: !0,
  gridRowSpan: !0,
  gridRowStart: !0,
  gridColumn: !0,
  gridColumnEnd: !0,
  gridColumnSpan: !0,
  gridColumnStart: !0,
  fontWeight: !0,
  lineClamp: !0,
  lineHeight: !0,
  opacity: !0,
  order: !0,
  orphans: !0,
  tabSize: !0,
  widows: !0,
  zIndex: !0,
  zoom: !0,
  fillOpacity: !0,
  floodOpacity: !0,
  stopOpacity: !0,
  strokeDasharray: !0,
  strokeDashoffset: !0,
  strokeMiterlimit: !0,
  strokeOpacity: !0,
  strokeWidth: !0
}, zc = ["Webkit", "ms", "Moz", "O"];
Object.keys(xn).forEach(function(e) {
  zc.forEach(function(t) {
    t = t + e.charAt(0).toUpperCase() + e.substring(1), xn[t] = xn[e];
  });
});
function fs(e, t, n) {
  return t == null || typeof t == "boolean" || t === "" ? "" : n || typeof t != "number" || t === 0 || xn.hasOwnProperty(e) && xn[e] ? ("" + t).trim() : t + "px";
}
function ds(e, t) {
  e = e.style;
  for (var n in t) if (t.hasOwnProperty(n)) {
    var r = n.indexOf("--") === 0, l = fs(n, t[n], r);
    n === "float" && (n = "cssFloat"), r ? e.setProperty(n, l) : e[n] = l;
  }
}
var Lc = A({ menuitem: !0 }, { area: !0, base: !0, br: !0, col: !0, embed: !0, hr: !0, img: !0, input: !0, keygen: !0, link: !0, meta: !0, param: !0, source: !0, track: !0, wbr: !0 });
function to(e, t) {
  if (t) {
    if (Lc[e] && (t.children != null || t.dangerouslySetInnerHTML != null)) throw Error(y(137, e));
    if (t.dangerouslySetInnerHTML != null) {
      if (t.children != null) throw Error(y(60));
      if (typeof t.dangerouslySetInnerHTML != "object" || !("__html" in t.dangerouslySetInnerHTML)) throw Error(y(61));
    }
    if (t.style != null && typeof t.style != "object") throw Error(y(62));
  }
}
function no(e, t) {
  if (e.indexOf("-") === -1) return typeof t.is == "string";
  switch (e) {
    case "annotation-xml":
    case "color-profile":
    case "font-face":
    case "font-face-src":
    case "font-face-uri":
    case "font-face-format":
    case "font-face-name":
    case "missing-glyph":
      return !1;
    default:
      return !0;
  }
}
var ro = null;
function Xo(e) {
  return e = e.target || e.srcElement || window, e.correspondingUseElement && (e = e.correspondingUseElement), e.nodeType === 3 ? e.parentNode : e;
}
var lo = null, Yt = null, Xt = null;
function Wi(e) {
  if (e = qn(e)) {
    if (typeof lo != "function") throw Error(y(280));
    var t = e.stateNode;
    t && (t = ol(t), lo(e.stateNode, e.type, t));
  }
}
function ps(e) {
  Yt ? Xt ? Xt.push(e) : Xt = [e] : Yt = e;
}
function ms() {
  if (Yt) {
    var e = Yt, t = Xt;
    if (Xt = Yt = null, Wi(e), t) for (e = 0; e < t.length; e++) Wi(t[e]);
  }
}
function vs(e, t) {
  return e(t);
}
function hs() {
}
var xl = !1;
function ys(e, t, n) {
  if (xl) return e(t, n);
  xl = !0;
  try {
    return vs(e, t, n);
  } finally {
    xl = !1, (Yt !== null || Xt !== null) && (hs(), ms());
  }
}
function On(e, t) {
  var n = e.stateNode;
  if (n === null) return null;
  var r = ol(n);
  if (r === null) return null;
  n = r[t];
  e: switch (t) {
    case "onClick":
    case "onClickCapture":
    case "onDoubleClick":
    case "onDoubleClickCapture":
    case "onMouseDown":
    case "onMouseDownCapture":
    case "onMouseMove":
    case "onMouseMoveCapture":
    case "onMouseUp":
    case "onMouseUpCapture":
    case "onMouseEnter":
      (r = !r.disabled) || (e = e.type, r = !(e === "button" || e === "input" || e === "select" || e === "textarea")), e = !r;
      break e;
    default:
      e = !1;
  }
  if (e) return null;
  if (n && typeof n != "function") throw Error(y(231, t, typeof n));
  return n;
}
var oo = !1;
if (Qe) try {
  var dn = {};
  Object.defineProperty(dn, "passive", { get: function() {
    oo = !0;
  } }), window.addEventListener("test", dn, dn), window.removeEventListener("test", dn, dn);
} catch {
  oo = !1;
}
function Tc(e, t, n, r, l, o, i, u, s) {
  var f = Array.prototype.slice.call(arguments, 3);
  try {
    t.apply(n, f);
  } catch (v) {
    this.onError(v);
  }
}
var Cn = !1, Rr = null, Dr = !1, io = null, Mc = { onError: function(e) {
  Cn = !0, Rr = e;
} };
function Rc(e, t, n, r, l, o, i, u, s) {
  Cn = !1, Rr = null, Tc.apply(Mc, arguments);
}
function Dc(e, t, n, r, l, o, i, u, s) {
  if (Rc.apply(this, arguments), Cn) {
    if (Cn) {
      var f = Rr;
      Cn = !1, Rr = null;
    } else throw Error(y(198));
    Dr || (Dr = !0, io = f);
  }
}
function Mt(e) {
  var t = e, n = e;
  if (e.alternate) for (; t.return; ) t = t.return;
  else {
    e = t;
    do
      t = e, t.flags & 4098 && (n = t.return), e = t.return;
    while (e);
  }
  return t.tag === 3 ? n : null;
}
function gs(e) {
  if (e.tag === 13) {
    var t = e.memoizedState;
    if (t === null && (e = e.alternate, e !== null && (t = e.memoizedState)), t !== null) return t.dehydrated;
  }
  return null;
}
function Hi(e) {
  if (Mt(e) !== e) throw Error(y(188));
}
function Oc(e) {
  var t = e.alternate;
  if (!t) {
    if (t = Mt(e), t === null) throw Error(y(188));
    return t !== e ? null : e;
  }
  for (var n = e, r = t; ; ) {
    var l = n.return;
    if (l === null) break;
    var o = l.alternate;
    if (o === null) {
      if (r = l.return, r !== null) {
        n = r;
        continue;
      }
      break;
    }
    if (l.child === o.child) {
      for (o = l.child; o; ) {
        if (o === n) return Hi(l), e;
        if (o === r) return Hi(l), t;
        o = o.sibling;
      }
      throw Error(y(188));
    }
    if (n.return !== r.return) n = l, r = o;
    else {
      for (var i = !1, u = l.child; u; ) {
        if (u === n) {
          i = !0, n = l, r = o;
          break;
        }
        if (u === r) {
          i = !0, r = l, n = o;
          break;
        }
        u = u.sibling;
      }
      if (!i) {
        for (u = o.child; u; ) {
          if (u === n) {
            i = !0, n = o, r = l;
            break;
          }
          if (u === r) {
            i = !0, r = o, n = l;
            break;
          }
          u = u.sibling;
        }
        if (!i) throw Error(y(189));
      }
    }
    if (n.alternate !== r) throw Error(y(190));
  }
  if (n.tag !== 3) throw Error(y(188));
  return n.stateNode.current === n ? e : t;
}
function ws(e) {
  return e = Oc(e), e !== null ? Ss(e) : null;
}
function Ss(e) {
  if (e.tag === 5 || e.tag === 6) return e;
  for (e = e.child; e !== null; ) {
    var t = Ss(e);
    if (t !== null) return t;
    e = e.sibling;
  }
  return null;
}
var ks = ge.unstable_scheduleCallback, Qi = ge.unstable_cancelCallback, jc = ge.unstable_shouldYield, Ic = ge.unstable_requestPaint, Q = ge.unstable_now, Fc = ge.unstable_getCurrentPriorityLevel, Go = ge.unstable_ImmediatePriority, Es = ge.unstable_UserBlockingPriority, Or = ge.unstable_NormalPriority, Uc = ge.unstable_LowPriority, xs = ge.unstable_IdlePriority, tl = null, Ue = null;
function $c(e) {
  if (Ue && typeof Ue.onCommitFiberRoot == "function") try {
    Ue.onCommitFiberRoot(tl, e, void 0, (e.current.flags & 128) === 128);
  } catch {
  }
}
var Re = Math.clz32 ? Math.clz32 : Bc, Vc = Math.log, Ac = Math.LN2;
function Bc(e) {
  return e >>>= 0, e === 0 ? 32 : 31 - (Vc(e) / Ac | 0) | 0;
}
var ir = 64, ur = 4194304;
function kn(e) {
  switch (e & -e) {
    case 1:
      return 1;
    case 2:
      return 2;
    case 4:
      return 4;
    case 8:
      return 8;
    case 16:
      return 16;
    case 32:
      return 32;
    case 64:
    case 128:
    case 256:
    case 512:
    case 1024:
    case 2048:
    case 4096:
    case 8192:
    case 16384:
    case 32768:
    case 65536:
    case 131072:
    case 262144:
    case 524288:
    case 1048576:
    case 2097152:
      return e & 4194240;
    case 4194304:
    case 8388608:
    case 16777216:
    case 33554432:
    case 67108864:
      return e & 130023424;
    case 134217728:
      return 134217728;
    case 268435456:
      return 268435456;
    case 536870912:
      return 536870912;
    case 1073741824:
      return 1073741824;
    default:
      return e;
  }
}
function jr(e, t) {
  var n = e.pendingLanes;
  if (n === 0) return 0;
  var r = 0, l = e.suspendedLanes, o = e.pingedLanes, i = n & 268435455;
  if (i !== 0) {
    var u = i & ~l;
    u !== 0 ? r = kn(u) : (o &= i, o !== 0 && (r = kn(o)));
  } else i = n & ~l, i !== 0 ? r = kn(i) : o !== 0 && (r = kn(o));
  if (r === 0) return 0;
  if (t !== 0 && t !== r && !(t & l) && (l = r & -r, o = t & -t, l >= o || l === 16 && (o & 4194240) !== 0)) return t;
  if (r & 4 && (r |= n & 16), t = e.entangledLanes, t !== 0) for (e = e.entanglements, t &= r; 0 < t; ) n = 31 - Re(t), l = 1 << n, r |= e[n], t &= ~l;
  return r;
}
function Wc(e, t) {
  switch (e) {
    case 1:
    case 2:
    case 4:
      return t + 250;
    case 8:
    case 16:
    case 32:
    case 64:
    case 128:
    case 256:
    case 512:
    case 1024:
    case 2048:
    case 4096:
    case 8192:
    case 16384:
    case 32768:
    case 65536:
    case 131072:
    case 262144:
    case 524288:
    case 1048576:
    case 2097152:
      return t + 5e3;
    case 4194304:
    case 8388608:
    case 16777216:
    case 33554432:
    case 67108864:
      return -1;
    case 134217728:
    case 268435456:
    case 536870912:
    case 1073741824:
      return -1;
    default:
      return -1;
  }
}
function Hc(e, t) {
  for (var n = e.suspendedLanes, r = e.pingedLanes, l = e.expirationTimes, o = e.pendingLanes; 0 < o; ) {
    var i = 31 - Re(o), u = 1 << i, s = l[i];
    s === -1 ? (!(u & n) || u & r) && (l[i] = Wc(u, t)) : s <= t && (e.expiredLanes |= u), o &= ~u;
  }
}
function uo(e) {
  return e = e.pendingLanes & -1073741825, e !== 0 ? e : e & 1073741824 ? 1073741824 : 0;
}
function Cs() {
  var e = ir;
  return ir <<= 1, !(ir & 4194240) && (ir = 64), e;
}
function Cl(e) {
  for (var t = [], n = 0; 31 > n; n++) t.push(e);
  return t;
}
function Zn(e, t, n) {
  e.pendingLanes |= t, t !== 536870912 && (e.suspendedLanes = 0, e.pingedLanes = 0), e = e.eventTimes, t = 31 - Re(t), e[t] = n;
}
function Qc(e, t) {
  var n = e.pendingLanes & ~t;
  e.pendingLanes = t, e.suspendedLanes = 0, e.pingedLanes = 0, e.expiredLanes &= t, e.mutableReadLanes &= t, e.entangledLanes &= t, t = e.entanglements;
  var r = e.eventTimes;
  for (e = e.expirationTimes; 0 < n; ) {
    var l = 31 - Re(n), o = 1 << l;
    t[l] = 0, r[l] = -1, e[l] = -1, n &= ~o;
  }
}
function Zo(e, t) {
  var n = e.entangledLanes |= t;
  for (e = e.entanglements; n; ) {
    var r = 31 - Re(n), l = 1 << r;
    l & t | e[r] & t && (e[r] |= t), n &= ~l;
  }
}
var O = 0;
function Ns(e) {
  return e &= -e, 1 < e ? 4 < e ? e & 268435455 ? 16 : 536870912 : 4 : 1;
}
var _s, Jo, Ps, zs, Ls, so = !1, sr = [], rt = null, lt = null, ot = null, jn = /* @__PURE__ */ new Map(), In = /* @__PURE__ */ new Map(), be = [], Kc = "mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset submit".split(" ");
function Ki(e, t) {
  switch (e) {
    case "focusin":
    case "focusout":
      rt = null;
      break;
    case "dragenter":
    case "dragleave":
      lt = null;
      break;
    case "mouseover":
    case "mouseout":
      ot = null;
      break;
    case "pointerover":
    case "pointerout":
      jn.delete(t.pointerId);
      break;
    case "gotpointercapture":
    case "lostpointercapture":
      In.delete(t.pointerId);
  }
}
function pn(e, t, n, r, l, o) {
  return e === null || e.nativeEvent !== o ? (e = { blockedOn: t, domEventName: n, eventSystemFlags: r, nativeEvent: o, targetContainers: [l] }, t !== null && (t = qn(t), t !== null && Jo(t)), e) : (e.eventSystemFlags |= r, t = e.targetContainers, l !== null && t.indexOf(l) === -1 && t.push(l), e);
}
function Yc(e, t, n, r, l) {
  switch (t) {
    case "focusin":
      return rt = pn(rt, e, t, n, r, l), !0;
    case "dragenter":
      return lt = pn(lt, e, t, n, r, l), !0;
    case "mouseover":
      return ot = pn(ot, e, t, n, r, l), !0;
    case "pointerover":
      var o = l.pointerId;
      return jn.set(o, pn(jn.get(o) || null, e, t, n, r, l)), !0;
    case "gotpointercapture":
      return o = l.pointerId, In.set(o, pn(In.get(o) || null, e, t, n, r, l)), !0;
  }
  return !1;
}
function Ts(e) {
  var t = St(e.target);
  if (t !== null) {
    var n = Mt(t);
    if (n !== null) {
      if (t = n.tag, t === 13) {
        if (t = gs(n), t !== null) {
          e.blockedOn = t, Ls(e.priority, function() {
            Ps(n);
          });
          return;
        }
      } else if (t === 3 && n.stateNode.current.memoizedState.isDehydrated) {
        e.blockedOn = n.tag === 3 ? n.stateNode.containerInfo : null;
        return;
      }
    }
  }
  e.blockedOn = null;
}
function kr(e) {
  if (e.blockedOn !== null) return !1;
  for (var t = e.targetContainers; 0 < t.length; ) {
    var n = ao(e.domEventName, e.eventSystemFlags, t[0], e.nativeEvent);
    if (n === null) {
      n = e.nativeEvent;
      var r = new n.constructor(n.type, n);
      ro = r, n.target.dispatchEvent(r), ro = null;
    } else return t = qn(n), t !== null && Jo(t), e.blockedOn = n, !1;
    t.shift();
  }
  return !0;
}
function Yi(e, t, n) {
  kr(e) && n.delete(t);
}
function Xc() {
  so = !1, rt !== null && kr(rt) && (rt = null), lt !== null && kr(lt) && (lt = null), ot !== null && kr(ot) && (ot = null), jn.forEach(Yi), In.forEach(Yi);
}
function mn(e, t) {
  e.blockedOn === t && (e.blockedOn = null, so || (so = !0, ge.unstable_scheduleCallback(ge.unstable_NormalPriority, Xc)));
}
function Fn(e) {
  function t(l) {
    return mn(l, e);
  }
  if (0 < sr.length) {
    mn(sr[0], e);
    for (var n = 1; n < sr.length; n++) {
      var r = sr[n];
      r.blockedOn === e && (r.blockedOn = null);
    }
  }
  for (rt !== null && mn(rt, e), lt !== null && mn(lt, e), ot !== null && mn(ot, e), jn.forEach(t), In.forEach(t), n = 0; n < be.length; n++) r = be[n], r.blockedOn === e && (r.blockedOn = null);
  for (; 0 < be.length && (n = be[0], n.blockedOn === null); ) Ts(n), n.blockedOn === null && be.shift();
}
var Gt = Ge.ReactCurrentBatchConfig, Ir = !0;
function Gc(e, t, n, r) {
  var l = O, o = Gt.transition;
  Gt.transition = null;
  try {
    O = 1, qo(e, t, n, r);
  } finally {
    O = l, Gt.transition = o;
  }
}
function Zc(e, t, n, r) {
  var l = O, o = Gt.transition;
  Gt.transition = null;
  try {
    O = 4, qo(e, t, n, r);
  } finally {
    O = l, Gt.transition = o;
  }
}
function qo(e, t, n, r) {
  if (Ir) {
    var l = ao(e, t, n, r);
    if (l === null) Ol(e, t, r, Fr, n), Ki(e, r);
    else if (Yc(l, e, t, n, r)) r.stopPropagation();
    else if (Ki(e, r), t & 4 && -1 < Kc.indexOf(e)) {
      for (; l !== null; ) {
        var o = qn(l);
        if (o !== null && _s(o), o = ao(e, t, n, r), o === null && Ol(e, t, r, Fr, n), o === l) break;
        l = o;
      }
      l !== null && r.stopPropagation();
    } else Ol(e, t, r, null, n);
  }
}
var Fr = null;
function ao(e, t, n, r) {
  if (Fr = null, e = Xo(r), e = St(e), e !== null) if (t = Mt(e), t === null) e = null;
  else if (n = t.tag, n === 13) {
    if (e = gs(t), e !== null) return e;
    e = null;
  } else if (n === 3) {
    if (t.stateNode.current.memoizedState.isDehydrated) return t.tag === 3 ? t.stateNode.containerInfo : null;
    e = null;
  } else t !== e && (e = null);
  return Fr = e, null;
}
function Ms(e) {
  switch (e) {
    case "cancel":
    case "click":
    case "close":
    case "contextmenu":
    case "copy":
    case "cut":
    case "auxclick":
    case "dblclick":
    case "dragend":
    case "dragstart":
    case "drop":
    case "focusin":
    case "focusout":
    case "input":
    case "invalid":
    case "keydown":
    case "keypress":
    case "keyup":
    case "mousedown":
    case "mouseup":
    case "paste":
    case "pause":
    case "play":
    case "pointercancel":
    case "pointerdown":
    case "pointerup":
    case "ratechange":
    case "reset":
    case "resize":
    case "seeked":
    case "submit":
    case "touchcancel":
    case "touchend":
    case "touchstart":
    case "volumechange":
    case "change":
    case "selectionchange":
    case "textInput":
    case "compositionstart":
    case "compositionend":
    case "compositionupdate":
    case "beforeblur":
    case "afterblur":
    case "beforeinput":
    case "blur":
    case "fullscreenchange":
    case "focus":
    case "hashchange":
    case "popstate":
    case "select":
    case "selectstart":
      return 1;
    case "drag":
    case "dragenter":
    case "dragexit":
    case "dragleave":
    case "dragover":
    case "mousemove":
    case "mouseout":
    case "mouseover":
    case "pointermove":
    case "pointerout":
    case "pointerover":
    case "scroll":
    case "toggle":
    case "touchmove":
    case "wheel":
    case "mouseenter":
    case "mouseleave":
    case "pointerenter":
    case "pointerleave":
      return 4;
    case "message":
      switch (Fc()) {
        case Go:
          return 1;
        case Es:
          return 4;
        case Or:
        case Uc:
          return 16;
        case xs:
          return 536870912;
        default:
          return 16;
      }
    default:
      return 16;
  }
}
var tt = null, bo = null, Er = null;
function Rs() {
  if (Er) return Er;
  var e, t = bo, n = t.length, r, l = "value" in tt ? tt.value : tt.textContent, o = l.length;
  for (e = 0; e < n && t[e] === l[e]; e++) ;
  var i = n - e;
  for (r = 1; r <= i && t[n - r] === l[o - r]; r++) ;
  return Er = l.slice(e, 1 < r ? 1 - r : void 0);
}
function xr(e) {
  var t = e.keyCode;
  return "charCode" in e ? (e = e.charCode, e === 0 && t === 13 && (e = 13)) : e = t, e === 10 && (e = 13), 32 <= e || e === 13 ? e : 0;
}
function ar() {
  return !0;
}
function Xi() {
  return !1;
}
function Se(e) {
  function t(n, r, l, o, i) {
    this._reactName = n, this._targetInst = l, this.type = r, this.nativeEvent = o, this.target = i, this.currentTarget = null;
    for (var u in e) e.hasOwnProperty(u) && (n = e[u], this[u] = n ? n(o) : o[u]);
    return this.isDefaultPrevented = (o.defaultPrevented != null ? o.defaultPrevented : o.returnValue === !1) ? ar : Xi, this.isPropagationStopped = Xi, this;
  }
  return A(t.prototype, { preventDefault: function() {
    this.defaultPrevented = !0;
    var n = this.nativeEvent;
    n && (n.preventDefault ? n.preventDefault() : typeof n.returnValue != "unknown" && (n.returnValue = !1), this.isDefaultPrevented = ar);
  }, stopPropagation: function() {
    var n = this.nativeEvent;
    n && (n.stopPropagation ? n.stopPropagation() : typeof n.cancelBubble != "unknown" && (n.cancelBubble = !0), this.isPropagationStopped = ar);
  }, persist: function() {
  }, isPersistent: ar }), t;
}
var un = { eventPhase: 0, bubbles: 0, cancelable: 0, timeStamp: function(e) {
  return e.timeStamp || Date.now();
}, defaultPrevented: 0, isTrusted: 0 }, ei = Se(un), Jn = A({}, un, { view: 0, detail: 0 }), Jc = Se(Jn), Nl, _l, vn, nl = A({}, Jn, { screenX: 0, screenY: 0, clientX: 0, clientY: 0, pageX: 0, pageY: 0, ctrlKey: 0, shiftKey: 0, altKey: 0, metaKey: 0, getModifierState: ti, button: 0, buttons: 0, relatedTarget: function(e) {
  return e.relatedTarget === void 0 ? e.fromElement === e.srcElement ? e.toElement : e.fromElement : e.relatedTarget;
}, movementX: function(e) {
  return "movementX" in e ? e.movementX : (e !== vn && (vn && e.type === "mousemove" ? (Nl = e.screenX - vn.screenX, _l = e.screenY - vn.screenY) : _l = Nl = 0, vn = e), Nl);
}, movementY: function(e) {
  return "movementY" in e ? e.movementY : _l;
} }), Gi = Se(nl), qc = A({}, nl, { dataTransfer: 0 }), bc = Se(qc), ef = A({}, Jn, { relatedTarget: 0 }), Pl = Se(ef), tf = A({}, un, { animationName: 0, elapsedTime: 0, pseudoElement: 0 }), nf = Se(tf), rf = A({}, un, { clipboardData: function(e) {
  return "clipboardData" in e ? e.clipboardData : window.clipboardData;
} }), lf = Se(rf), of = A({}, un, { data: 0 }), Zi = Se(of), uf = {
  Esc: "Escape",
  Spacebar: " ",
  Left: "ArrowLeft",
  Up: "ArrowUp",
  Right: "ArrowRight",
  Down: "ArrowDown",
  Del: "Delete",
  Win: "OS",
  Menu: "ContextMenu",
  Apps: "ContextMenu",
  Scroll: "ScrollLock",
  MozPrintableKey: "Unidentified"
}, sf = {
  8: "Backspace",
  9: "Tab",
  12: "Clear",
  13: "Enter",
  16: "Shift",
  17: "Control",
  18: "Alt",
  19: "Pause",
  20: "CapsLock",
  27: "Escape",
  32: " ",
  33: "PageUp",
  34: "PageDown",
  35: "End",
  36: "Home",
  37: "ArrowLeft",
  38: "ArrowUp",
  39: "ArrowRight",
  40: "ArrowDown",
  45: "Insert",
  46: "Delete",
  112: "F1",
  113: "F2",
  114: "F3",
  115: "F4",
  116: "F5",
  117: "F6",
  118: "F7",
  119: "F8",
  120: "F9",
  121: "F10",
  122: "F11",
  123: "F12",
  144: "NumLock",
  145: "ScrollLock",
  224: "Meta"
}, af = { Alt: "altKey", Control: "ctrlKey", Meta: "metaKey", Shift: "shiftKey" };
function cf(e) {
  var t = this.nativeEvent;
  return t.getModifierState ? t.getModifierState(e) : (e = af[e]) ? !!t[e] : !1;
}
function ti() {
  return cf;
}
var ff = A({}, Jn, { key: function(e) {
  if (e.key) {
    var t = uf[e.key] || e.key;
    if (t !== "Unidentified") return t;
  }
  return e.type === "keypress" ? (e = xr(e), e === 13 ? "Enter" : String.fromCharCode(e)) : e.type === "keydown" || e.type === "keyup" ? sf[e.keyCode] || "Unidentified" : "";
}, code: 0, location: 0, ctrlKey: 0, shiftKey: 0, altKey: 0, metaKey: 0, repeat: 0, locale: 0, getModifierState: ti, charCode: function(e) {
  return e.type === "keypress" ? xr(e) : 0;
}, keyCode: function(e) {
  return e.type === "keydown" || e.type === "keyup" ? e.keyCode : 0;
}, which: function(e) {
  return e.type === "keypress" ? xr(e) : e.type === "keydown" || e.type === "keyup" ? e.keyCode : 0;
} }), df = Se(ff), pf = A({}, nl, { pointerId: 0, width: 0, height: 0, pressure: 0, tangentialPressure: 0, tiltX: 0, tiltY: 0, twist: 0, pointerType: 0, isPrimary: 0 }), Ji = Se(pf), mf = A({}, Jn, { touches: 0, targetTouches: 0, changedTouches: 0, altKey: 0, metaKey: 0, ctrlKey: 0, shiftKey: 0, getModifierState: ti }), vf = Se(mf), hf = A({}, un, { propertyName: 0, elapsedTime: 0, pseudoElement: 0 }), yf = Se(hf), gf = A({}, nl, {
  deltaX: function(e) {
    return "deltaX" in e ? e.deltaX : "wheelDeltaX" in e ? -e.wheelDeltaX : 0;
  },
  deltaY: function(e) {
    return "deltaY" in e ? e.deltaY : "wheelDeltaY" in e ? -e.wheelDeltaY : "wheelDelta" in e ? -e.wheelDelta : 0;
  },
  deltaZ: 0,
  deltaMode: 0
}), wf = Se(gf), Sf = [9, 13, 27, 32], ni = Qe && "CompositionEvent" in window, Nn = null;
Qe && "documentMode" in document && (Nn = document.documentMode);
var kf = Qe && "TextEvent" in window && !Nn, Ds = Qe && (!ni || Nn && 8 < Nn && 11 >= Nn), qi = " ", bi = !1;
function Os(e, t) {
  switch (e) {
    case "keyup":
      return Sf.indexOf(t.keyCode) !== -1;
    case "keydown":
      return t.keyCode !== 229;
    case "keypress":
    case "mousedown":
    case "focusout":
      return !0;
    default:
      return !1;
  }
}
function js(e) {
  return e = e.detail, typeof e == "object" && "data" in e ? e.data : null;
}
var It = !1;
function Ef(e, t) {
  switch (e) {
    case "compositionend":
      return js(t);
    case "keypress":
      return t.which !== 32 ? null : (bi = !0, qi);
    case "textInput":
      return e = t.data, e === qi && bi ? null : e;
    default:
      return null;
  }
}
function xf(e, t) {
  if (It) return e === "compositionend" || !ni && Os(e, t) ? (e = Rs(), Er = bo = tt = null, It = !1, e) : null;
  switch (e) {
    case "paste":
      return null;
    case "keypress":
      if (!(t.ctrlKey || t.altKey || t.metaKey) || t.ctrlKey && t.altKey) {
        if (t.char && 1 < t.char.length) return t.char;
        if (t.which) return String.fromCharCode(t.which);
      }
      return null;
    case "compositionend":
      return Ds && t.locale !== "ko" ? null : t.data;
    default:
      return null;
  }
}
var Cf = { color: !0, date: !0, datetime: !0, "datetime-local": !0, email: !0, month: !0, number: !0, password: !0, range: !0, search: !0, tel: !0, text: !0, time: !0, url: !0, week: !0 };
function eu(e) {
  var t = e && e.nodeName && e.nodeName.toLowerCase();
  return t === "input" ? !!Cf[e.type] : t === "textarea";
}
function Is(e, t, n, r) {
  ps(r), t = Ur(t, "onChange"), 0 < t.length && (n = new ei("onChange", "change", null, n, r), e.push({ event: n, listeners: t }));
}
var _n = null, Un = null;
function Nf(e) {
  Ys(e, 0);
}
function rl(e) {
  var t = $t(e);
  if (is(t)) return e;
}
function _f(e, t) {
  if (e === "change") return t;
}
var Fs = !1;
if (Qe) {
  var zl;
  if (Qe) {
    var Ll = "oninput" in document;
    if (!Ll) {
      var tu = document.createElement("div");
      tu.setAttribute("oninput", "return;"), Ll = typeof tu.oninput == "function";
    }
    zl = Ll;
  } else zl = !1;
  Fs = zl && (!document.documentMode || 9 < document.documentMode);
}
function nu() {
  _n && (_n.detachEvent("onpropertychange", Us), Un = _n = null);
}
function Us(e) {
  if (e.propertyName === "value" && rl(Un)) {
    var t = [];
    Is(t, Un, e, Xo(e)), ys(Nf, t);
  }
}
function Pf(e, t, n) {
  e === "focusin" ? (nu(), _n = t, Un = n, _n.attachEvent("onpropertychange", Us)) : e === "focusout" && nu();
}
function zf(e) {
  if (e === "selectionchange" || e === "keyup" || e === "keydown") return rl(Un);
}
function Lf(e, t) {
  if (e === "click") return rl(t);
}
function Tf(e, t) {
  if (e === "input" || e === "change") return rl(t);
}
function Mf(e, t) {
  return e === t && (e !== 0 || 1 / e === 1 / t) || e !== e && t !== t;
}
var Oe = typeof Object.is == "function" ? Object.is : Mf;
function $n(e, t) {
  if (Oe(e, t)) return !0;
  if (typeof e != "object" || e === null || typeof t != "object" || t === null) return !1;
  var n = Object.keys(e), r = Object.keys(t);
  if (n.length !== r.length) return !1;
  for (r = 0; r < n.length; r++) {
    var l = n[r];
    if (!Ql.call(t, l) || !Oe(e[l], t[l])) return !1;
  }
  return !0;
}
function ru(e) {
  for (; e && e.firstChild; ) e = e.firstChild;
  return e;
}
function lu(e, t) {
  var n = ru(e);
  e = 0;
  for (var r; n; ) {
    if (n.nodeType === 3) {
      if (r = e + n.textContent.length, e <= t && r >= t) return { node: n, offset: t - e };
      e = r;
    }
    e: {
      for (; n; ) {
        if (n.nextSibling) {
          n = n.nextSibling;
          break e;
        }
        n = n.parentNode;
      }
      n = void 0;
    }
    n = ru(n);
  }
}
function $s(e, t) {
  return e && t ? e === t ? !0 : e && e.nodeType === 3 ? !1 : t && t.nodeType === 3 ? $s(e, t.parentNode) : "contains" in e ? e.contains(t) : e.compareDocumentPosition ? !!(e.compareDocumentPosition(t) & 16) : !1 : !1;
}
function Vs() {
  for (var e = window, t = Mr(); t instanceof e.HTMLIFrameElement; ) {
    try {
      var n = typeof t.contentWindow.location.href == "string";
    } catch {
      n = !1;
    }
    if (n) e = t.contentWindow;
    else break;
    t = Mr(e.document);
  }
  return t;
}
function ri(e) {
  var t = e && e.nodeName && e.nodeName.toLowerCase();
  return t && (t === "input" && (e.type === "text" || e.type === "search" || e.type === "tel" || e.type === "url" || e.type === "password") || t === "textarea" || e.contentEditable === "true");
}
function Rf(e) {
  var t = Vs(), n = e.focusedElem, r = e.selectionRange;
  if (t !== n && n && n.ownerDocument && $s(n.ownerDocument.documentElement, n)) {
    if (r !== null && ri(n)) {
      if (t = r.start, e = r.end, e === void 0 && (e = t), "selectionStart" in n) n.selectionStart = t, n.selectionEnd = Math.min(e, n.value.length);
      else if (e = (t = n.ownerDocument || document) && t.defaultView || window, e.getSelection) {
        e = e.getSelection();
        var l = n.textContent.length, o = Math.min(r.start, l);
        r = r.end === void 0 ? o : Math.min(r.end, l), !e.extend && o > r && (l = r, r = o, o = l), l = lu(n, o);
        var i = lu(
          n,
          r
        );
        l && i && (e.rangeCount !== 1 || e.anchorNode !== l.node || e.anchorOffset !== l.offset || e.focusNode !== i.node || e.focusOffset !== i.offset) && (t = t.createRange(), t.setStart(l.node, l.offset), e.removeAllRanges(), o > r ? (e.addRange(t), e.extend(i.node, i.offset)) : (t.setEnd(i.node, i.offset), e.addRange(t)));
      }
    }
    for (t = [], e = n; e = e.parentNode; ) e.nodeType === 1 && t.push({ element: e, left: e.scrollLeft, top: e.scrollTop });
    for (typeof n.focus == "function" && n.focus(), n = 0; n < t.length; n++) e = t[n], e.element.scrollLeft = e.left, e.element.scrollTop = e.top;
  }
}
var Df = Qe && "documentMode" in document && 11 >= document.documentMode, Ft = null, co = null, Pn = null, fo = !1;
function ou(e, t, n) {
  var r = n.window === n ? n.document : n.nodeType === 9 ? n : n.ownerDocument;
  fo || Ft == null || Ft !== Mr(r) || (r = Ft, "selectionStart" in r && ri(r) ? r = { start: r.selectionStart, end: r.selectionEnd } : (r = (r.ownerDocument && r.ownerDocument.defaultView || window).getSelection(), r = { anchorNode: r.anchorNode, anchorOffset: r.anchorOffset, focusNode: r.focusNode, focusOffset: r.focusOffset }), Pn && $n(Pn, r) || (Pn = r, r = Ur(co, "onSelect"), 0 < r.length && (t = new ei("onSelect", "select", null, t, n), e.push({ event: t, listeners: r }), t.target = Ft)));
}
function cr(e, t) {
  var n = {};
  return n[e.toLowerCase()] = t.toLowerCase(), n["Webkit" + e] = "webkit" + t, n["Moz" + e] = "moz" + t, n;
}
var Ut = { animationend: cr("Animation", "AnimationEnd"), animationiteration: cr("Animation", "AnimationIteration"), animationstart: cr("Animation", "AnimationStart"), transitionend: cr("Transition", "TransitionEnd") }, Tl = {}, As = {};
Qe && (As = document.createElement("div").style, "AnimationEvent" in window || (delete Ut.animationend.animation, delete Ut.animationiteration.animation, delete Ut.animationstart.animation), "TransitionEvent" in window || delete Ut.transitionend.transition);
function ll(e) {
  if (Tl[e]) return Tl[e];
  if (!Ut[e]) return e;
  var t = Ut[e], n;
  for (n in t) if (t.hasOwnProperty(n) && n in As) return Tl[e] = t[n];
  return e;
}
var Bs = ll("animationend"), Ws = ll("animationiteration"), Hs = ll("animationstart"), Qs = ll("transitionend"), Ks = /* @__PURE__ */ new Map(), iu = "abort auxClick cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");
function pt(e, t) {
  Ks.set(e, t), Tt(t, [e]);
}
for (var Ml = 0; Ml < iu.length; Ml++) {
  var Rl = iu[Ml], Of = Rl.toLowerCase(), jf = Rl[0].toUpperCase() + Rl.slice(1);
  pt(Of, "on" + jf);
}
pt(Bs, "onAnimationEnd");
pt(Ws, "onAnimationIteration");
pt(Hs, "onAnimationStart");
pt("dblclick", "onDoubleClick");
pt("focusin", "onFocus");
pt("focusout", "onBlur");
pt(Qs, "onTransitionEnd");
qt("onMouseEnter", ["mouseout", "mouseover"]);
qt("onMouseLeave", ["mouseout", "mouseover"]);
qt("onPointerEnter", ["pointerout", "pointerover"]);
qt("onPointerLeave", ["pointerout", "pointerover"]);
Tt("onChange", "change click focusin focusout input keydown keyup selectionchange".split(" "));
Tt("onSelect", "focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" "));
Tt("onBeforeInput", ["compositionend", "keypress", "textInput", "paste"]);
Tt("onCompositionEnd", "compositionend focusout keydown keypress keyup mousedown".split(" "));
Tt("onCompositionStart", "compositionstart focusout keydown keypress keyup mousedown".split(" "));
Tt("onCompositionUpdate", "compositionupdate focusout keydown keypress keyup mousedown".split(" "));
var En = "abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "), If = new Set("cancel close invalid load scroll toggle".split(" ").concat(En));
function uu(e, t, n) {
  var r = e.type || "unknown-event";
  e.currentTarget = n, Dc(r, t, void 0, e), e.currentTarget = null;
}
function Ys(e, t) {
  t = (t & 4) !== 0;
  for (var n = 0; n < e.length; n++) {
    var r = e[n], l = r.event;
    r = r.listeners;
    e: {
      var o = void 0;
      if (t) for (var i = r.length - 1; 0 <= i; i--) {
        var u = r[i], s = u.instance, f = u.currentTarget;
        if (u = u.listener, s !== o && l.isPropagationStopped()) break e;
        uu(l, u, f), o = s;
      }
      else for (i = 0; i < r.length; i++) {
        if (u = r[i], s = u.instance, f = u.currentTarget, u = u.listener, s !== o && l.isPropagationStopped()) break e;
        uu(l, u, f), o = s;
      }
    }
  }
  if (Dr) throw e = io, Dr = !1, io = null, e;
}
function I(e, t) {
  var n = t[yo];
  n === void 0 && (n = t[yo] = /* @__PURE__ */ new Set());
  var r = e + "__bubble";
  n.has(r) || (Xs(t, e, 2, !1), n.add(r));
}
function Dl(e, t, n) {
  var r = 0;
  t && (r |= 4), Xs(n, e, r, t);
}
var fr = "_reactListening" + Math.random().toString(36).slice(2);
function Vn(e) {
  if (!e[fr]) {
    e[fr] = !0, ts.forEach(function(n) {
      n !== "selectionchange" && (If.has(n) || Dl(n, !1, e), Dl(n, !0, e));
    });
    var t = e.nodeType === 9 ? e : e.ownerDocument;
    t === null || t[fr] || (t[fr] = !0, Dl("selectionchange", !1, t));
  }
}
function Xs(e, t, n, r) {
  switch (Ms(t)) {
    case 1:
      var l = Gc;
      break;
    case 4:
      l = Zc;
      break;
    default:
      l = qo;
  }
  n = l.bind(null, t, n, e), l = void 0, !oo || t !== "touchstart" && t !== "touchmove" && t !== "wheel" || (l = !0), r ? l !== void 0 ? e.addEventListener(t, n, { capture: !0, passive: l }) : e.addEventListener(t, n, !0) : l !== void 0 ? e.addEventListener(t, n, { passive: l }) : e.addEventListener(t, n, !1);
}
function Ol(e, t, n, r, l) {
  var o = r;
  if (!(t & 1) && !(t & 2) && r !== null) e: for (; ; ) {
    if (r === null) return;
    var i = r.tag;
    if (i === 3 || i === 4) {
      var u = r.stateNode.containerInfo;
      if (u === l || u.nodeType === 8 && u.parentNode === l) break;
      if (i === 4) for (i = r.return; i !== null; ) {
        var s = i.tag;
        if ((s === 3 || s === 4) && (s = i.stateNode.containerInfo, s === l || s.nodeType === 8 && s.parentNode === l)) return;
        i = i.return;
      }
      for (; u !== null; ) {
        if (i = St(u), i === null) return;
        if (s = i.tag, s === 5 || s === 6) {
          r = o = i;
          continue e;
        }
        u = u.parentNode;
      }
    }
    r = r.return;
  }
  ys(function() {
    var f = o, v = Xo(n), m = [];
    e: {
      var p = Ks.get(e);
      if (p !== void 0) {
        var w = ei, S = e;
        switch (e) {
          case "keypress":
            if (xr(n) === 0) break e;
          case "keydown":
          case "keyup":
            w = df;
            break;
          case "focusin":
            S = "focus", w = Pl;
            break;
          case "focusout":
            S = "blur", w = Pl;
            break;
          case "beforeblur":
          case "afterblur":
            w = Pl;
            break;
          case "click":
            if (n.button === 2) break e;
          case "auxclick":
          case "dblclick":
          case "mousedown":
          case "mousemove":
          case "mouseup":
          case "mouseout":
          case "mouseover":
          case "contextmenu":
            w = Gi;
            break;
          case "drag":
          case "dragend":
          case "dragenter":
          case "dragexit":
          case "dragleave":
          case "dragover":
          case "dragstart":
          case "drop":
            w = bc;
            break;
          case "touchcancel":
          case "touchend":
          case "touchmove":
          case "touchstart":
            w = vf;
            break;
          case Bs:
          case Ws:
          case Hs:
            w = nf;
            break;
          case Qs:
            w = yf;
            break;
          case "scroll":
            w = Jc;
            break;
          case "wheel":
            w = wf;
            break;
          case "copy":
          case "cut":
          case "paste":
            w = lf;
            break;
          case "gotpointercapture":
          case "lostpointercapture":
          case "pointercancel":
          case "pointerdown":
          case "pointermove":
          case "pointerout":
          case "pointerover":
          case "pointerup":
            w = Ji;
        }
        var g = (t & 4) !== 0, D = !g && e === "scroll", c = g ? p !== null ? p + "Capture" : null : p;
        g = [];
        for (var a = f, d; a !== null; ) {
          d = a;
          var h = d.stateNode;
          if (d.tag === 5 && h !== null && (d = h, c !== null && (h = On(a, c), h != null && g.push(An(a, h, d)))), D) break;
          a = a.return;
        }
        0 < g.length && (p = new w(p, S, null, n, v), m.push({ event: p, listeners: g }));
      }
    }
    if (!(t & 7)) {
      e: {
        if (p = e === "mouseover" || e === "pointerover", w = e === "mouseout" || e === "pointerout", p && n !== ro && (S = n.relatedTarget || n.fromElement) && (St(S) || S[Ke])) break e;
        if ((w || p) && (p = v.window === v ? v : (p = v.ownerDocument) ? p.defaultView || p.parentWindow : window, w ? (S = n.relatedTarget || n.toElement, w = f, S = S ? St(S) : null, S !== null && (D = Mt(S), S !== D || S.tag !== 5 && S.tag !== 6) && (S = null)) : (w = null, S = f), w !== S)) {
          if (g = Gi, h = "onMouseLeave", c = "onMouseEnter", a = "mouse", (e === "pointerout" || e === "pointerover") && (g = Ji, h = "onPointerLeave", c = "onPointerEnter", a = "pointer"), D = w == null ? p : $t(w), d = S == null ? p : $t(S), p = new g(h, a + "leave", w, n, v), p.target = D, p.relatedTarget = d, h = null, St(v) === f && (g = new g(c, a + "enter", S, n, v), g.target = d, g.relatedTarget = D, h = g), D = h, w && S) t: {
            for (g = w, c = S, a = 0, d = g; d; d = Rt(d)) a++;
            for (d = 0, h = c; h; h = Rt(h)) d++;
            for (; 0 < a - d; ) g = Rt(g), a--;
            for (; 0 < d - a; ) c = Rt(c), d--;
            for (; a--; ) {
              if (g === c || c !== null && g === c.alternate) break t;
              g = Rt(g), c = Rt(c);
            }
            g = null;
          }
          else g = null;
          w !== null && su(m, p, w, g, !1), S !== null && D !== null && su(m, D, S, g, !0);
        }
      }
      e: {
        if (p = f ? $t(f) : window, w = p.nodeName && p.nodeName.toLowerCase(), w === "select" || w === "input" && p.type === "file") var E = _f;
        else if (eu(p)) if (Fs) E = Tf;
        else {
          E = zf;
          var N = Pf;
        }
        else (w = p.nodeName) && w.toLowerCase() === "input" && (p.type === "checkbox" || p.type === "radio") && (E = Lf);
        if (E && (E = E(e, f))) {
          Is(m, E, n, v);
          break e;
        }
        N && N(e, p, f), e === "focusout" && (N = p._wrapperState) && N.controlled && p.type === "number" && ql(p, "number", p.value);
      }
      switch (N = f ? $t(f) : window, e) {
        case "focusin":
          (eu(N) || N.contentEditable === "true") && (Ft = N, co = f, Pn = null);
          break;
        case "focusout":
          Pn = co = Ft = null;
          break;
        case "mousedown":
          fo = !0;
          break;
        case "contextmenu":
        case "mouseup":
        case "dragend":
          fo = !1, ou(m, n, v);
          break;
        case "selectionchange":
          if (Df) break;
        case "keydown":
        case "keyup":
          ou(m, n, v);
      }
      var _;
      if (ni) e: {
        switch (e) {
          case "compositionstart":
            var P = "onCompositionStart";
            break e;
          case "compositionend":
            P = "onCompositionEnd";
            break e;
          case "compositionupdate":
            P = "onCompositionUpdate";
            break e;
        }
        P = void 0;
      }
      else It ? Os(e, n) && (P = "onCompositionEnd") : e === "keydown" && n.keyCode === 229 && (P = "onCompositionStart");
      P && (Ds && n.locale !== "ko" && (It || P !== "onCompositionStart" ? P === "onCompositionEnd" && It && (_ = Rs()) : (tt = v, bo = "value" in tt ? tt.value : tt.textContent, It = !0)), N = Ur(f, P), 0 < N.length && (P = new Zi(P, e, null, n, v), m.push({ event: P, listeners: N }), _ ? P.data = _ : (_ = js(n), _ !== null && (P.data = _)))), (_ = kf ? Ef(e, n) : xf(e, n)) && (f = Ur(f, "onBeforeInput"), 0 < f.length && (v = new Zi("onBeforeInput", "beforeinput", null, n, v), m.push({ event: v, listeners: f }), v.data = _));
    }
    Ys(m, t);
  });
}
function An(e, t, n) {
  return { instance: e, listener: t, currentTarget: n };
}
function Ur(e, t) {
  for (var n = t + "Capture", r = []; e !== null; ) {
    var l = e, o = l.stateNode;
    l.tag === 5 && o !== null && (l = o, o = On(e, n), o != null && r.unshift(An(e, o, l)), o = On(e, t), o != null && r.push(An(e, o, l))), e = e.return;
  }
  return r;
}
function Rt(e) {
  if (e === null) return null;
  do
    e = e.return;
  while (e && e.tag !== 5);
  return e || null;
}
function su(e, t, n, r, l) {
  for (var o = t._reactName, i = []; n !== null && n !== r; ) {
    var u = n, s = u.alternate, f = u.stateNode;
    if (s !== null && s === r) break;
    u.tag === 5 && f !== null && (u = f, l ? (s = On(n, o), s != null && i.unshift(An(n, s, u))) : l || (s = On(n, o), s != null && i.push(An(n, s, u)))), n = n.return;
  }
  i.length !== 0 && e.push({ event: t, listeners: i });
}
var Ff = /\r\n?/g, Uf = /\u0000|\uFFFD/g;
function au(e) {
  return (typeof e == "string" ? e : "" + e).replace(Ff, `
`).replace(Uf, "");
}
function dr(e, t, n) {
  if (t = au(t), au(e) !== t && n) throw Error(y(425));
}
function $r() {
}
var po = null, mo = null;
function vo(e, t) {
  return e === "textarea" || e === "noscript" || typeof t.children == "string" || typeof t.children == "number" || typeof t.dangerouslySetInnerHTML == "object" && t.dangerouslySetInnerHTML !== null && t.dangerouslySetInnerHTML.__html != null;
}
var ho = typeof setTimeout == "function" ? setTimeout : void 0, $f = typeof clearTimeout == "function" ? clearTimeout : void 0, cu = typeof Promise == "function" ? Promise : void 0, Vf = typeof queueMicrotask == "function" ? queueMicrotask : typeof cu < "u" ? function(e) {
  return cu.resolve(null).then(e).catch(Af);
} : ho;
function Af(e) {
  setTimeout(function() {
    throw e;
  });
}
function jl(e, t) {
  var n = t, r = 0;
  do {
    var l = n.nextSibling;
    if (e.removeChild(n), l && l.nodeType === 8) if (n = l.data, n === "/$") {
      if (r === 0) {
        e.removeChild(l), Fn(t);
        return;
      }
      r--;
    } else n !== "$" && n !== "$?" && n !== "$!" || r++;
    n = l;
  } while (n);
  Fn(t);
}
function it(e) {
  for (; e != null; e = e.nextSibling) {
    var t = e.nodeType;
    if (t === 1 || t === 3) break;
    if (t === 8) {
      if (t = e.data, t === "$" || t === "$!" || t === "$?") break;
      if (t === "/$") return null;
    }
  }
  return e;
}
function fu(e) {
  e = e.previousSibling;
  for (var t = 0; e; ) {
    if (e.nodeType === 8) {
      var n = e.data;
      if (n === "$" || n === "$!" || n === "$?") {
        if (t === 0) return e;
        t--;
      } else n === "/$" && t++;
    }
    e = e.previousSibling;
  }
  return null;
}
var sn = Math.random().toString(36).slice(2), Fe = "__reactFiber$" + sn, Bn = "__reactProps$" + sn, Ke = "__reactContainer$" + sn, yo = "__reactEvents$" + sn, Bf = "__reactListeners$" + sn, Wf = "__reactHandles$" + sn;
function St(e) {
  var t = e[Fe];
  if (t) return t;
  for (var n = e.parentNode; n; ) {
    if (t = n[Ke] || n[Fe]) {
      if (n = t.alternate, t.child !== null || n !== null && n.child !== null) for (e = fu(e); e !== null; ) {
        if (n = e[Fe]) return n;
        e = fu(e);
      }
      return t;
    }
    e = n, n = e.parentNode;
  }
  return null;
}
function qn(e) {
  return e = e[Fe] || e[Ke], !e || e.tag !== 5 && e.tag !== 6 && e.tag !== 13 && e.tag !== 3 ? null : e;
}
function $t(e) {
  if (e.tag === 5 || e.tag === 6) return e.stateNode;
  throw Error(y(33));
}
function ol(e) {
  return e[Bn] || null;
}
var go = [], Vt = -1;
function mt(e) {
  return { current: e };
}
function F(e) {
  0 > Vt || (e.current = go[Vt], go[Vt] = null, Vt--);
}
function j(e, t) {
  Vt++, go[Vt] = e.current, e.current = t;
}
var dt = {}, oe = mt(dt), de = mt(!1), Nt = dt;
function bt(e, t) {
  var n = e.type.contextTypes;
  if (!n) return dt;
  var r = e.stateNode;
  if (r && r.__reactInternalMemoizedUnmaskedChildContext === t) return r.__reactInternalMemoizedMaskedChildContext;
  var l = {}, o;
  for (o in n) l[o] = t[o];
  return r && (e = e.stateNode, e.__reactInternalMemoizedUnmaskedChildContext = t, e.__reactInternalMemoizedMaskedChildContext = l), l;
}
function pe(e) {
  return e = e.childContextTypes, e != null;
}
function Vr() {
  F(de), F(oe);
}
function du(e, t, n) {
  if (oe.current !== dt) throw Error(y(168));
  j(oe, t), j(de, n);
}
function Gs(e, t, n) {
  var r = e.stateNode;
  if (t = t.childContextTypes, typeof r.getChildContext != "function") return n;
  r = r.getChildContext();
  for (var l in r) if (!(l in t)) throw Error(y(108, _c(e) || "Unknown", l));
  return A({}, n, r);
}
function Ar(e) {
  return e = (e = e.stateNode) && e.__reactInternalMemoizedMergedChildContext || dt, Nt = oe.current, j(oe, e), j(de, de.current), !0;
}
function pu(e, t, n) {
  var r = e.stateNode;
  if (!r) throw Error(y(169));
  n ? (e = Gs(e, t, Nt), r.__reactInternalMemoizedMergedChildContext = e, F(de), F(oe), j(oe, e)) : F(de), j(de, n);
}
var Ae = null, il = !1, Il = !1;
function Zs(e) {
  Ae === null ? Ae = [e] : Ae.push(e);
}
function Hf(e) {
  il = !0, Zs(e);
}
function vt() {
  if (!Il && Ae !== null) {
    Il = !0;
    var e = 0, t = O;
    try {
      var n = Ae;
      for (O = 1; e < n.length; e++) {
        var r = n[e];
        do
          r = r(!0);
        while (r !== null);
      }
      Ae = null, il = !1;
    } catch (l) {
      throw Ae !== null && (Ae = Ae.slice(e + 1)), ks(Go, vt), l;
    } finally {
      O = t, Il = !1;
    }
  }
  return null;
}
var At = [], Bt = 0, Br = null, Wr = 0, ke = [], Ee = 0, _t = null, Be = 1, We = "";
function gt(e, t) {
  At[Bt++] = Wr, At[Bt++] = Br, Br = e, Wr = t;
}
function Js(e, t, n) {
  ke[Ee++] = Be, ke[Ee++] = We, ke[Ee++] = _t, _t = e;
  var r = Be;
  e = We;
  var l = 32 - Re(r) - 1;
  r &= ~(1 << l), n += 1;
  var o = 32 - Re(t) + l;
  if (30 < o) {
    var i = l - l % 5;
    o = (r & (1 << i) - 1).toString(32), r >>= i, l -= i, Be = 1 << 32 - Re(t) + l | n << l | r, We = o + e;
  } else Be = 1 << o | n << l | r, We = e;
}
function li(e) {
  e.return !== null && (gt(e, 1), Js(e, 1, 0));
}
function oi(e) {
  for (; e === Br; ) Br = At[--Bt], At[Bt] = null, Wr = At[--Bt], At[Bt] = null;
  for (; e === _t; ) _t = ke[--Ee], ke[Ee] = null, We = ke[--Ee], ke[Ee] = null, Be = ke[--Ee], ke[Ee] = null;
}
var ye = null, he = null, U = !1, Me = null;
function qs(e, t) {
  var n = xe(5, null, null, 0);
  n.elementType = "DELETED", n.stateNode = t, n.return = e, t = e.deletions, t === null ? (e.deletions = [n], e.flags |= 16) : t.push(n);
}
function mu(e, t) {
  switch (e.tag) {
    case 5:
      var n = e.type;
      return t = t.nodeType !== 1 || n.toLowerCase() !== t.nodeName.toLowerCase() ? null : t, t !== null ? (e.stateNode = t, ye = e, he = it(t.firstChild), !0) : !1;
    case 6:
      return t = e.pendingProps === "" || t.nodeType !== 3 ? null : t, t !== null ? (e.stateNode = t, ye = e, he = null, !0) : !1;
    case 13:
      return t = t.nodeType !== 8 ? null : t, t !== null ? (n = _t !== null ? { id: Be, overflow: We } : null, e.memoizedState = { dehydrated: t, treeContext: n, retryLane: 1073741824 }, n = xe(18, null, null, 0), n.stateNode = t, n.return = e, e.child = n, ye = e, he = null, !0) : !1;
    default:
      return !1;
  }
}
function wo(e) {
  return (e.mode & 1) !== 0 && (e.flags & 128) === 0;
}
function So(e) {
  if (U) {
    var t = he;
    if (t) {
      var n = t;
      if (!mu(e, t)) {
        if (wo(e)) throw Error(y(418));
        t = it(n.nextSibling);
        var r = ye;
        t && mu(e, t) ? qs(r, n) : (e.flags = e.flags & -4097 | 2, U = !1, ye = e);
      }
    } else {
      if (wo(e)) throw Error(y(418));
      e.flags = e.flags & -4097 | 2, U = !1, ye = e;
    }
  }
}
function vu(e) {
  for (e = e.return; e !== null && e.tag !== 5 && e.tag !== 3 && e.tag !== 13; ) e = e.return;
  ye = e;
}
function pr(e) {
  if (e !== ye) return !1;
  if (!U) return vu(e), U = !0, !1;
  var t;
  if ((t = e.tag !== 3) && !(t = e.tag !== 5) && (t = e.type, t = t !== "head" && t !== "body" && !vo(e.type, e.memoizedProps)), t && (t = he)) {
    if (wo(e)) throw bs(), Error(y(418));
    for (; t; ) qs(e, t), t = it(t.nextSibling);
  }
  if (vu(e), e.tag === 13) {
    if (e = e.memoizedState, e = e !== null ? e.dehydrated : null, !e) throw Error(y(317));
    e: {
      for (e = e.nextSibling, t = 0; e; ) {
        if (e.nodeType === 8) {
          var n = e.data;
          if (n === "/$") {
            if (t === 0) {
              he = it(e.nextSibling);
              break e;
            }
            t--;
          } else n !== "$" && n !== "$!" && n !== "$?" || t++;
        }
        e = e.nextSibling;
      }
      he = null;
    }
  } else he = ye ? it(e.stateNode.nextSibling) : null;
  return !0;
}
function bs() {
  for (var e = he; e; ) e = it(e.nextSibling);
}
function en() {
  he = ye = null, U = !1;
}
function ii(e) {
  Me === null ? Me = [e] : Me.push(e);
}
var Qf = Ge.ReactCurrentBatchConfig;
function hn(e, t, n) {
  if (e = n.ref, e !== null && typeof e != "function" && typeof e != "object") {
    if (n._owner) {
      if (n = n._owner, n) {
        if (n.tag !== 1) throw Error(y(309));
        var r = n.stateNode;
      }
      if (!r) throw Error(y(147, e));
      var l = r, o = "" + e;
      return t !== null && t.ref !== null && typeof t.ref == "function" && t.ref._stringRef === o ? t.ref : (t = function(i) {
        var u = l.refs;
        i === null ? delete u[o] : u[o] = i;
      }, t._stringRef = o, t);
    }
    if (typeof e != "string") throw Error(y(284));
    if (!n._owner) throw Error(y(290, e));
  }
  return e;
}
function mr(e, t) {
  throw e = Object.prototype.toString.call(t), Error(y(31, e === "[object Object]" ? "object with keys {" + Object.keys(t).join(", ") + "}" : e));
}
function hu(e) {
  var t = e._init;
  return t(e._payload);
}
function ea(e) {
  function t(c, a) {
    if (e) {
      var d = c.deletions;
      d === null ? (c.deletions = [a], c.flags |= 16) : d.push(a);
    }
  }
  function n(c, a) {
    if (!e) return null;
    for (; a !== null; ) t(c, a), a = a.sibling;
    return null;
  }
  function r(c, a) {
    for (c = /* @__PURE__ */ new Map(); a !== null; ) a.key !== null ? c.set(a.key, a) : c.set(a.index, a), a = a.sibling;
    return c;
  }
  function l(c, a) {
    return c = ct(c, a), c.index = 0, c.sibling = null, c;
  }
  function o(c, a, d) {
    return c.index = d, e ? (d = c.alternate, d !== null ? (d = d.index, d < a ? (c.flags |= 2, a) : d) : (c.flags |= 2, a)) : (c.flags |= 1048576, a);
  }
  function i(c) {
    return e && c.alternate === null && (c.flags |= 2), c;
  }
  function u(c, a, d, h) {
    return a === null || a.tag !== 6 ? (a = Wl(d, c.mode, h), a.return = c, a) : (a = l(a, d), a.return = c, a);
  }
  function s(c, a, d, h) {
    var E = d.type;
    return E === jt ? v(c, a, d.props.children, h, d.key) : a !== null && (a.elementType === E || typeof E == "object" && E !== null && E.$$typeof === Je && hu(E) === a.type) ? (h = l(a, d.props), h.ref = hn(c, a, d), h.return = c, h) : (h = Tr(d.type, d.key, d.props, null, c.mode, h), h.ref = hn(c, a, d), h.return = c, h);
  }
  function f(c, a, d, h) {
    return a === null || a.tag !== 4 || a.stateNode.containerInfo !== d.containerInfo || a.stateNode.implementation !== d.implementation ? (a = Hl(d, c.mode, h), a.return = c, a) : (a = l(a, d.children || []), a.return = c, a);
  }
  function v(c, a, d, h, E) {
    return a === null || a.tag !== 7 ? (a = Ct(d, c.mode, h, E), a.return = c, a) : (a = l(a, d), a.return = c, a);
  }
  function m(c, a, d) {
    if (typeof a == "string" && a !== "" || typeof a == "number") return a = Wl("" + a, c.mode, d), a.return = c, a;
    if (typeof a == "object" && a !== null) {
      switch (a.$$typeof) {
        case rr:
          return d = Tr(a.type, a.key, a.props, null, c.mode, d), d.ref = hn(c, null, a), d.return = c, d;
        case Ot:
          return a = Hl(a, c.mode, d), a.return = c, a;
        case Je:
          var h = a._init;
          return m(c, h(a._payload), d);
      }
      if (Sn(a) || fn(a)) return a = Ct(a, c.mode, d, null), a.return = c, a;
      mr(c, a);
    }
    return null;
  }
  function p(c, a, d, h) {
    var E = a !== null ? a.key : null;
    if (typeof d == "string" && d !== "" || typeof d == "number") return E !== null ? null : u(c, a, "" + d, h);
    if (typeof d == "object" && d !== null) {
      switch (d.$$typeof) {
        case rr:
          return d.key === E ? s(c, a, d, h) : null;
        case Ot:
          return d.key === E ? f(c, a, d, h) : null;
        case Je:
          return E = d._init, p(
            c,
            a,
            E(d._payload),
            h
          );
      }
      if (Sn(d) || fn(d)) return E !== null ? null : v(c, a, d, h, null);
      mr(c, d);
    }
    return null;
  }
  function w(c, a, d, h, E) {
    if (typeof h == "string" && h !== "" || typeof h == "number") return c = c.get(d) || null, u(a, c, "" + h, E);
    if (typeof h == "object" && h !== null) {
      switch (h.$$typeof) {
        case rr:
          return c = c.get(h.key === null ? d : h.key) || null, s(a, c, h, E);
        case Ot:
          return c = c.get(h.key === null ? d : h.key) || null, f(a, c, h, E);
        case Je:
          var N = h._init;
          return w(c, a, d, N(h._payload), E);
      }
      if (Sn(h) || fn(h)) return c = c.get(d) || null, v(a, c, h, E, null);
      mr(a, h);
    }
    return null;
  }
  function S(c, a, d, h) {
    for (var E = null, N = null, _ = a, P = a = 0, W = null; _ !== null && P < d.length; P++) {
      _.index > P ? (W = _, _ = null) : W = _.sibling;
      var M = p(c, _, d[P], h);
      if (M === null) {
        _ === null && (_ = W);
        break;
      }
      e && _ && M.alternate === null && t(c, _), a = o(M, a, P), N === null ? E = M : N.sibling = M, N = M, _ = W;
    }
    if (P === d.length) return n(c, _), U && gt(c, P), E;
    if (_ === null) {
      for (; P < d.length; P++) _ = m(c, d[P], h), _ !== null && (a = o(_, a, P), N === null ? E = _ : N.sibling = _, N = _);
      return U && gt(c, P), E;
    }
    for (_ = r(c, _); P < d.length; P++) W = w(_, c, P, d[P], h), W !== null && (e && W.alternate !== null && _.delete(W.key === null ? P : W.key), a = o(W, a, P), N === null ? E = W : N.sibling = W, N = W);
    return e && _.forEach(function(Pe) {
      return t(c, Pe);
    }), U && gt(c, P), E;
  }
  function g(c, a, d, h) {
    var E = fn(d);
    if (typeof E != "function") throw Error(y(150));
    if (d = E.call(d), d == null) throw Error(y(151));
    for (var N = E = null, _ = a, P = a = 0, W = null, M = d.next(); _ !== null && !M.done; P++, M = d.next()) {
      _.index > P ? (W = _, _ = null) : W = _.sibling;
      var Pe = p(c, _, M.value, h);
      if (Pe === null) {
        _ === null && (_ = W);
        break;
      }
      e && _ && Pe.alternate === null && t(c, _), a = o(Pe, a, P), N === null ? E = Pe : N.sibling = Pe, N = Pe, _ = W;
    }
    if (M.done) return n(
      c,
      _
    ), U && gt(c, P), E;
    if (_ === null) {
      for (; !M.done; P++, M = d.next()) M = m(c, M.value, h), M !== null && (a = o(M, a, P), N === null ? E = M : N.sibling = M, N = M);
      return U && gt(c, P), E;
    }
    for (_ = r(c, _); !M.done; P++, M = d.next()) M = w(_, c, P, M.value, h), M !== null && (e && M.alternate !== null && _.delete(M.key === null ? P : M.key), a = o(M, a, P), N === null ? E = M : N.sibling = M, N = M);
    return e && _.forEach(function(an) {
      return t(c, an);
    }), U && gt(c, P), E;
  }
  function D(c, a, d, h) {
    if (typeof d == "object" && d !== null && d.type === jt && d.key === null && (d = d.props.children), typeof d == "object" && d !== null) {
      switch (d.$$typeof) {
        case rr:
          e: {
            for (var E = d.key, N = a; N !== null; ) {
              if (N.key === E) {
                if (E = d.type, E === jt) {
                  if (N.tag === 7) {
                    n(c, N.sibling), a = l(N, d.props.children), a.return = c, c = a;
                    break e;
                  }
                } else if (N.elementType === E || typeof E == "object" && E !== null && E.$$typeof === Je && hu(E) === N.type) {
                  n(c, N.sibling), a = l(N, d.props), a.ref = hn(c, N, d), a.return = c, c = a;
                  break e;
                }
                n(c, N);
                break;
              } else t(c, N);
              N = N.sibling;
            }
            d.type === jt ? (a = Ct(d.props.children, c.mode, h, d.key), a.return = c, c = a) : (h = Tr(d.type, d.key, d.props, null, c.mode, h), h.ref = hn(c, a, d), h.return = c, c = h);
          }
          return i(c);
        case Ot:
          e: {
            for (N = d.key; a !== null; ) {
              if (a.key === N) if (a.tag === 4 && a.stateNode.containerInfo === d.containerInfo && a.stateNode.implementation === d.implementation) {
                n(c, a.sibling), a = l(a, d.children || []), a.return = c, c = a;
                break e;
              } else {
                n(c, a);
                break;
              }
              else t(c, a);
              a = a.sibling;
            }
            a = Hl(d, c.mode, h), a.return = c, c = a;
          }
          return i(c);
        case Je:
          return N = d._init, D(c, a, N(d._payload), h);
      }
      if (Sn(d)) return S(c, a, d, h);
      if (fn(d)) return g(c, a, d, h);
      mr(c, d);
    }
    return typeof d == "string" && d !== "" || typeof d == "number" ? (d = "" + d, a !== null && a.tag === 6 ? (n(c, a.sibling), a = l(a, d), a.return = c, c = a) : (n(c, a), a = Wl(d, c.mode, h), a.return = c, c = a), i(c)) : n(c, a);
  }
  return D;
}
var tn = ea(!0), ta = ea(!1), Hr = mt(null), Qr = null, Wt = null, ui = null;
function si() {
  ui = Wt = Qr = null;
}
function ai(e) {
  var t = Hr.current;
  F(Hr), e._currentValue = t;
}
function ko(e, t, n) {
  for (; e !== null; ) {
    var r = e.alternate;
    if ((e.childLanes & t) !== t ? (e.childLanes |= t, r !== null && (r.childLanes |= t)) : r !== null && (r.childLanes & t) !== t && (r.childLanes |= t), e === n) break;
    e = e.return;
  }
}
function Zt(e, t) {
  Qr = e, ui = Wt = null, e = e.dependencies, e !== null && e.firstContext !== null && (e.lanes & t && (fe = !0), e.firstContext = null);
}
function Ne(e) {
  var t = e._currentValue;
  if (ui !== e) if (e = { context: e, memoizedValue: t, next: null }, Wt === null) {
    if (Qr === null) throw Error(y(308));
    Wt = e, Qr.dependencies = { lanes: 0, firstContext: e };
  } else Wt = Wt.next = e;
  return t;
}
var kt = null;
function ci(e) {
  kt === null ? kt = [e] : kt.push(e);
}
function na(e, t, n, r) {
  var l = t.interleaved;
  return l === null ? (n.next = n, ci(t)) : (n.next = l.next, l.next = n), t.interleaved = n, Ye(e, r);
}
function Ye(e, t) {
  e.lanes |= t;
  var n = e.alternate;
  for (n !== null && (n.lanes |= t), n = e, e = e.return; e !== null; ) e.childLanes |= t, n = e.alternate, n !== null && (n.childLanes |= t), n = e, e = e.return;
  return n.tag === 3 ? n.stateNode : null;
}
var qe = !1;
function fi(e) {
  e.updateQueue = { baseState: e.memoizedState, firstBaseUpdate: null, lastBaseUpdate: null, shared: { pending: null, interleaved: null, lanes: 0 }, effects: null };
}
function ra(e, t) {
  e = e.updateQueue, t.updateQueue === e && (t.updateQueue = { baseState: e.baseState, firstBaseUpdate: e.firstBaseUpdate, lastBaseUpdate: e.lastBaseUpdate, shared: e.shared, effects: e.effects });
}
function He(e, t) {
  return { eventTime: e, lane: t, tag: 0, payload: null, callback: null, next: null };
}
function ut(e, t, n) {
  var r = e.updateQueue;
  if (r === null) return null;
  if (r = r.shared, R & 2) {
    var l = r.pending;
    return l === null ? t.next = t : (t.next = l.next, l.next = t), r.pending = t, Ye(e, n);
  }
  return l = r.interleaved, l === null ? (t.next = t, ci(r)) : (t.next = l.next, l.next = t), r.interleaved = t, Ye(e, n);
}
function Cr(e, t, n) {
  if (t = t.updateQueue, t !== null && (t = t.shared, (n & 4194240) !== 0)) {
    var r = t.lanes;
    r &= e.pendingLanes, n |= r, t.lanes = n, Zo(e, n);
  }
}
function yu(e, t) {
  var n = e.updateQueue, r = e.alternate;
  if (r !== null && (r = r.updateQueue, n === r)) {
    var l = null, o = null;
    if (n = n.firstBaseUpdate, n !== null) {
      do {
        var i = { eventTime: n.eventTime, lane: n.lane, tag: n.tag, payload: n.payload, callback: n.callback, next: null };
        o === null ? l = o = i : o = o.next = i, n = n.next;
      } while (n !== null);
      o === null ? l = o = t : o = o.next = t;
    } else l = o = t;
    n = { baseState: r.baseState, firstBaseUpdate: l, lastBaseUpdate: o, shared: r.shared, effects: r.effects }, e.updateQueue = n;
    return;
  }
  e = n.lastBaseUpdate, e === null ? n.firstBaseUpdate = t : e.next = t, n.lastBaseUpdate = t;
}
function Kr(e, t, n, r) {
  var l = e.updateQueue;
  qe = !1;
  var o = l.firstBaseUpdate, i = l.lastBaseUpdate, u = l.shared.pending;
  if (u !== null) {
    l.shared.pending = null;
    var s = u, f = s.next;
    s.next = null, i === null ? o = f : i.next = f, i = s;
    var v = e.alternate;
    v !== null && (v = v.updateQueue, u = v.lastBaseUpdate, u !== i && (u === null ? v.firstBaseUpdate = f : u.next = f, v.lastBaseUpdate = s));
  }
  if (o !== null) {
    var m = l.baseState;
    i = 0, v = f = s = null, u = o;
    do {
      var p = u.lane, w = u.eventTime;
      if ((r & p) === p) {
        v !== null && (v = v.next = {
          eventTime: w,
          lane: 0,
          tag: u.tag,
          payload: u.payload,
          callback: u.callback,
          next: null
        });
        e: {
          var S = e, g = u;
          switch (p = t, w = n, g.tag) {
            case 1:
              if (S = g.payload, typeof S == "function") {
                m = S.call(w, m, p);
                break e;
              }
              m = S;
              break e;
            case 3:
              S.flags = S.flags & -65537 | 128;
            case 0:
              if (S = g.payload, p = typeof S == "function" ? S.call(w, m, p) : S, p == null) break e;
              m = A({}, m, p);
              break e;
            case 2:
              qe = !0;
          }
        }
        u.callback !== null && u.lane !== 0 && (e.flags |= 64, p = l.effects, p === null ? l.effects = [u] : p.push(u));
      } else w = { eventTime: w, lane: p, tag: u.tag, payload: u.payload, callback: u.callback, next: null }, v === null ? (f = v = w, s = m) : v = v.next = w, i |= p;
      if (u = u.next, u === null) {
        if (u = l.shared.pending, u === null) break;
        p = u, u = p.next, p.next = null, l.lastBaseUpdate = p, l.shared.pending = null;
      }
    } while (!0);
    if (v === null && (s = m), l.baseState = s, l.firstBaseUpdate = f, l.lastBaseUpdate = v, t = l.shared.interleaved, t !== null) {
      l = t;
      do
        i |= l.lane, l = l.next;
      while (l !== t);
    } else o === null && (l.shared.lanes = 0);
    zt |= i, e.lanes = i, e.memoizedState = m;
  }
}
function gu(e, t, n) {
  if (e = t.effects, t.effects = null, e !== null) for (t = 0; t < e.length; t++) {
    var r = e[t], l = r.callback;
    if (l !== null) {
      if (r.callback = null, r = n, typeof l != "function") throw Error(y(191, l));
      l.call(r);
    }
  }
}
var bn = {}, $e = mt(bn), Wn = mt(bn), Hn = mt(bn);
function Et(e) {
  if (e === bn) throw Error(y(174));
  return e;
}
function di(e, t) {
  switch (j(Hn, t), j(Wn, e), j($e, bn), e = t.nodeType, e) {
    case 9:
    case 11:
      t = (t = t.documentElement) ? t.namespaceURI : eo(null, "");
      break;
    default:
      e = e === 8 ? t.parentNode : t, t = e.namespaceURI || null, e = e.tagName, t = eo(t, e);
  }
  F($e), j($e, t);
}
function nn() {
  F($e), F(Wn), F(Hn);
}
function la(e) {
  Et(Hn.current);
  var t = Et($e.current), n = eo(t, e.type);
  t !== n && (j(Wn, e), j($e, n));
}
function pi(e) {
  Wn.current === e && (F($e), F(Wn));
}
var $ = mt(0);
function Yr(e) {
  for (var t = e; t !== null; ) {
    if (t.tag === 13) {
      var n = t.memoizedState;
      if (n !== null && (n = n.dehydrated, n === null || n.data === "$?" || n.data === "$!")) return t;
    } else if (t.tag === 19 && t.memoizedProps.revealOrder !== void 0) {
      if (t.flags & 128) return t;
    } else if (t.child !== null) {
      t.child.return = t, t = t.child;
      continue;
    }
    if (t === e) break;
    for (; t.sibling === null; ) {
      if (t.return === null || t.return === e) return null;
      t = t.return;
    }
    t.sibling.return = t.return, t = t.sibling;
  }
  return null;
}
var Fl = [];
function mi() {
  for (var e = 0; e < Fl.length; e++) Fl[e]._workInProgressVersionPrimary = null;
  Fl.length = 0;
}
var Nr = Ge.ReactCurrentDispatcher, Ul = Ge.ReactCurrentBatchConfig, Pt = 0, V = null, Y = null, Z = null, Xr = !1, zn = !1, Qn = 0, Kf = 0;
function ne() {
  throw Error(y(321));
}
function vi(e, t) {
  if (t === null) return !1;
  for (var n = 0; n < t.length && n < e.length; n++) if (!Oe(e[n], t[n])) return !1;
  return !0;
}
function hi(e, t, n, r, l, o) {
  if (Pt = o, V = t, t.memoizedState = null, t.updateQueue = null, t.lanes = 0, Nr.current = e === null || e.memoizedState === null ? Zf : Jf, e = n(r, l), zn) {
    o = 0;
    do {
      if (zn = !1, Qn = 0, 25 <= o) throw Error(y(301));
      o += 1, Z = Y = null, t.updateQueue = null, Nr.current = qf, e = n(r, l);
    } while (zn);
  }
  if (Nr.current = Gr, t = Y !== null && Y.next !== null, Pt = 0, Z = Y = V = null, Xr = !1, t) throw Error(y(300));
  return e;
}
function yi() {
  var e = Qn !== 0;
  return Qn = 0, e;
}
function Ie() {
  var e = { memoizedState: null, baseState: null, baseQueue: null, queue: null, next: null };
  return Z === null ? V.memoizedState = Z = e : Z = Z.next = e, Z;
}
function _e() {
  if (Y === null) {
    var e = V.alternate;
    e = e !== null ? e.memoizedState : null;
  } else e = Y.next;
  var t = Z === null ? V.memoizedState : Z.next;
  if (t !== null) Z = t, Y = e;
  else {
    if (e === null) throw Error(y(310));
    Y = e, e = { memoizedState: Y.memoizedState, baseState: Y.baseState, baseQueue: Y.baseQueue, queue: Y.queue, next: null }, Z === null ? V.memoizedState = Z = e : Z = Z.next = e;
  }
  return Z;
}
function Kn(e, t) {
  return typeof t == "function" ? t(e) : t;
}
function $l(e) {
  var t = _e(), n = t.queue;
  if (n === null) throw Error(y(311));
  n.lastRenderedReducer = e;
  var r = Y, l = r.baseQueue, o = n.pending;
  if (o !== null) {
    if (l !== null) {
      var i = l.next;
      l.next = o.next, o.next = i;
    }
    r.baseQueue = l = o, n.pending = null;
  }
  if (l !== null) {
    o = l.next, r = r.baseState;
    var u = i = null, s = null, f = o;
    do {
      var v = f.lane;
      if ((Pt & v) === v) s !== null && (s = s.next = { lane: 0, action: f.action, hasEagerState: f.hasEagerState, eagerState: f.eagerState, next: null }), r = f.hasEagerState ? f.eagerState : e(r, f.action);
      else {
        var m = {
          lane: v,
          action: f.action,
          hasEagerState: f.hasEagerState,
          eagerState: f.eagerState,
          next: null
        };
        s === null ? (u = s = m, i = r) : s = s.next = m, V.lanes |= v, zt |= v;
      }
      f = f.next;
    } while (f !== null && f !== o);
    s === null ? i = r : s.next = u, Oe(r, t.memoizedState) || (fe = !0), t.memoizedState = r, t.baseState = i, t.baseQueue = s, n.lastRenderedState = r;
  }
  if (e = n.interleaved, e !== null) {
    l = e;
    do
      o = l.lane, V.lanes |= o, zt |= o, l = l.next;
    while (l !== e);
  } else l === null && (n.lanes = 0);
  return [t.memoizedState, n.dispatch];
}
function Vl(e) {
  var t = _e(), n = t.queue;
  if (n === null) throw Error(y(311));
  n.lastRenderedReducer = e;
  var r = n.dispatch, l = n.pending, o = t.memoizedState;
  if (l !== null) {
    n.pending = null;
    var i = l = l.next;
    do
      o = e(o, i.action), i = i.next;
    while (i !== l);
    Oe(o, t.memoizedState) || (fe = !0), t.memoizedState = o, t.baseQueue === null && (t.baseState = o), n.lastRenderedState = o;
  }
  return [o, r];
}
function oa() {
}
function ia(e, t) {
  var n = V, r = _e(), l = t(), o = !Oe(r.memoizedState, l);
  if (o && (r.memoizedState = l, fe = !0), r = r.queue, gi(aa.bind(null, n, r, e), [e]), r.getSnapshot !== t || o || Z !== null && Z.memoizedState.tag & 1) {
    if (n.flags |= 2048, Yn(9, sa.bind(null, n, r, l, t), void 0, null), q === null) throw Error(y(349));
    Pt & 30 || ua(n, t, l);
  }
  return l;
}
function ua(e, t, n) {
  e.flags |= 16384, e = { getSnapshot: t, value: n }, t = V.updateQueue, t === null ? (t = { lastEffect: null, stores: null }, V.updateQueue = t, t.stores = [e]) : (n = t.stores, n === null ? t.stores = [e] : n.push(e));
}
function sa(e, t, n, r) {
  t.value = n, t.getSnapshot = r, ca(t) && fa(e);
}
function aa(e, t, n) {
  return n(function() {
    ca(t) && fa(e);
  });
}
function ca(e) {
  var t = e.getSnapshot;
  e = e.value;
  try {
    var n = t();
    return !Oe(e, n);
  } catch {
    return !0;
  }
}
function fa(e) {
  var t = Ye(e, 1);
  t !== null && De(t, e, 1, -1);
}
function wu(e) {
  var t = Ie();
  return typeof e == "function" && (e = e()), t.memoizedState = t.baseState = e, e = { pending: null, interleaved: null, lanes: 0, dispatch: null, lastRenderedReducer: Kn, lastRenderedState: e }, t.queue = e, e = e.dispatch = Gf.bind(null, V, e), [t.memoizedState, e];
}
function Yn(e, t, n, r) {
  return e = { tag: e, create: t, destroy: n, deps: r, next: null }, t = V.updateQueue, t === null ? (t = { lastEffect: null, stores: null }, V.updateQueue = t, t.lastEffect = e.next = e) : (n = t.lastEffect, n === null ? t.lastEffect = e.next = e : (r = n.next, n.next = e, e.next = r, t.lastEffect = e)), e;
}
function da() {
  return _e().memoizedState;
}
function _r(e, t, n, r) {
  var l = Ie();
  V.flags |= e, l.memoizedState = Yn(1 | t, n, void 0, r === void 0 ? null : r);
}
function ul(e, t, n, r) {
  var l = _e();
  r = r === void 0 ? null : r;
  var o = void 0;
  if (Y !== null) {
    var i = Y.memoizedState;
    if (o = i.destroy, r !== null && vi(r, i.deps)) {
      l.memoizedState = Yn(t, n, o, r);
      return;
    }
  }
  V.flags |= e, l.memoizedState = Yn(1 | t, n, o, r);
}
function Su(e, t) {
  return _r(8390656, 8, e, t);
}
function gi(e, t) {
  return ul(2048, 8, e, t);
}
function pa(e, t) {
  return ul(4, 2, e, t);
}
function ma(e, t) {
  return ul(4, 4, e, t);
}
function va(e, t) {
  if (typeof t == "function") return e = e(), t(e), function() {
    t(null);
  };
  if (t != null) return e = e(), t.current = e, function() {
    t.current = null;
  };
}
function ha(e, t, n) {
  return n = n != null ? n.concat([e]) : null, ul(4, 4, va.bind(null, t, e), n);
}
function wi() {
}
function ya(e, t) {
  var n = _e();
  t = t === void 0 ? null : t;
  var r = n.memoizedState;
  return r !== null && t !== null && vi(t, r[1]) ? r[0] : (n.memoizedState = [e, t], e);
}
function ga(e, t) {
  var n = _e();
  t = t === void 0 ? null : t;
  var r = n.memoizedState;
  return r !== null && t !== null && vi(t, r[1]) ? r[0] : (e = e(), n.memoizedState = [e, t], e);
}
function wa(e, t, n) {
  return Pt & 21 ? (Oe(n, t) || (n = Cs(), V.lanes |= n, zt |= n, e.baseState = !0), t) : (e.baseState && (e.baseState = !1, fe = !0), e.memoizedState = n);
}
function Yf(e, t) {
  var n = O;
  O = n !== 0 && 4 > n ? n : 4, e(!0);
  var r = Ul.transition;
  Ul.transition = {};
  try {
    e(!1), t();
  } finally {
    O = n, Ul.transition = r;
  }
}
function Sa() {
  return _e().memoizedState;
}
function Xf(e, t, n) {
  var r = at(e);
  if (n = { lane: r, action: n, hasEagerState: !1, eagerState: null, next: null }, ka(e)) Ea(t, n);
  else if (n = na(e, t, n, r), n !== null) {
    var l = ue();
    De(n, e, r, l), xa(n, t, r);
  }
}
function Gf(e, t, n) {
  var r = at(e), l = { lane: r, action: n, hasEagerState: !1, eagerState: null, next: null };
  if (ka(e)) Ea(t, l);
  else {
    var o = e.alternate;
    if (e.lanes === 0 && (o === null || o.lanes === 0) && (o = t.lastRenderedReducer, o !== null)) try {
      var i = t.lastRenderedState, u = o(i, n);
      if (l.hasEagerState = !0, l.eagerState = u, Oe(u, i)) {
        var s = t.interleaved;
        s === null ? (l.next = l, ci(t)) : (l.next = s.next, s.next = l), t.interleaved = l;
        return;
      }
    } catch {
    } finally {
    }
    n = na(e, t, l, r), n !== null && (l = ue(), De(n, e, r, l), xa(n, t, r));
  }
}
function ka(e) {
  var t = e.alternate;
  return e === V || t !== null && t === V;
}
function Ea(e, t) {
  zn = Xr = !0;
  var n = e.pending;
  n === null ? t.next = t : (t.next = n.next, n.next = t), e.pending = t;
}
function xa(e, t, n) {
  if (n & 4194240) {
    var r = t.lanes;
    r &= e.pendingLanes, n |= r, t.lanes = n, Zo(e, n);
  }
}
var Gr = { readContext: Ne, useCallback: ne, useContext: ne, useEffect: ne, useImperativeHandle: ne, useInsertionEffect: ne, useLayoutEffect: ne, useMemo: ne, useReducer: ne, useRef: ne, useState: ne, useDebugValue: ne, useDeferredValue: ne, useTransition: ne, useMutableSource: ne, useSyncExternalStore: ne, useId: ne, unstable_isNewReconciler: !1 }, Zf = { readContext: Ne, useCallback: function(e, t) {
  return Ie().memoizedState = [e, t === void 0 ? null : t], e;
}, useContext: Ne, useEffect: Su, useImperativeHandle: function(e, t, n) {
  return n = n != null ? n.concat([e]) : null, _r(
    4194308,
    4,
    va.bind(null, t, e),
    n
  );
}, useLayoutEffect: function(e, t) {
  return _r(4194308, 4, e, t);
}, useInsertionEffect: function(e, t) {
  return _r(4, 2, e, t);
}, useMemo: function(e, t) {
  var n = Ie();
  return t = t === void 0 ? null : t, e = e(), n.memoizedState = [e, t], e;
}, useReducer: function(e, t, n) {
  var r = Ie();
  return t = n !== void 0 ? n(t) : t, r.memoizedState = r.baseState = t, e = { pending: null, interleaved: null, lanes: 0, dispatch: null, lastRenderedReducer: e, lastRenderedState: t }, r.queue = e, e = e.dispatch = Xf.bind(null, V, e), [r.memoizedState, e];
}, useRef: function(e) {
  var t = Ie();
  return e = { current: e }, t.memoizedState = e;
}, useState: wu, useDebugValue: wi, useDeferredValue: function(e) {
  return Ie().memoizedState = e;
}, useTransition: function() {
  var e = wu(!1), t = e[0];
  return e = Yf.bind(null, e[1]), Ie().memoizedState = e, [t, e];
}, useMutableSource: function() {
}, useSyncExternalStore: function(e, t, n) {
  var r = V, l = Ie();
  if (U) {
    if (n === void 0) throw Error(y(407));
    n = n();
  } else {
    if (n = t(), q === null) throw Error(y(349));
    Pt & 30 || ua(r, t, n);
  }
  l.memoizedState = n;
  var o = { value: n, getSnapshot: t };
  return l.queue = o, Su(aa.bind(
    null,
    r,
    o,
    e
  ), [e]), r.flags |= 2048, Yn(9, sa.bind(null, r, o, n, t), void 0, null), n;
}, useId: function() {
  var e = Ie(), t = q.identifierPrefix;
  if (U) {
    var n = We, r = Be;
    n = (r & ~(1 << 32 - Re(r) - 1)).toString(32) + n, t = ":" + t + "R" + n, n = Qn++, 0 < n && (t += "H" + n.toString(32)), t += ":";
  } else n = Kf++, t = ":" + t + "r" + n.toString(32) + ":";
  return e.memoizedState = t;
}, unstable_isNewReconciler: !1 }, Jf = {
  readContext: Ne,
  useCallback: ya,
  useContext: Ne,
  useEffect: gi,
  useImperativeHandle: ha,
  useInsertionEffect: pa,
  useLayoutEffect: ma,
  useMemo: ga,
  useReducer: $l,
  useRef: da,
  useState: function() {
    return $l(Kn);
  },
  useDebugValue: wi,
  useDeferredValue: function(e) {
    var t = _e();
    return wa(t, Y.memoizedState, e);
  },
  useTransition: function() {
    var e = $l(Kn)[0], t = _e().memoizedState;
    return [e, t];
  },
  useMutableSource: oa,
  useSyncExternalStore: ia,
  useId: Sa,
  unstable_isNewReconciler: !1
}, qf = { readContext: Ne, useCallback: ya, useContext: Ne, useEffect: gi, useImperativeHandle: ha, useInsertionEffect: pa, useLayoutEffect: ma, useMemo: ga, useReducer: Vl, useRef: da, useState: function() {
  return Vl(Kn);
}, useDebugValue: wi, useDeferredValue: function(e) {
  var t = _e();
  return Y === null ? t.memoizedState = e : wa(t, Y.memoizedState, e);
}, useTransition: function() {
  var e = Vl(Kn)[0], t = _e().memoizedState;
  return [e, t];
}, useMutableSource: oa, useSyncExternalStore: ia, useId: Sa, unstable_isNewReconciler: !1 };
function Le(e, t) {
  if (e && e.defaultProps) {
    t = A({}, t), e = e.defaultProps;
    for (var n in e) t[n] === void 0 && (t[n] = e[n]);
    return t;
  }
  return t;
}
function Eo(e, t, n, r) {
  t = e.memoizedState, n = n(r, t), n = n == null ? t : A({}, t, n), e.memoizedState = n, e.lanes === 0 && (e.updateQueue.baseState = n);
}
var sl = { isMounted: function(e) {
  return (e = e._reactInternals) ? Mt(e) === e : !1;
}, enqueueSetState: function(e, t, n) {
  e = e._reactInternals;
  var r = ue(), l = at(e), o = He(r, l);
  o.payload = t, n != null && (o.callback = n), t = ut(e, o, l), t !== null && (De(t, e, l, r), Cr(t, e, l));
}, enqueueReplaceState: function(e, t, n) {
  e = e._reactInternals;
  var r = ue(), l = at(e), o = He(r, l);
  o.tag = 1, o.payload = t, n != null && (o.callback = n), t = ut(e, o, l), t !== null && (De(t, e, l, r), Cr(t, e, l));
}, enqueueForceUpdate: function(e, t) {
  e = e._reactInternals;
  var n = ue(), r = at(e), l = He(n, r);
  l.tag = 2, t != null && (l.callback = t), t = ut(e, l, r), t !== null && (De(t, e, r, n), Cr(t, e, r));
} };
function ku(e, t, n, r, l, o, i) {
  return e = e.stateNode, typeof e.shouldComponentUpdate == "function" ? e.shouldComponentUpdate(r, o, i) : t.prototype && t.prototype.isPureReactComponent ? !$n(n, r) || !$n(l, o) : !0;
}
function Ca(e, t, n) {
  var r = !1, l = dt, o = t.contextType;
  return typeof o == "object" && o !== null ? o = Ne(o) : (l = pe(t) ? Nt : oe.current, r = t.contextTypes, o = (r = r != null) ? bt(e, l) : dt), t = new t(n, o), e.memoizedState = t.state !== null && t.state !== void 0 ? t.state : null, t.updater = sl, e.stateNode = t, t._reactInternals = e, r && (e = e.stateNode, e.__reactInternalMemoizedUnmaskedChildContext = l, e.__reactInternalMemoizedMaskedChildContext = o), t;
}
function Eu(e, t, n, r) {
  e = t.state, typeof t.componentWillReceiveProps == "function" && t.componentWillReceiveProps(n, r), typeof t.UNSAFE_componentWillReceiveProps == "function" && t.UNSAFE_componentWillReceiveProps(n, r), t.state !== e && sl.enqueueReplaceState(t, t.state, null);
}
function xo(e, t, n, r) {
  var l = e.stateNode;
  l.props = n, l.state = e.memoizedState, l.refs = {}, fi(e);
  var o = t.contextType;
  typeof o == "object" && o !== null ? l.context = Ne(o) : (o = pe(t) ? Nt : oe.current, l.context = bt(e, o)), l.state = e.memoizedState, o = t.getDerivedStateFromProps, typeof o == "function" && (Eo(e, t, o, n), l.state = e.memoizedState), typeof t.getDerivedStateFromProps == "function" || typeof l.getSnapshotBeforeUpdate == "function" || typeof l.UNSAFE_componentWillMount != "function" && typeof l.componentWillMount != "function" || (t = l.state, typeof l.componentWillMount == "function" && l.componentWillMount(), typeof l.UNSAFE_componentWillMount == "function" && l.UNSAFE_componentWillMount(), t !== l.state && sl.enqueueReplaceState(l, l.state, null), Kr(e, n, l, r), l.state = e.memoizedState), typeof l.componentDidMount == "function" && (e.flags |= 4194308);
}
function rn(e, t) {
  try {
    var n = "", r = t;
    do
      n += Nc(r), r = r.return;
    while (r);
    var l = n;
  } catch (o) {
    l = `
Error generating stack: ` + o.message + `
` + o.stack;
  }
  return { value: e, source: t, stack: l, digest: null };
}
function Al(e, t, n) {
  return { value: e, source: null, stack: n ?? null, digest: t ?? null };
}
function Co(e, t) {
  try {
    console.error(t.value);
  } catch (n) {
    setTimeout(function() {
      throw n;
    });
  }
}
var bf = typeof WeakMap == "function" ? WeakMap : Map;
function Na(e, t, n) {
  n = He(-1, n), n.tag = 3, n.payload = { element: null };
  var r = t.value;
  return n.callback = function() {
    Jr || (Jr = !0, Oo = r), Co(e, t);
  }, n;
}
function _a(e, t, n) {
  n = He(-1, n), n.tag = 3;
  var r = e.type.getDerivedStateFromError;
  if (typeof r == "function") {
    var l = t.value;
    n.payload = function() {
      return r(l);
    }, n.callback = function() {
      Co(e, t);
    };
  }
  var o = e.stateNode;
  return o !== null && typeof o.componentDidCatch == "function" && (n.callback = function() {
    Co(e, t), typeof r != "function" && (st === null ? st = /* @__PURE__ */ new Set([this]) : st.add(this));
    var i = t.stack;
    this.componentDidCatch(t.value, { componentStack: i !== null ? i : "" });
  }), n;
}
function xu(e, t, n) {
  var r = e.pingCache;
  if (r === null) {
    r = e.pingCache = new bf();
    var l = /* @__PURE__ */ new Set();
    r.set(t, l);
  } else l = r.get(t), l === void 0 && (l = /* @__PURE__ */ new Set(), r.set(t, l));
  l.has(n) || (l.add(n), e = pd.bind(null, e, t, n), t.then(e, e));
}
function Cu(e) {
  do {
    var t;
    if ((t = e.tag === 13) && (t = e.memoizedState, t = t !== null ? t.dehydrated !== null : !0), t) return e;
    e = e.return;
  } while (e !== null);
  return null;
}
function Nu(e, t, n, r, l) {
  return e.mode & 1 ? (e.flags |= 65536, e.lanes = l, e) : (e === t ? e.flags |= 65536 : (e.flags |= 128, n.flags |= 131072, n.flags &= -52805, n.tag === 1 && (n.alternate === null ? n.tag = 17 : (t = He(-1, 1), t.tag = 2, ut(n, t, 1))), n.lanes |= 1), e);
}
var ed = Ge.ReactCurrentOwner, fe = !1;
function ie(e, t, n, r) {
  t.child = e === null ? ta(t, null, n, r) : tn(t, e.child, n, r);
}
function _u(e, t, n, r, l) {
  n = n.render;
  var o = t.ref;
  return Zt(t, l), r = hi(e, t, n, r, o, l), n = yi(), e !== null && !fe ? (t.updateQueue = e.updateQueue, t.flags &= -2053, e.lanes &= ~l, Xe(e, t, l)) : (U && n && li(t), t.flags |= 1, ie(e, t, r, l), t.child);
}
function Pu(e, t, n, r, l) {
  if (e === null) {
    var o = n.type;
    return typeof o == "function" && !Pi(o) && o.defaultProps === void 0 && n.compare === null && n.defaultProps === void 0 ? (t.tag = 15, t.type = o, Pa(e, t, o, r, l)) : (e = Tr(n.type, null, r, t, t.mode, l), e.ref = t.ref, e.return = t, t.child = e);
  }
  if (o = e.child, !(e.lanes & l)) {
    var i = o.memoizedProps;
    if (n = n.compare, n = n !== null ? n : $n, n(i, r) && e.ref === t.ref) return Xe(e, t, l);
  }
  return t.flags |= 1, e = ct(o, r), e.ref = t.ref, e.return = t, t.child = e;
}
function Pa(e, t, n, r, l) {
  if (e !== null) {
    var o = e.memoizedProps;
    if ($n(o, r) && e.ref === t.ref) if (fe = !1, t.pendingProps = r = o, (e.lanes & l) !== 0) e.flags & 131072 && (fe = !0);
    else return t.lanes = e.lanes, Xe(e, t, l);
  }
  return No(e, t, n, r, l);
}
function za(e, t, n) {
  var r = t.pendingProps, l = r.children, o = e !== null ? e.memoizedState : null;
  if (r.mode === "hidden") if (!(t.mode & 1)) t.memoizedState = { baseLanes: 0, cachePool: null, transitions: null }, j(Qt, ve), ve |= n;
  else {
    if (!(n & 1073741824)) return e = o !== null ? o.baseLanes | n : n, t.lanes = t.childLanes = 1073741824, t.memoizedState = { baseLanes: e, cachePool: null, transitions: null }, t.updateQueue = null, j(Qt, ve), ve |= e, null;
    t.memoizedState = { baseLanes: 0, cachePool: null, transitions: null }, r = o !== null ? o.baseLanes : n, j(Qt, ve), ve |= r;
  }
  else o !== null ? (r = o.baseLanes | n, t.memoizedState = null) : r = n, j(Qt, ve), ve |= r;
  return ie(e, t, l, n), t.child;
}
function La(e, t) {
  var n = t.ref;
  (e === null && n !== null || e !== null && e.ref !== n) && (t.flags |= 512, t.flags |= 2097152);
}
function No(e, t, n, r, l) {
  var o = pe(n) ? Nt : oe.current;
  return o = bt(t, o), Zt(t, l), n = hi(e, t, n, r, o, l), r = yi(), e !== null && !fe ? (t.updateQueue = e.updateQueue, t.flags &= -2053, e.lanes &= ~l, Xe(e, t, l)) : (U && r && li(t), t.flags |= 1, ie(e, t, n, l), t.child);
}
function zu(e, t, n, r, l) {
  if (pe(n)) {
    var o = !0;
    Ar(t);
  } else o = !1;
  if (Zt(t, l), t.stateNode === null) Pr(e, t), Ca(t, n, r), xo(t, n, r, l), r = !0;
  else if (e === null) {
    var i = t.stateNode, u = t.memoizedProps;
    i.props = u;
    var s = i.context, f = n.contextType;
    typeof f == "object" && f !== null ? f = Ne(f) : (f = pe(n) ? Nt : oe.current, f = bt(t, f));
    var v = n.getDerivedStateFromProps, m = typeof v == "function" || typeof i.getSnapshotBeforeUpdate == "function";
    m || typeof i.UNSAFE_componentWillReceiveProps != "function" && typeof i.componentWillReceiveProps != "function" || (u !== r || s !== f) && Eu(t, i, r, f), qe = !1;
    var p = t.memoizedState;
    i.state = p, Kr(t, r, i, l), s = t.memoizedState, u !== r || p !== s || de.current || qe ? (typeof v == "function" && (Eo(t, n, v, r), s = t.memoizedState), (u = qe || ku(t, n, u, r, p, s, f)) ? (m || typeof i.UNSAFE_componentWillMount != "function" && typeof i.componentWillMount != "function" || (typeof i.componentWillMount == "function" && i.componentWillMount(), typeof i.UNSAFE_componentWillMount == "function" && i.UNSAFE_componentWillMount()), typeof i.componentDidMount == "function" && (t.flags |= 4194308)) : (typeof i.componentDidMount == "function" && (t.flags |= 4194308), t.memoizedProps = r, t.memoizedState = s), i.props = r, i.state = s, i.context = f, r = u) : (typeof i.componentDidMount == "function" && (t.flags |= 4194308), r = !1);
  } else {
    i = t.stateNode, ra(e, t), u = t.memoizedProps, f = t.type === t.elementType ? u : Le(t.type, u), i.props = f, m = t.pendingProps, p = i.context, s = n.contextType, typeof s == "object" && s !== null ? s = Ne(s) : (s = pe(n) ? Nt : oe.current, s = bt(t, s));
    var w = n.getDerivedStateFromProps;
    (v = typeof w == "function" || typeof i.getSnapshotBeforeUpdate == "function") || typeof i.UNSAFE_componentWillReceiveProps != "function" && typeof i.componentWillReceiveProps != "function" || (u !== m || p !== s) && Eu(t, i, r, s), qe = !1, p = t.memoizedState, i.state = p, Kr(t, r, i, l);
    var S = t.memoizedState;
    u !== m || p !== S || de.current || qe ? (typeof w == "function" && (Eo(t, n, w, r), S = t.memoizedState), (f = qe || ku(t, n, f, r, p, S, s) || !1) ? (v || typeof i.UNSAFE_componentWillUpdate != "function" && typeof i.componentWillUpdate != "function" || (typeof i.componentWillUpdate == "function" && i.componentWillUpdate(r, S, s), typeof i.UNSAFE_componentWillUpdate == "function" && i.UNSAFE_componentWillUpdate(r, S, s)), typeof i.componentDidUpdate == "function" && (t.flags |= 4), typeof i.getSnapshotBeforeUpdate == "function" && (t.flags |= 1024)) : (typeof i.componentDidUpdate != "function" || u === e.memoizedProps && p === e.memoizedState || (t.flags |= 4), typeof i.getSnapshotBeforeUpdate != "function" || u === e.memoizedProps && p === e.memoizedState || (t.flags |= 1024), t.memoizedProps = r, t.memoizedState = S), i.props = r, i.state = S, i.context = s, r = f) : (typeof i.componentDidUpdate != "function" || u === e.memoizedProps && p === e.memoizedState || (t.flags |= 4), typeof i.getSnapshotBeforeUpdate != "function" || u === e.memoizedProps && p === e.memoizedState || (t.flags |= 1024), r = !1);
  }
  return _o(e, t, n, r, o, l);
}
function _o(e, t, n, r, l, o) {
  La(e, t);
  var i = (t.flags & 128) !== 0;
  if (!r && !i) return l && pu(t, n, !1), Xe(e, t, o);
  r = t.stateNode, ed.current = t;
  var u = i && typeof n.getDerivedStateFromError != "function" ? null : r.render();
  return t.flags |= 1, e !== null && i ? (t.child = tn(t, e.child, null, o), t.child = tn(t, null, u, o)) : ie(e, t, u, o), t.memoizedState = r.state, l && pu(t, n, !0), t.child;
}
function Ta(e) {
  var t = e.stateNode;
  t.pendingContext ? du(e, t.pendingContext, t.pendingContext !== t.context) : t.context && du(e, t.context, !1), di(e, t.containerInfo);
}
function Lu(e, t, n, r, l) {
  return en(), ii(l), t.flags |= 256, ie(e, t, n, r), t.child;
}
var Po = { dehydrated: null, treeContext: null, retryLane: 0 };
function zo(e) {
  return { baseLanes: e, cachePool: null, transitions: null };
}
function Ma(e, t, n) {
  var r = t.pendingProps, l = $.current, o = !1, i = (t.flags & 128) !== 0, u;
  if ((u = i) || (u = e !== null && e.memoizedState === null ? !1 : (l & 2) !== 0), u ? (o = !0, t.flags &= -129) : (e === null || e.memoizedState !== null) && (l |= 1), j($, l & 1), e === null)
    return So(t), e = t.memoizedState, e !== null && (e = e.dehydrated, e !== null) ? (t.mode & 1 ? e.data === "$!" ? t.lanes = 8 : t.lanes = 1073741824 : t.lanes = 1, null) : (i = r.children, e = r.fallback, o ? (r = t.mode, o = t.child, i = { mode: "hidden", children: i }, !(r & 1) && o !== null ? (o.childLanes = 0, o.pendingProps = i) : o = fl(i, r, 0, null), e = Ct(e, r, n, null), o.return = t, e.return = t, o.sibling = e, t.child = o, t.child.memoizedState = zo(n), t.memoizedState = Po, e) : Si(t, i));
  if (l = e.memoizedState, l !== null && (u = l.dehydrated, u !== null)) return td(e, t, i, r, u, l, n);
  if (o) {
    o = r.fallback, i = t.mode, l = e.child, u = l.sibling;
    var s = { mode: "hidden", children: r.children };
    return !(i & 1) && t.child !== l ? (r = t.child, r.childLanes = 0, r.pendingProps = s, t.deletions = null) : (r = ct(l, s), r.subtreeFlags = l.subtreeFlags & 14680064), u !== null ? o = ct(u, o) : (o = Ct(o, i, n, null), o.flags |= 2), o.return = t, r.return = t, r.sibling = o, t.child = r, r = o, o = t.child, i = e.child.memoizedState, i = i === null ? zo(n) : { baseLanes: i.baseLanes | n, cachePool: null, transitions: i.transitions }, o.memoizedState = i, o.childLanes = e.childLanes & ~n, t.memoizedState = Po, r;
  }
  return o = e.child, e = o.sibling, r = ct(o, { mode: "visible", children: r.children }), !(t.mode & 1) && (r.lanes = n), r.return = t, r.sibling = null, e !== null && (n = t.deletions, n === null ? (t.deletions = [e], t.flags |= 16) : n.push(e)), t.child = r, t.memoizedState = null, r;
}
function Si(e, t) {
  return t = fl({ mode: "visible", children: t }, e.mode, 0, null), t.return = e, e.child = t;
}
function vr(e, t, n, r) {
  return r !== null && ii(r), tn(t, e.child, null, n), e = Si(t, t.pendingProps.children), e.flags |= 2, t.memoizedState = null, e;
}
function td(e, t, n, r, l, o, i) {
  if (n)
    return t.flags & 256 ? (t.flags &= -257, r = Al(Error(y(422))), vr(e, t, i, r)) : t.memoizedState !== null ? (t.child = e.child, t.flags |= 128, null) : (o = r.fallback, l = t.mode, r = fl({ mode: "visible", children: r.children }, l, 0, null), o = Ct(o, l, i, null), o.flags |= 2, r.return = t, o.return = t, r.sibling = o, t.child = r, t.mode & 1 && tn(t, e.child, null, i), t.child.memoizedState = zo(i), t.memoizedState = Po, o);
  if (!(t.mode & 1)) return vr(e, t, i, null);
  if (l.data === "$!") {
    if (r = l.nextSibling && l.nextSibling.dataset, r) var u = r.dgst;
    return r = u, o = Error(y(419)), r = Al(o, r, void 0), vr(e, t, i, r);
  }
  if (u = (i & e.childLanes) !== 0, fe || u) {
    if (r = q, r !== null) {
      switch (i & -i) {
        case 4:
          l = 2;
          break;
        case 16:
          l = 8;
          break;
        case 64:
        case 128:
        case 256:
        case 512:
        case 1024:
        case 2048:
        case 4096:
        case 8192:
        case 16384:
        case 32768:
        case 65536:
        case 131072:
        case 262144:
        case 524288:
        case 1048576:
        case 2097152:
        case 4194304:
        case 8388608:
        case 16777216:
        case 33554432:
        case 67108864:
          l = 32;
          break;
        case 536870912:
          l = 268435456;
          break;
        default:
          l = 0;
      }
      l = l & (r.suspendedLanes | i) ? 0 : l, l !== 0 && l !== o.retryLane && (o.retryLane = l, Ye(e, l), De(r, e, l, -1));
    }
    return _i(), r = Al(Error(y(421))), vr(e, t, i, r);
  }
  return l.data === "$?" ? (t.flags |= 128, t.child = e.child, t = md.bind(null, e), l._reactRetry = t, null) : (e = o.treeContext, he = it(l.nextSibling), ye = t, U = !0, Me = null, e !== null && (ke[Ee++] = Be, ke[Ee++] = We, ke[Ee++] = _t, Be = e.id, We = e.overflow, _t = t), t = Si(t, r.children), t.flags |= 4096, t);
}
function Tu(e, t, n) {
  e.lanes |= t;
  var r = e.alternate;
  r !== null && (r.lanes |= t), ko(e.return, t, n);
}
function Bl(e, t, n, r, l) {
  var o = e.memoizedState;
  o === null ? e.memoizedState = { isBackwards: t, rendering: null, renderingStartTime: 0, last: r, tail: n, tailMode: l } : (o.isBackwards = t, o.rendering = null, o.renderingStartTime = 0, o.last = r, o.tail = n, o.tailMode = l);
}
function Ra(e, t, n) {
  var r = t.pendingProps, l = r.revealOrder, o = r.tail;
  if (ie(e, t, r.children, n), r = $.current, r & 2) r = r & 1 | 2, t.flags |= 128;
  else {
    if (e !== null && e.flags & 128) e: for (e = t.child; e !== null; ) {
      if (e.tag === 13) e.memoizedState !== null && Tu(e, n, t);
      else if (e.tag === 19) Tu(e, n, t);
      else if (e.child !== null) {
        e.child.return = e, e = e.child;
        continue;
      }
      if (e === t) break e;
      for (; e.sibling === null; ) {
        if (e.return === null || e.return === t) break e;
        e = e.return;
      }
      e.sibling.return = e.return, e = e.sibling;
    }
    r &= 1;
  }
  if (j($, r), !(t.mode & 1)) t.memoizedState = null;
  else switch (l) {
    case "forwards":
      for (n = t.child, l = null; n !== null; ) e = n.alternate, e !== null && Yr(e) === null && (l = n), n = n.sibling;
      n = l, n === null ? (l = t.child, t.child = null) : (l = n.sibling, n.sibling = null), Bl(t, !1, l, n, o);
      break;
    case "backwards":
      for (n = null, l = t.child, t.child = null; l !== null; ) {
        if (e = l.alternate, e !== null && Yr(e) === null) {
          t.child = l;
          break;
        }
        e = l.sibling, l.sibling = n, n = l, l = e;
      }
      Bl(t, !0, n, null, o);
      break;
    case "together":
      Bl(t, !1, null, null, void 0);
      break;
    default:
      t.memoizedState = null;
  }
  return t.child;
}
function Pr(e, t) {
  !(t.mode & 1) && e !== null && (e.alternate = null, t.alternate = null, t.flags |= 2);
}
function Xe(e, t, n) {
  if (e !== null && (t.dependencies = e.dependencies), zt |= t.lanes, !(n & t.childLanes)) return null;
  if (e !== null && t.child !== e.child) throw Error(y(153));
  if (t.child !== null) {
    for (e = t.child, n = ct(e, e.pendingProps), t.child = n, n.return = t; e.sibling !== null; ) e = e.sibling, n = n.sibling = ct(e, e.pendingProps), n.return = t;
    n.sibling = null;
  }
  return t.child;
}
function nd(e, t, n) {
  switch (t.tag) {
    case 3:
      Ta(t), en();
      break;
    case 5:
      la(t);
      break;
    case 1:
      pe(t.type) && Ar(t);
      break;
    case 4:
      di(t, t.stateNode.containerInfo);
      break;
    case 10:
      var r = t.type._context, l = t.memoizedProps.value;
      j(Hr, r._currentValue), r._currentValue = l;
      break;
    case 13:
      if (r = t.memoizedState, r !== null)
        return r.dehydrated !== null ? (j($, $.current & 1), t.flags |= 128, null) : n & t.child.childLanes ? Ma(e, t, n) : (j($, $.current & 1), e = Xe(e, t, n), e !== null ? e.sibling : null);
      j($, $.current & 1);
      break;
    case 19:
      if (r = (n & t.childLanes) !== 0, e.flags & 128) {
        if (r) return Ra(e, t, n);
        t.flags |= 128;
      }
      if (l = t.memoizedState, l !== null && (l.rendering = null, l.tail = null, l.lastEffect = null), j($, $.current), r) break;
      return null;
    case 22:
    case 23:
      return t.lanes = 0, za(e, t, n);
  }
  return Xe(e, t, n);
}
var Da, Lo, Oa, ja;
Da = function(e, t) {
  for (var n = t.child; n !== null; ) {
    if (n.tag === 5 || n.tag === 6) e.appendChild(n.stateNode);
    else if (n.tag !== 4 && n.child !== null) {
      n.child.return = n, n = n.child;
      continue;
    }
    if (n === t) break;
    for (; n.sibling === null; ) {
      if (n.return === null || n.return === t) return;
      n = n.return;
    }
    n.sibling.return = n.return, n = n.sibling;
  }
};
Lo = function() {
};
Oa = function(e, t, n, r) {
  var l = e.memoizedProps;
  if (l !== r) {
    e = t.stateNode, Et($e.current);
    var o = null;
    switch (n) {
      case "input":
        l = Zl(e, l), r = Zl(e, r), o = [];
        break;
      case "select":
        l = A({}, l, { value: void 0 }), r = A({}, r, { value: void 0 }), o = [];
        break;
      case "textarea":
        l = bl(e, l), r = bl(e, r), o = [];
        break;
      default:
        typeof l.onClick != "function" && typeof r.onClick == "function" && (e.onclick = $r);
    }
    to(n, r);
    var i;
    n = null;
    for (f in l) if (!r.hasOwnProperty(f) && l.hasOwnProperty(f) && l[f] != null) if (f === "style") {
      var u = l[f];
      for (i in u) u.hasOwnProperty(i) && (n || (n = {}), n[i] = "");
    } else f !== "dangerouslySetInnerHTML" && f !== "children" && f !== "suppressContentEditableWarning" && f !== "suppressHydrationWarning" && f !== "autoFocus" && (Rn.hasOwnProperty(f) ? o || (o = []) : (o = o || []).push(f, null));
    for (f in r) {
      var s = r[f];
      if (u = l != null ? l[f] : void 0, r.hasOwnProperty(f) && s !== u && (s != null || u != null)) if (f === "style") if (u) {
        for (i in u) !u.hasOwnProperty(i) || s && s.hasOwnProperty(i) || (n || (n = {}), n[i] = "");
        for (i in s) s.hasOwnProperty(i) && u[i] !== s[i] && (n || (n = {}), n[i] = s[i]);
      } else n || (o || (o = []), o.push(
        f,
        n
      )), n = s;
      else f === "dangerouslySetInnerHTML" ? (s = s ? s.__html : void 0, u = u ? u.__html : void 0, s != null && u !== s && (o = o || []).push(f, s)) : f === "children" ? typeof s != "string" && typeof s != "number" || (o = o || []).push(f, "" + s) : f !== "suppressContentEditableWarning" && f !== "suppressHydrationWarning" && (Rn.hasOwnProperty(f) ? (s != null && f === "onScroll" && I("scroll", e), o || u === s || (o = [])) : (o = o || []).push(f, s));
    }
    n && (o = o || []).push("style", n);
    var f = o;
    (t.updateQueue = f) && (t.flags |= 4);
  }
};
ja = function(e, t, n, r) {
  n !== r && (t.flags |= 4);
};
function yn(e, t) {
  if (!U) switch (e.tailMode) {
    case "hidden":
      t = e.tail;
      for (var n = null; t !== null; ) t.alternate !== null && (n = t), t = t.sibling;
      n === null ? e.tail = null : n.sibling = null;
      break;
    case "collapsed":
      n = e.tail;
      for (var r = null; n !== null; ) n.alternate !== null && (r = n), n = n.sibling;
      r === null ? t || e.tail === null ? e.tail = null : e.tail.sibling = null : r.sibling = null;
  }
}
function re(e) {
  var t = e.alternate !== null && e.alternate.child === e.child, n = 0, r = 0;
  if (t) for (var l = e.child; l !== null; ) n |= l.lanes | l.childLanes, r |= l.subtreeFlags & 14680064, r |= l.flags & 14680064, l.return = e, l = l.sibling;
  else for (l = e.child; l !== null; ) n |= l.lanes | l.childLanes, r |= l.subtreeFlags, r |= l.flags, l.return = e, l = l.sibling;
  return e.subtreeFlags |= r, e.childLanes = n, t;
}
function rd(e, t, n) {
  var r = t.pendingProps;
  switch (oi(t), t.tag) {
    case 2:
    case 16:
    case 15:
    case 0:
    case 11:
    case 7:
    case 8:
    case 12:
    case 9:
    case 14:
      return re(t), null;
    case 1:
      return pe(t.type) && Vr(), re(t), null;
    case 3:
      return r = t.stateNode, nn(), F(de), F(oe), mi(), r.pendingContext && (r.context = r.pendingContext, r.pendingContext = null), (e === null || e.child === null) && (pr(t) ? t.flags |= 4 : e === null || e.memoizedState.isDehydrated && !(t.flags & 256) || (t.flags |= 1024, Me !== null && (Fo(Me), Me = null))), Lo(e, t), re(t), null;
    case 5:
      pi(t);
      var l = Et(Hn.current);
      if (n = t.type, e !== null && t.stateNode != null) Oa(e, t, n, r, l), e.ref !== t.ref && (t.flags |= 512, t.flags |= 2097152);
      else {
        if (!r) {
          if (t.stateNode === null) throw Error(y(166));
          return re(t), null;
        }
        if (e = Et($e.current), pr(t)) {
          r = t.stateNode, n = t.type;
          var o = t.memoizedProps;
          switch (r[Fe] = t, r[Bn] = o, e = (t.mode & 1) !== 0, n) {
            case "dialog":
              I("cancel", r), I("close", r);
              break;
            case "iframe":
            case "object":
            case "embed":
              I("load", r);
              break;
            case "video":
            case "audio":
              for (l = 0; l < En.length; l++) I(En[l], r);
              break;
            case "source":
              I("error", r);
              break;
            case "img":
            case "image":
            case "link":
              I(
                "error",
                r
              ), I("load", r);
              break;
            case "details":
              I("toggle", r);
              break;
            case "input":
              $i(r, o), I("invalid", r);
              break;
            case "select":
              r._wrapperState = { wasMultiple: !!o.multiple }, I("invalid", r);
              break;
            case "textarea":
              Ai(r, o), I("invalid", r);
          }
          to(n, o), l = null;
          for (var i in o) if (o.hasOwnProperty(i)) {
            var u = o[i];
            i === "children" ? typeof u == "string" ? r.textContent !== u && (o.suppressHydrationWarning !== !0 && dr(r.textContent, u, e), l = ["children", u]) : typeof u == "number" && r.textContent !== "" + u && (o.suppressHydrationWarning !== !0 && dr(
              r.textContent,
              u,
              e
            ), l = ["children", "" + u]) : Rn.hasOwnProperty(i) && u != null && i === "onScroll" && I("scroll", r);
          }
          switch (n) {
            case "input":
              lr(r), Vi(r, o, !0);
              break;
            case "textarea":
              lr(r), Bi(r);
              break;
            case "select":
            case "option":
              break;
            default:
              typeof o.onClick == "function" && (r.onclick = $r);
          }
          r = l, t.updateQueue = r, r !== null && (t.flags |= 4);
        } else {
          i = l.nodeType === 9 ? l : l.ownerDocument, e === "http://www.w3.org/1999/xhtml" && (e = as(n)), e === "http://www.w3.org/1999/xhtml" ? n === "script" ? (e = i.createElement("div"), e.innerHTML = "<script><\/script>", e = e.removeChild(e.firstChild)) : typeof r.is == "string" ? e = i.createElement(n, { is: r.is }) : (e = i.createElement(n), n === "select" && (i = e, r.multiple ? i.multiple = !0 : r.size && (i.size = r.size))) : e = i.createElementNS(e, n), e[Fe] = t, e[Bn] = r, Da(e, t, !1, !1), t.stateNode = e;
          e: {
            switch (i = no(n, r), n) {
              case "dialog":
                I("cancel", e), I("close", e), l = r;
                break;
              case "iframe":
              case "object":
              case "embed":
                I("load", e), l = r;
                break;
              case "video":
              case "audio":
                for (l = 0; l < En.length; l++) I(En[l], e);
                l = r;
                break;
              case "source":
                I("error", e), l = r;
                break;
              case "img":
              case "image":
              case "link":
                I(
                  "error",
                  e
                ), I("load", e), l = r;
                break;
              case "details":
                I("toggle", e), l = r;
                break;
              case "input":
                $i(e, r), l = Zl(e, r), I("invalid", e);
                break;
              case "option":
                l = r;
                break;
              case "select":
                e._wrapperState = { wasMultiple: !!r.multiple }, l = A({}, r, { value: void 0 }), I("invalid", e);
                break;
              case "textarea":
                Ai(e, r), l = bl(e, r), I("invalid", e);
                break;
              default:
                l = r;
            }
            to(n, l), u = l;
            for (o in u) if (u.hasOwnProperty(o)) {
              var s = u[o];
              o === "style" ? ds(e, s) : o === "dangerouslySetInnerHTML" ? (s = s ? s.__html : void 0, s != null && cs(e, s)) : o === "children" ? typeof s == "string" ? (n !== "textarea" || s !== "") && Dn(e, s) : typeof s == "number" && Dn(e, "" + s) : o !== "suppressContentEditableWarning" && o !== "suppressHydrationWarning" && o !== "autoFocus" && (Rn.hasOwnProperty(o) ? s != null && o === "onScroll" && I("scroll", e) : s != null && Ho(e, o, s, i));
            }
            switch (n) {
              case "input":
                lr(e), Vi(e, r, !1);
                break;
              case "textarea":
                lr(e), Bi(e);
                break;
              case "option":
                r.value != null && e.setAttribute("value", "" + ft(r.value));
                break;
              case "select":
                e.multiple = !!r.multiple, o = r.value, o != null ? Kt(e, !!r.multiple, o, !1) : r.defaultValue != null && Kt(
                  e,
                  !!r.multiple,
                  r.defaultValue,
                  !0
                );
                break;
              default:
                typeof l.onClick == "function" && (e.onclick = $r);
            }
            switch (n) {
              case "button":
              case "input":
              case "select":
              case "textarea":
                r = !!r.autoFocus;
                break e;
              case "img":
                r = !0;
                break e;
              default:
                r = !1;
            }
          }
          r && (t.flags |= 4);
        }
        t.ref !== null && (t.flags |= 512, t.flags |= 2097152);
      }
      return re(t), null;
    case 6:
      if (e && t.stateNode != null) ja(e, t, e.memoizedProps, r);
      else {
        if (typeof r != "string" && t.stateNode === null) throw Error(y(166));
        if (n = Et(Hn.current), Et($e.current), pr(t)) {
          if (r = t.stateNode, n = t.memoizedProps, r[Fe] = t, (o = r.nodeValue !== n) && (e = ye, e !== null)) switch (e.tag) {
            case 3:
              dr(r.nodeValue, n, (e.mode & 1) !== 0);
              break;
            case 5:
              e.memoizedProps.suppressHydrationWarning !== !0 && dr(r.nodeValue, n, (e.mode & 1) !== 0);
          }
          o && (t.flags |= 4);
        } else r = (n.nodeType === 9 ? n : n.ownerDocument).createTextNode(r), r[Fe] = t, t.stateNode = r;
      }
      return re(t), null;
    case 13:
      if (F($), r = t.memoizedState, e === null || e.memoizedState !== null && e.memoizedState.dehydrated !== null) {
        if (U && he !== null && t.mode & 1 && !(t.flags & 128)) bs(), en(), t.flags |= 98560, o = !1;
        else if (o = pr(t), r !== null && r.dehydrated !== null) {
          if (e === null) {
            if (!o) throw Error(y(318));
            if (o = t.memoizedState, o = o !== null ? o.dehydrated : null, !o) throw Error(y(317));
            o[Fe] = t;
          } else en(), !(t.flags & 128) && (t.memoizedState = null), t.flags |= 4;
          re(t), o = !1;
        } else Me !== null && (Fo(Me), Me = null), o = !0;
        if (!o) return t.flags & 65536 ? t : null;
      }
      return t.flags & 128 ? (t.lanes = n, t) : (r = r !== null, r !== (e !== null && e.memoizedState !== null) && r && (t.child.flags |= 8192, t.mode & 1 && (e === null || $.current & 1 ? X === 0 && (X = 3) : _i())), t.updateQueue !== null && (t.flags |= 4), re(t), null);
    case 4:
      return nn(), Lo(e, t), e === null && Vn(t.stateNode.containerInfo), re(t), null;
    case 10:
      return ai(t.type._context), re(t), null;
    case 17:
      return pe(t.type) && Vr(), re(t), null;
    case 19:
      if (F($), o = t.memoizedState, o === null) return re(t), null;
      if (r = (t.flags & 128) !== 0, i = o.rendering, i === null) if (r) yn(o, !1);
      else {
        if (X !== 0 || e !== null && e.flags & 128) for (e = t.child; e !== null; ) {
          if (i = Yr(e), i !== null) {
            for (t.flags |= 128, yn(o, !1), r = i.updateQueue, r !== null && (t.updateQueue = r, t.flags |= 4), t.subtreeFlags = 0, r = n, n = t.child; n !== null; ) o = n, e = r, o.flags &= 14680066, i = o.alternate, i === null ? (o.childLanes = 0, o.lanes = e, o.child = null, o.subtreeFlags = 0, o.memoizedProps = null, o.memoizedState = null, o.updateQueue = null, o.dependencies = null, o.stateNode = null) : (o.childLanes = i.childLanes, o.lanes = i.lanes, o.child = i.child, o.subtreeFlags = 0, o.deletions = null, o.memoizedProps = i.memoizedProps, o.memoizedState = i.memoizedState, o.updateQueue = i.updateQueue, o.type = i.type, e = i.dependencies, o.dependencies = e === null ? null : { lanes: e.lanes, firstContext: e.firstContext }), n = n.sibling;
            return j($, $.current & 1 | 2), t.child;
          }
          e = e.sibling;
        }
        o.tail !== null && Q() > ln && (t.flags |= 128, r = !0, yn(o, !1), t.lanes = 4194304);
      }
      else {
        if (!r) if (e = Yr(i), e !== null) {
          if (t.flags |= 128, r = !0, n = e.updateQueue, n !== null && (t.updateQueue = n, t.flags |= 4), yn(o, !0), o.tail === null && o.tailMode === "hidden" && !i.alternate && !U) return re(t), null;
        } else 2 * Q() - o.renderingStartTime > ln && n !== 1073741824 && (t.flags |= 128, r = !0, yn(o, !1), t.lanes = 4194304);
        o.isBackwards ? (i.sibling = t.child, t.child = i) : (n = o.last, n !== null ? n.sibling = i : t.child = i, o.last = i);
      }
      return o.tail !== null ? (t = o.tail, o.rendering = t, o.tail = t.sibling, o.renderingStartTime = Q(), t.sibling = null, n = $.current, j($, r ? n & 1 | 2 : n & 1), t) : (re(t), null);
    case 22:
    case 23:
      return Ni(), r = t.memoizedState !== null, e !== null && e.memoizedState !== null !== r && (t.flags |= 8192), r && t.mode & 1 ? ve & 1073741824 && (re(t), t.subtreeFlags & 6 && (t.flags |= 8192)) : re(t), null;
    case 24:
      return null;
    case 25:
      return null;
  }
  throw Error(y(156, t.tag));
}
function ld(e, t) {
  switch (oi(t), t.tag) {
    case 1:
      return pe(t.type) && Vr(), e = t.flags, e & 65536 ? (t.flags = e & -65537 | 128, t) : null;
    case 3:
      return nn(), F(de), F(oe), mi(), e = t.flags, e & 65536 && !(e & 128) ? (t.flags = e & -65537 | 128, t) : null;
    case 5:
      return pi(t), null;
    case 13:
      if (F($), e = t.memoizedState, e !== null && e.dehydrated !== null) {
        if (t.alternate === null) throw Error(y(340));
        en();
      }
      return e = t.flags, e & 65536 ? (t.flags = e & -65537 | 128, t) : null;
    case 19:
      return F($), null;
    case 4:
      return nn(), null;
    case 10:
      return ai(t.type._context), null;
    case 22:
    case 23:
      return Ni(), null;
    case 24:
      return null;
    default:
      return null;
  }
}
var hr = !1, le = !1, od = typeof WeakSet == "function" ? WeakSet : Set, x = null;
function Ht(e, t) {
  var n = e.ref;
  if (n !== null) if (typeof n == "function") try {
    n(null);
  } catch (r) {
    B(e, t, r);
  }
  else n.current = null;
}
function To(e, t, n) {
  try {
    n();
  } catch (r) {
    B(e, t, r);
  }
}
var Mu = !1;
function id(e, t) {
  if (po = Ir, e = Vs(), ri(e)) {
    if ("selectionStart" in e) var n = { start: e.selectionStart, end: e.selectionEnd };
    else e: {
      n = (n = e.ownerDocument) && n.defaultView || window;
      var r = n.getSelection && n.getSelection();
      if (r && r.rangeCount !== 0) {
        n = r.anchorNode;
        var l = r.anchorOffset, o = r.focusNode;
        r = r.focusOffset;
        try {
          n.nodeType, o.nodeType;
        } catch {
          n = null;
          break e;
        }
        var i = 0, u = -1, s = -1, f = 0, v = 0, m = e, p = null;
        t: for (; ; ) {
          for (var w; m !== n || l !== 0 && m.nodeType !== 3 || (u = i + l), m !== o || r !== 0 && m.nodeType !== 3 || (s = i + r), m.nodeType === 3 && (i += m.nodeValue.length), (w = m.firstChild) !== null; )
            p = m, m = w;
          for (; ; ) {
            if (m === e) break t;
            if (p === n && ++f === l && (u = i), p === o && ++v === r && (s = i), (w = m.nextSibling) !== null) break;
            m = p, p = m.parentNode;
          }
          m = w;
        }
        n = u === -1 || s === -1 ? null : { start: u, end: s };
      } else n = null;
    }
    n = n || { start: 0, end: 0 };
  } else n = null;
  for (mo = { focusedElem: e, selectionRange: n }, Ir = !1, x = t; x !== null; ) if (t = x, e = t.child, (t.subtreeFlags & 1028) !== 0 && e !== null) e.return = t, x = e;
  else for (; x !== null; ) {
    t = x;
    try {
      var S = t.alternate;
      if (t.flags & 1024) switch (t.tag) {
        case 0:
        case 11:
        case 15:
          break;
        case 1:
          if (S !== null) {
            var g = S.memoizedProps, D = S.memoizedState, c = t.stateNode, a = c.getSnapshotBeforeUpdate(t.elementType === t.type ? g : Le(t.type, g), D);
            c.__reactInternalSnapshotBeforeUpdate = a;
          }
          break;
        case 3:
          var d = t.stateNode.containerInfo;
          d.nodeType === 1 ? d.textContent = "" : d.nodeType === 9 && d.documentElement && d.removeChild(d.documentElement);
          break;
        case 5:
        case 6:
        case 4:
        case 17:
          break;
        default:
          throw Error(y(163));
      }
    } catch (h) {
      B(t, t.return, h);
    }
    if (e = t.sibling, e !== null) {
      e.return = t.return, x = e;
      break;
    }
    x = t.return;
  }
  return S = Mu, Mu = !1, S;
}
function Ln(e, t, n) {
  var r = t.updateQueue;
  if (r = r !== null ? r.lastEffect : null, r !== null) {
    var l = r = r.next;
    do {
      if ((l.tag & e) === e) {
        var o = l.destroy;
        l.destroy = void 0, o !== void 0 && To(t, n, o);
      }
      l = l.next;
    } while (l !== r);
  }
}
function al(e, t) {
  if (t = t.updateQueue, t = t !== null ? t.lastEffect : null, t !== null) {
    var n = t = t.next;
    do {
      if ((n.tag & e) === e) {
        var r = n.create;
        n.destroy = r();
      }
      n = n.next;
    } while (n !== t);
  }
}
function Mo(e) {
  var t = e.ref;
  if (t !== null) {
    var n = e.stateNode;
    switch (e.tag) {
      case 5:
        e = n;
        break;
      default:
        e = n;
    }
    typeof t == "function" ? t(e) : t.current = e;
  }
}
function Ia(e) {
  var t = e.alternate;
  t !== null && (e.alternate = null, Ia(t)), e.child = null, e.deletions = null, e.sibling = null, e.tag === 5 && (t = e.stateNode, t !== null && (delete t[Fe], delete t[Bn], delete t[yo], delete t[Bf], delete t[Wf])), e.stateNode = null, e.return = null, e.dependencies = null, e.memoizedProps = null, e.memoizedState = null, e.pendingProps = null, e.stateNode = null, e.updateQueue = null;
}
function Fa(e) {
  return e.tag === 5 || e.tag === 3 || e.tag === 4;
}
function Ru(e) {
  e: for (; ; ) {
    for (; e.sibling === null; ) {
      if (e.return === null || Fa(e.return)) return null;
      e = e.return;
    }
    for (e.sibling.return = e.return, e = e.sibling; e.tag !== 5 && e.tag !== 6 && e.tag !== 18; ) {
      if (e.flags & 2 || e.child === null || e.tag === 4) continue e;
      e.child.return = e, e = e.child;
    }
    if (!(e.flags & 2)) return e.stateNode;
  }
}
function Ro(e, t, n) {
  var r = e.tag;
  if (r === 5 || r === 6) e = e.stateNode, t ? n.nodeType === 8 ? n.parentNode.insertBefore(e, t) : n.insertBefore(e, t) : (n.nodeType === 8 ? (t = n.parentNode, t.insertBefore(e, n)) : (t = n, t.appendChild(e)), n = n._reactRootContainer, n != null || t.onclick !== null || (t.onclick = $r));
  else if (r !== 4 && (e = e.child, e !== null)) for (Ro(e, t, n), e = e.sibling; e !== null; ) Ro(e, t, n), e = e.sibling;
}
function Do(e, t, n) {
  var r = e.tag;
  if (r === 5 || r === 6) e = e.stateNode, t ? n.insertBefore(e, t) : n.appendChild(e);
  else if (r !== 4 && (e = e.child, e !== null)) for (Do(e, t, n), e = e.sibling; e !== null; ) Do(e, t, n), e = e.sibling;
}
var b = null, Te = !1;
function Ze(e, t, n) {
  for (n = n.child; n !== null; ) Ua(e, t, n), n = n.sibling;
}
function Ua(e, t, n) {
  if (Ue && typeof Ue.onCommitFiberUnmount == "function") try {
    Ue.onCommitFiberUnmount(tl, n);
  } catch {
  }
  switch (n.tag) {
    case 5:
      le || Ht(n, t);
    case 6:
      var r = b, l = Te;
      b = null, Ze(e, t, n), b = r, Te = l, b !== null && (Te ? (e = b, n = n.stateNode, e.nodeType === 8 ? e.parentNode.removeChild(n) : e.removeChild(n)) : b.removeChild(n.stateNode));
      break;
    case 18:
      b !== null && (Te ? (e = b, n = n.stateNode, e.nodeType === 8 ? jl(e.parentNode, n) : e.nodeType === 1 && jl(e, n), Fn(e)) : jl(b, n.stateNode));
      break;
    case 4:
      r = b, l = Te, b = n.stateNode.containerInfo, Te = !0, Ze(e, t, n), b = r, Te = l;
      break;
    case 0:
    case 11:
    case 14:
    case 15:
      if (!le && (r = n.updateQueue, r !== null && (r = r.lastEffect, r !== null))) {
        l = r = r.next;
        do {
          var o = l, i = o.destroy;
          o = o.tag, i !== void 0 && (o & 2 || o & 4) && To(n, t, i), l = l.next;
        } while (l !== r);
      }
      Ze(e, t, n);
      break;
    case 1:
      if (!le && (Ht(n, t), r = n.stateNode, typeof r.componentWillUnmount == "function")) try {
        r.props = n.memoizedProps, r.state = n.memoizedState, r.componentWillUnmount();
      } catch (u) {
        B(n, t, u);
      }
      Ze(e, t, n);
      break;
    case 21:
      Ze(e, t, n);
      break;
    case 22:
      n.mode & 1 ? (le = (r = le) || n.memoizedState !== null, Ze(e, t, n), le = r) : Ze(e, t, n);
      break;
    default:
      Ze(e, t, n);
  }
}
function Du(e) {
  var t = e.updateQueue;
  if (t !== null) {
    e.updateQueue = null;
    var n = e.stateNode;
    n === null && (n = e.stateNode = new od()), t.forEach(function(r) {
      var l = vd.bind(null, e, r);
      n.has(r) || (n.add(r), r.then(l, l));
    });
  }
}
function ze(e, t) {
  var n = t.deletions;
  if (n !== null) for (var r = 0; r < n.length; r++) {
    var l = n[r];
    try {
      var o = e, i = t, u = i;
      e: for (; u !== null; ) {
        switch (u.tag) {
          case 5:
            b = u.stateNode, Te = !1;
            break e;
          case 3:
            b = u.stateNode.containerInfo, Te = !0;
            break e;
          case 4:
            b = u.stateNode.containerInfo, Te = !0;
            break e;
        }
        u = u.return;
      }
      if (b === null) throw Error(y(160));
      Ua(o, i, l), b = null, Te = !1;
      var s = l.alternate;
      s !== null && (s.return = null), l.return = null;
    } catch (f) {
      B(l, t, f);
    }
  }
  if (t.subtreeFlags & 12854) for (t = t.child; t !== null; ) $a(t, e), t = t.sibling;
}
function $a(e, t) {
  var n = e.alternate, r = e.flags;
  switch (e.tag) {
    case 0:
    case 11:
    case 14:
    case 15:
      if (ze(t, e), je(e), r & 4) {
        try {
          Ln(3, e, e.return), al(3, e);
        } catch (g) {
          B(e, e.return, g);
        }
        try {
          Ln(5, e, e.return);
        } catch (g) {
          B(e, e.return, g);
        }
      }
      break;
    case 1:
      ze(t, e), je(e), r & 512 && n !== null && Ht(n, n.return);
      break;
    case 5:
      if (ze(t, e), je(e), r & 512 && n !== null && Ht(n, n.return), e.flags & 32) {
        var l = e.stateNode;
        try {
          Dn(l, "");
        } catch (g) {
          B(e, e.return, g);
        }
      }
      if (r & 4 && (l = e.stateNode, l != null)) {
        var o = e.memoizedProps, i = n !== null ? n.memoizedProps : o, u = e.type, s = e.updateQueue;
        if (e.updateQueue = null, s !== null) try {
          u === "input" && o.type === "radio" && o.name != null && us(l, o), no(u, i);
          var f = no(u, o);
          for (i = 0; i < s.length; i += 2) {
            var v = s[i], m = s[i + 1];
            v === "style" ? ds(l, m) : v === "dangerouslySetInnerHTML" ? cs(l, m) : v === "children" ? Dn(l, m) : Ho(l, v, m, f);
          }
          switch (u) {
            case "input":
              Jl(l, o);
              break;
            case "textarea":
              ss(l, o);
              break;
            case "select":
              var p = l._wrapperState.wasMultiple;
              l._wrapperState.wasMultiple = !!o.multiple;
              var w = o.value;
              w != null ? Kt(l, !!o.multiple, w, !1) : p !== !!o.multiple && (o.defaultValue != null ? Kt(
                l,
                !!o.multiple,
                o.defaultValue,
                !0
              ) : Kt(l, !!o.multiple, o.multiple ? [] : "", !1));
          }
          l[Bn] = o;
        } catch (g) {
          B(e, e.return, g);
        }
      }
      break;
    case 6:
      if (ze(t, e), je(e), r & 4) {
        if (e.stateNode === null) throw Error(y(162));
        l = e.stateNode, o = e.memoizedProps;
        try {
          l.nodeValue = o;
        } catch (g) {
          B(e, e.return, g);
        }
      }
      break;
    case 3:
      if (ze(t, e), je(e), r & 4 && n !== null && n.memoizedState.isDehydrated) try {
        Fn(t.containerInfo);
      } catch (g) {
        B(e, e.return, g);
      }
      break;
    case 4:
      ze(t, e), je(e);
      break;
    case 13:
      ze(t, e), je(e), l = e.child, l.flags & 8192 && (o = l.memoizedState !== null, l.stateNode.isHidden = o, !o || l.alternate !== null && l.alternate.memoizedState !== null || (xi = Q())), r & 4 && Du(e);
      break;
    case 22:
      if (v = n !== null && n.memoizedState !== null, e.mode & 1 ? (le = (f = le) || v, ze(t, e), le = f) : ze(t, e), je(e), r & 8192) {
        if (f = e.memoizedState !== null, (e.stateNode.isHidden = f) && !v && e.mode & 1) for (x = e, v = e.child; v !== null; ) {
          for (m = x = v; x !== null; ) {
            switch (p = x, w = p.child, p.tag) {
              case 0:
              case 11:
              case 14:
              case 15:
                Ln(4, p, p.return);
                break;
              case 1:
                Ht(p, p.return);
                var S = p.stateNode;
                if (typeof S.componentWillUnmount == "function") {
                  r = p, n = p.return;
                  try {
                    t = r, S.props = t.memoizedProps, S.state = t.memoizedState, S.componentWillUnmount();
                  } catch (g) {
                    B(r, n, g);
                  }
                }
                break;
              case 5:
                Ht(p, p.return);
                break;
              case 22:
                if (p.memoizedState !== null) {
                  ju(m);
                  continue;
                }
            }
            w !== null ? (w.return = p, x = w) : ju(m);
          }
          v = v.sibling;
        }
        e: for (v = null, m = e; ; ) {
          if (m.tag === 5) {
            if (v === null) {
              v = m;
              try {
                l = m.stateNode, f ? (o = l.style, typeof o.setProperty == "function" ? o.setProperty("display", "none", "important") : o.display = "none") : (u = m.stateNode, s = m.memoizedProps.style, i = s != null && s.hasOwnProperty("display") ? s.display : null, u.style.display = fs("display", i));
              } catch (g) {
                B(e, e.return, g);
              }
            }
          } else if (m.tag === 6) {
            if (v === null) try {
              m.stateNode.nodeValue = f ? "" : m.memoizedProps;
            } catch (g) {
              B(e, e.return, g);
            }
          } else if ((m.tag !== 22 && m.tag !== 23 || m.memoizedState === null || m === e) && m.child !== null) {
            m.child.return = m, m = m.child;
            continue;
          }
          if (m === e) break e;
          for (; m.sibling === null; ) {
            if (m.return === null || m.return === e) break e;
            v === m && (v = null), m = m.return;
          }
          v === m && (v = null), m.sibling.return = m.return, m = m.sibling;
        }
      }
      break;
    case 19:
      ze(t, e), je(e), r & 4 && Du(e);
      break;
    case 21:
      break;
    default:
      ze(
        t,
        e
      ), je(e);
  }
}
function je(e) {
  var t = e.flags;
  if (t & 2) {
    try {
      e: {
        for (var n = e.return; n !== null; ) {
          if (Fa(n)) {
            var r = n;
            break e;
          }
          n = n.return;
        }
        throw Error(y(160));
      }
      switch (r.tag) {
        case 5:
          var l = r.stateNode;
          r.flags & 32 && (Dn(l, ""), r.flags &= -33);
          var o = Ru(e);
          Do(e, o, l);
          break;
        case 3:
        case 4:
          var i = r.stateNode.containerInfo, u = Ru(e);
          Ro(e, u, i);
          break;
        default:
          throw Error(y(161));
      }
    } catch (s) {
      B(e, e.return, s);
    }
    e.flags &= -3;
  }
  t & 4096 && (e.flags &= -4097);
}
function ud(e, t, n) {
  x = e, Va(e);
}
function Va(e, t, n) {
  for (var r = (e.mode & 1) !== 0; x !== null; ) {
    var l = x, o = l.child;
    if (l.tag === 22 && r) {
      var i = l.memoizedState !== null || hr;
      if (!i) {
        var u = l.alternate, s = u !== null && u.memoizedState !== null || le;
        u = hr;
        var f = le;
        if (hr = i, (le = s) && !f) for (x = l; x !== null; ) i = x, s = i.child, i.tag === 22 && i.memoizedState !== null ? Iu(l) : s !== null ? (s.return = i, x = s) : Iu(l);
        for (; o !== null; ) x = o, Va(o), o = o.sibling;
        x = l, hr = u, le = f;
      }
      Ou(e);
    } else l.subtreeFlags & 8772 && o !== null ? (o.return = l, x = o) : Ou(e);
  }
}
function Ou(e) {
  for (; x !== null; ) {
    var t = x;
    if (t.flags & 8772) {
      var n = t.alternate;
      try {
        if (t.flags & 8772) switch (t.tag) {
          case 0:
          case 11:
          case 15:
            le || al(5, t);
            break;
          case 1:
            var r = t.stateNode;
            if (t.flags & 4 && !le) if (n === null) r.componentDidMount();
            else {
              var l = t.elementType === t.type ? n.memoizedProps : Le(t.type, n.memoizedProps);
              r.componentDidUpdate(l, n.memoizedState, r.__reactInternalSnapshotBeforeUpdate);
            }
            var o = t.updateQueue;
            o !== null && gu(t, o, r);
            break;
          case 3:
            var i = t.updateQueue;
            if (i !== null) {
              if (n = null, t.child !== null) switch (t.child.tag) {
                case 5:
                  n = t.child.stateNode;
                  break;
                case 1:
                  n = t.child.stateNode;
              }
              gu(t, i, n);
            }
            break;
          case 5:
            var u = t.stateNode;
            if (n === null && t.flags & 4) {
              n = u;
              var s = t.memoizedProps;
              switch (t.type) {
                case "button":
                case "input":
                case "select":
                case "textarea":
                  s.autoFocus && n.focus();
                  break;
                case "img":
                  s.src && (n.src = s.src);
              }
            }
            break;
          case 6:
            break;
          case 4:
            break;
          case 12:
            break;
          case 13:
            if (t.memoizedState === null) {
              var f = t.alternate;
              if (f !== null) {
                var v = f.memoizedState;
                if (v !== null) {
                  var m = v.dehydrated;
                  m !== null && Fn(m);
                }
              }
            }
            break;
          case 19:
          case 17:
          case 21:
          case 22:
          case 23:
          case 25:
            break;
          default:
            throw Error(y(163));
        }
        le || t.flags & 512 && Mo(t);
      } catch (p) {
        B(t, t.return, p);
      }
    }
    if (t === e) {
      x = null;
      break;
    }
    if (n = t.sibling, n !== null) {
      n.return = t.return, x = n;
      break;
    }
    x = t.return;
  }
}
function ju(e) {
  for (; x !== null; ) {
    var t = x;
    if (t === e) {
      x = null;
      break;
    }
    var n = t.sibling;
    if (n !== null) {
      n.return = t.return, x = n;
      break;
    }
    x = t.return;
  }
}
function Iu(e) {
  for (; x !== null; ) {
    var t = x;
    try {
      switch (t.tag) {
        case 0:
        case 11:
        case 15:
          var n = t.return;
          try {
            al(4, t);
          } catch (s) {
            B(t, n, s);
          }
          break;
        case 1:
          var r = t.stateNode;
          if (typeof r.componentDidMount == "function") {
            var l = t.return;
            try {
              r.componentDidMount();
            } catch (s) {
              B(t, l, s);
            }
          }
          var o = t.return;
          try {
            Mo(t);
          } catch (s) {
            B(t, o, s);
          }
          break;
        case 5:
          var i = t.return;
          try {
            Mo(t);
          } catch (s) {
            B(t, i, s);
          }
      }
    } catch (s) {
      B(t, t.return, s);
    }
    if (t === e) {
      x = null;
      break;
    }
    var u = t.sibling;
    if (u !== null) {
      u.return = t.return, x = u;
      break;
    }
    x = t.return;
  }
}
var sd = Math.ceil, Zr = Ge.ReactCurrentDispatcher, ki = Ge.ReactCurrentOwner, Ce = Ge.ReactCurrentBatchConfig, R = 0, q = null, K = null, ee = 0, ve = 0, Qt = mt(0), X = 0, Xn = null, zt = 0, cl = 0, Ei = 0, Tn = null, ce = null, xi = 0, ln = 1 / 0, Ve = null, Jr = !1, Oo = null, st = null, yr = !1, nt = null, qr = 0, Mn = 0, jo = null, zr = -1, Lr = 0;
function ue() {
  return R & 6 ? Q() : zr !== -1 ? zr : zr = Q();
}
function at(e) {
  return e.mode & 1 ? R & 2 && ee !== 0 ? ee & -ee : Qf.transition !== null ? (Lr === 0 && (Lr = Cs()), Lr) : (e = O, e !== 0 || (e = window.event, e = e === void 0 ? 16 : Ms(e.type)), e) : 1;
}
function De(e, t, n, r) {
  if (50 < Mn) throw Mn = 0, jo = null, Error(y(185));
  Zn(e, n, r), (!(R & 2) || e !== q) && (e === q && (!(R & 2) && (cl |= n), X === 4 && et(e, ee)), me(e, r), n === 1 && R === 0 && !(t.mode & 1) && (ln = Q() + 500, il && vt()));
}
function me(e, t) {
  var n = e.callbackNode;
  Hc(e, t);
  var r = jr(e, e === q ? ee : 0);
  if (r === 0) n !== null && Qi(n), e.callbackNode = null, e.callbackPriority = 0;
  else if (t = r & -r, e.callbackPriority !== t) {
    if (n != null && Qi(n), t === 1) e.tag === 0 ? Hf(Fu.bind(null, e)) : Zs(Fu.bind(null, e)), Vf(function() {
      !(R & 6) && vt();
    }), n = null;
    else {
      switch (Ns(r)) {
        case 1:
          n = Go;
          break;
        case 4:
          n = Es;
          break;
        case 16:
          n = Or;
          break;
        case 536870912:
          n = xs;
          break;
        default:
          n = Or;
      }
      n = Xa(n, Aa.bind(null, e));
    }
    e.callbackPriority = t, e.callbackNode = n;
  }
}
function Aa(e, t) {
  if (zr = -1, Lr = 0, R & 6) throw Error(y(327));
  var n = e.callbackNode;
  if (Jt() && e.callbackNode !== n) return null;
  var r = jr(e, e === q ? ee : 0);
  if (r === 0) return null;
  if (r & 30 || r & e.expiredLanes || t) t = br(e, r);
  else {
    t = r;
    var l = R;
    R |= 2;
    var o = Wa();
    (q !== e || ee !== t) && (Ve = null, ln = Q() + 500, xt(e, t));
    do
      try {
        fd();
        break;
      } catch (u) {
        Ba(e, u);
      }
    while (!0);
    si(), Zr.current = o, R = l, K !== null ? t = 0 : (q = null, ee = 0, t = X);
  }
  if (t !== 0) {
    if (t === 2 && (l = uo(e), l !== 0 && (r = l, t = Io(e, l))), t === 1) throw n = Xn, xt(e, 0), et(e, r), me(e, Q()), n;
    if (t === 6) et(e, r);
    else {
      if (l = e.current.alternate, !(r & 30) && !ad(l) && (t = br(e, r), t === 2 && (o = uo(e), o !== 0 && (r = o, t = Io(e, o))), t === 1)) throw n = Xn, xt(e, 0), et(e, r), me(e, Q()), n;
      switch (e.finishedWork = l, e.finishedLanes = r, t) {
        case 0:
        case 1:
          throw Error(y(345));
        case 2:
          wt(e, ce, Ve);
          break;
        case 3:
          if (et(e, r), (r & 130023424) === r && (t = xi + 500 - Q(), 10 < t)) {
            if (jr(e, 0) !== 0) break;
            if (l = e.suspendedLanes, (l & r) !== r) {
              ue(), e.pingedLanes |= e.suspendedLanes & l;
              break;
            }
            e.timeoutHandle = ho(wt.bind(null, e, ce, Ve), t);
            break;
          }
          wt(e, ce, Ve);
          break;
        case 4:
          if (et(e, r), (r & 4194240) === r) break;
          for (t = e.eventTimes, l = -1; 0 < r; ) {
            var i = 31 - Re(r);
            o = 1 << i, i = t[i], i > l && (l = i), r &= ~o;
          }
          if (r = l, r = Q() - r, r = (120 > r ? 120 : 480 > r ? 480 : 1080 > r ? 1080 : 1920 > r ? 1920 : 3e3 > r ? 3e3 : 4320 > r ? 4320 : 1960 * sd(r / 1960)) - r, 10 < r) {
            e.timeoutHandle = ho(wt.bind(null, e, ce, Ve), r);
            break;
          }
          wt(e, ce, Ve);
          break;
        case 5:
          wt(e, ce, Ve);
          break;
        default:
          throw Error(y(329));
      }
    }
  }
  return me(e, Q()), e.callbackNode === n ? Aa.bind(null, e) : null;
}
function Io(e, t) {
  var n = Tn;
  return e.current.memoizedState.isDehydrated && (xt(e, t).flags |= 256), e = br(e, t), e !== 2 && (t = ce, ce = n, t !== null && Fo(t)), e;
}
function Fo(e) {
  ce === null ? ce = e : ce.push.apply(ce, e);
}
function ad(e) {
  for (var t = e; ; ) {
    if (t.flags & 16384) {
      var n = t.updateQueue;
      if (n !== null && (n = n.stores, n !== null)) for (var r = 0; r < n.length; r++) {
        var l = n[r], o = l.getSnapshot;
        l = l.value;
        try {
          if (!Oe(o(), l)) return !1;
        } catch {
          return !1;
        }
      }
    }
    if (n = t.child, t.subtreeFlags & 16384 && n !== null) n.return = t, t = n;
    else {
      if (t === e) break;
      for (; t.sibling === null; ) {
        if (t.return === null || t.return === e) return !0;
        t = t.return;
      }
      t.sibling.return = t.return, t = t.sibling;
    }
  }
  return !0;
}
function et(e, t) {
  for (t &= ~Ei, t &= ~cl, e.suspendedLanes |= t, e.pingedLanes &= ~t, e = e.expirationTimes; 0 < t; ) {
    var n = 31 - Re(t), r = 1 << n;
    e[n] = -1, t &= ~r;
  }
}
function Fu(e) {
  if (R & 6) throw Error(y(327));
  Jt();
  var t = jr(e, 0);
  if (!(t & 1)) return me(e, Q()), null;
  var n = br(e, t);
  if (e.tag !== 0 && n === 2) {
    var r = uo(e);
    r !== 0 && (t = r, n = Io(e, r));
  }
  if (n === 1) throw n = Xn, xt(e, 0), et(e, t), me(e, Q()), n;
  if (n === 6) throw Error(y(345));
  return e.finishedWork = e.current.alternate, e.finishedLanes = t, wt(e, ce, Ve), me(e, Q()), null;
}
function Ci(e, t) {
  var n = R;
  R |= 1;
  try {
    return e(t);
  } finally {
    R = n, R === 0 && (ln = Q() + 500, il && vt());
  }
}
function Lt(e) {
  nt !== null && nt.tag === 0 && !(R & 6) && Jt();
  var t = R;
  R |= 1;
  var n = Ce.transition, r = O;
  try {
    if (Ce.transition = null, O = 1, e) return e();
  } finally {
    O = r, Ce.transition = n, R = t, !(R & 6) && vt();
  }
}
function Ni() {
  ve = Qt.current, F(Qt);
}
function xt(e, t) {
  e.finishedWork = null, e.finishedLanes = 0;
  var n = e.timeoutHandle;
  if (n !== -1 && (e.timeoutHandle = -1, $f(n)), K !== null) for (n = K.return; n !== null; ) {
    var r = n;
    switch (oi(r), r.tag) {
      case 1:
        r = r.type.childContextTypes, r != null && Vr();
        break;
      case 3:
        nn(), F(de), F(oe), mi();
        break;
      case 5:
        pi(r);
        break;
      case 4:
        nn();
        break;
      case 13:
        F($);
        break;
      case 19:
        F($);
        break;
      case 10:
        ai(r.type._context);
        break;
      case 22:
      case 23:
        Ni();
    }
    n = n.return;
  }
  if (q = e, K = e = ct(e.current, null), ee = ve = t, X = 0, Xn = null, Ei = cl = zt = 0, ce = Tn = null, kt !== null) {
    for (t = 0; t < kt.length; t++) if (n = kt[t], r = n.interleaved, r !== null) {
      n.interleaved = null;
      var l = r.next, o = n.pending;
      if (o !== null) {
        var i = o.next;
        o.next = l, r.next = i;
      }
      n.pending = r;
    }
    kt = null;
  }
  return e;
}
function Ba(e, t) {
  do {
    var n = K;
    try {
      if (si(), Nr.current = Gr, Xr) {
        for (var r = V.memoizedState; r !== null; ) {
          var l = r.queue;
          l !== null && (l.pending = null), r = r.next;
        }
        Xr = !1;
      }
      if (Pt = 0, Z = Y = V = null, zn = !1, Qn = 0, ki.current = null, n === null || n.return === null) {
        X = 1, Xn = t, K = null;
        break;
      }
      e: {
        var o = e, i = n.return, u = n, s = t;
        if (t = ee, u.flags |= 32768, s !== null && typeof s == "object" && typeof s.then == "function") {
          var f = s, v = u, m = v.tag;
          if (!(v.mode & 1) && (m === 0 || m === 11 || m === 15)) {
            var p = v.alternate;
            p ? (v.updateQueue = p.updateQueue, v.memoizedState = p.memoizedState, v.lanes = p.lanes) : (v.updateQueue = null, v.memoizedState = null);
          }
          var w = Cu(i);
          if (w !== null) {
            w.flags &= -257, Nu(w, i, u, o, t), w.mode & 1 && xu(o, f, t), t = w, s = f;
            var S = t.updateQueue;
            if (S === null) {
              var g = /* @__PURE__ */ new Set();
              g.add(s), t.updateQueue = g;
            } else S.add(s);
            break e;
          } else {
            if (!(t & 1)) {
              xu(o, f, t), _i();
              break e;
            }
            s = Error(y(426));
          }
        } else if (U && u.mode & 1) {
          var D = Cu(i);
          if (D !== null) {
            !(D.flags & 65536) && (D.flags |= 256), Nu(D, i, u, o, t), ii(rn(s, u));
            break e;
          }
        }
        o = s = rn(s, u), X !== 4 && (X = 2), Tn === null ? Tn = [o] : Tn.push(o), o = i;
        do {
          switch (o.tag) {
            case 3:
              o.flags |= 65536, t &= -t, o.lanes |= t;
              var c = Na(o, s, t);
              yu(o, c);
              break e;
            case 1:
              u = s;
              var a = o.type, d = o.stateNode;
              if (!(o.flags & 128) && (typeof a.getDerivedStateFromError == "function" || d !== null && typeof d.componentDidCatch == "function" && (st === null || !st.has(d)))) {
                o.flags |= 65536, t &= -t, o.lanes |= t;
                var h = _a(o, u, t);
                yu(o, h);
                break e;
              }
          }
          o = o.return;
        } while (o !== null);
      }
      Qa(n);
    } catch (E) {
      t = E, K === n && n !== null && (K = n = n.return);
      continue;
    }
    break;
  } while (!0);
}
function Wa() {
  var e = Zr.current;
  return Zr.current = Gr, e === null ? Gr : e;
}
function _i() {
  (X === 0 || X === 3 || X === 2) && (X = 4), q === null || !(zt & 268435455) && !(cl & 268435455) || et(q, ee);
}
function br(e, t) {
  var n = R;
  R |= 2;
  var r = Wa();
  (q !== e || ee !== t) && (Ve = null, xt(e, t));
  do
    try {
      cd();
      break;
    } catch (l) {
      Ba(e, l);
    }
  while (!0);
  if (si(), R = n, Zr.current = r, K !== null) throw Error(y(261));
  return q = null, ee = 0, X;
}
function cd() {
  for (; K !== null; ) Ha(K);
}
function fd() {
  for (; K !== null && !jc(); ) Ha(K);
}
function Ha(e) {
  var t = Ya(e.alternate, e, ve);
  e.memoizedProps = e.pendingProps, t === null ? Qa(e) : K = t, ki.current = null;
}
function Qa(e) {
  var t = e;
  do {
    var n = t.alternate;
    if (e = t.return, t.flags & 32768) {
      if (n = ld(n, t), n !== null) {
        n.flags &= 32767, K = n;
        return;
      }
      if (e !== null) e.flags |= 32768, e.subtreeFlags = 0, e.deletions = null;
      else {
        X = 6, K = null;
        return;
      }
    } else if (n = rd(n, t, ve), n !== null) {
      K = n;
      return;
    }
    if (t = t.sibling, t !== null) {
      K = t;
      return;
    }
    K = t = e;
  } while (t !== null);
  X === 0 && (X = 5);
}
function wt(e, t, n) {
  var r = O, l = Ce.transition;
  try {
    Ce.transition = null, O = 1, dd(e, t, n, r);
  } finally {
    Ce.transition = l, O = r;
  }
  return null;
}
function dd(e, t, n, r) {
  do
    Jt();
  while (nt !== null);
  if (R & 6) throw Error(y(327));
  n = e.finishedWork;
  var l = e.finishedLanes;
  if (n === null) return null;
  if (e.finishedWork = null, e.finishedLanes = 0, n === e.current) throw Error(y(177));
  e.callbackNode = null, e.callbackPriority = 0;
  var o = n.lanes | n.childLanes;
  if (Qc(e, o), e === q && (K = q = null, ee = 0), !(n.subtreeFlags & 2064) && !(n.flags & 2064) || yr || (yr = !0, Xa(Or, function() {
    return Jt(), null;
  })), o = (n.flags & 15990) !== 0, n.subtreeFlags & 15990 || o) {
    o = Ce.transition, Ce.transition = null;
    var i = O;
    O = 1;
    var u = R;
    R |= 4, ki.current = null, id(e, n), $a(n, e), Rf(mo), Ir = !!po, mo = po = null, e.current = n, ud(n), Ic(), R = u, O = i, Ce.transition = o;
  } else e.current = n;
  if (yr && (yr = !1, nt = e, qr = l), o = e.pendingLanes, o === 0 && (st = null), $c(n.stateNode), me(e, Q()), t !== null) for (r = e.onRecoverableError, n = 0; n < t.length; n++) l = t[n], r(l.value, { componentStack: l.stack, digest: l.digest });
  if (Jr) throw Jr = !1, e = Oo, Oo = null, e;
  return qr & 1 && e.tag !== 0 && Jt(), o = e.pendingLanes, o & 1 ? e === jo ? Mn++ : (Mn = 0, jo = e) : Mn = 0, vt(), null;
}
function Jt() {
  if (nt !== null) {
    var e = Ns(qr), t = Ce.transition, n = O;
    try {
      if (Ce.transition = null, O = 16 > e ? 16 : e, nt === null) var r = !1;
      else {
        if (e = nt, nt = null, qr = 0, R & 6) throw Error(y(331));
        var l = R;
        for (R |= 4, x = e.current; x !== null; ) {
          var o = x, i = o.child;
          if (x.flags & 16) {
            var u = o.deletions;
            if (u !== null) {
              for (var s = 0; s < u.length; s++) {
                var f = u[s];
                for (x = f; x !== null; ) {
                  var v = x;
                  switch (v.tag) {
                    case 0:
                    case 11:
                    case 15:
                      Ln(8, v, o);
                  }
                  var m = v.child;
                  if (m !== null) m.return = v, x = m;
                  else for (; x !== null; ) {
                    v = x;
                    var p = v.sibling, w = v.return;
                    if (Ia(v), v === f) {
                      x = null;
                      break;
                    }
                    if (p !== null) {
                      p.return = w, x = p;
                      break;
                    }
                    x = w;
                  }
                }
              }
              var S = o.alternate;
              if (S !== null) {
                var g = S.child;
                if (g !== null) {
                  S.child = null;
                  do {
                    var D = g.sibling;
                    g.sibling = null, g = D;
                  } while (g !== null);
                }
              }
              x = o;
            }
          }
          if (o.subtreeFlags & 2064 && i !== null) i.return = o, x = i;
          else e: for (; x !== null; ) {
            if (o = x, o.flags & 2048) switch (o.tag) {
              case 0:
              case 11:
              case 15:
                Ln(9, o, o.return);
            }
            var c = o.sibling;
            if (c !== null) {
              c.return = o.return, x = c;
              break e;
            }
            x = o.return;
          }
        }
        var a = e.current;
        for (x = a; x !== null; ) {
          i = x;
          var d = i.child;
          if (i.subtreeFlags & 2064 && d !== null) d.return = i, x = d;
          else e: for (i = a; x !== null; ) {
            if (u = x, u.flags & 2048) try {
              switch (u.tag) {
                case 0:
                case 11:
                case 15:
                  al(9, u);
              }
            } catch (E) {
              B(u, u.return, E);
            }
            if (u === i) {
              x = null;
              break e;
            }
            var h = u.sibling;
            if (h !== null) {
              h.return = u.return, x = h;
              break e;
            }
            x = u.return;
          }
        }
        if (R = l, vt(), Ue && typeof Ue.onPostCommitFiberRoot == "function") try {
          Ue.onPostCommitFiberRoot(tl, e);
        } catch {
        }
        r = !0;
      }
      return r;
    } finally {
      O = n, Ce.transition = t;
    }
  }
  return !1;
}
function Uu(e, t, n) {
  t = rn(n, t), t = Na(e, t, 1), e = ut(e, t, 1), t = ue(), e !== null && (Zn(e, 1, t), me(e, t));
}
function B(e, t, n) {
  if (e.tag === 3) Uu(e, e, n);
  else for (; t !== null; ) {
    if (t.tag === 3) {
      Uu(t, e, n);
      break;
    } else if (t.tag === 1) {
      var r = t.stateNode;
      if (typeof t.type.getDerivedStateFromError == "function" || typeof r.componentDidCatch == "function" && (st === null || !st.has(r))) {
        e = rn(n, e), e = _a(t, e, 1), t = ut(t, e, 1), e = ue(), t !== null && (Zn(t, 1, e), me(t, e));
        break;
      }
    }
    t = t.return;
  }
}
function pd(e, t, n) {
  var r = e.pingCache;
  r !== null && r.delete(t), t = ue(), e.pingedLanes |= e.suspendedLanes & n, q === e && (ee & n) === n && (X === 4 || X === 3 && (ee & 130023424) === ee && 500 > Q() - xi ? xt(e, 0) : Ei |= n), me(e, t);
}
function Ka(e, t) {
  t === 0 && (e.mode & 1 ? (t = ur, ur <<= 1, !(ur & 130023424) && (ur = 4194304)) : t = 1);
  var n = ue();
  e = Ye(e, t), e !== null && (Zn(e, t, n), me(e, n));
}
function md(e) {
  var t = e.memoizedState, n = 0;
  t !== null && (n = t.retryLane), Ka(e, n);
}
function vd(e, t) {
  var n = 0;
  switch (e.tag) {
    case 13:
      var r = e.stateNode, l = e.memoizedState;
      l !== null && (n = l.retryLane);
      break;
    case 19:
      r = e.stateNode;
      break;
    default:
      throw Error(y(314));
  }
  r !== null && r.delete(t), Ka(e, n);
}
var Ya;
Ya = function(e, t, n) {
  if (e !== null) if (e.memoizedProps !== t.pendingProps || de.current) fe = !0;
  else {
    if (!(e.lanes & n) && !(t.flags & 128)) return fe = !1, nd(e, t, n);
    fe = !!(e.flags & 131072);
  }
  else fe = !1, U && t.flags & 1048576 && Js(t, Wr, t.index);
  switch (t.lanes = 0, t.tag) {
    case 2:
      var r = t.type;
      Pr(e, t), e = t.pendingProps;
      var l = bt(t, oe.current);
      Zt(t, n), l = hi(null, t, r, e, l, n);
      var o = yi();
      return t.flags |= 1, typeof l == "object" && l !== null && typeof l.render == "function" && l.$$typeof === void 0 ? (t.tag = 1, t.memoizedState = null, t.updateQueue = null, pe(r) ? (o = !0, Ar(t)) : o = !1, t.memoizedState = l.state !== null && l.state !== void 0 ? l.state : null, fi(t), l.updater = sl, t.stateNode = l, l._reactInternals = t, xo(t, r, e, n), t = _o(null, t, r, !0, o, n)) : (t.tag = 0, U && o && li(t), ie(null, t, l, n), t = t.child), t;
    case 16:
      r = t.elementType;
      e: {
        switch (Pr(e, t), e = t.pendingProps, l = r._init, r = l(r._payload), t.type = r, l = t.tag = yd(r), e = Le(r, e), l) {
          case 0:
            t = No(null, t, r, e, n);
            break e;
          case 1:
            t = zu(null, t, r, e, n);
            break e;
          case 11:
            t = _u(null, t, r, e, n);
            break e;
          case 14:
            t = Pu(null, t, r, Le(r.type, e), n);
            break e;
        }
        throw Error(y(
          306,
          r,
          ""
        ));
      }
      return t;
    case 0:
      return r = t.type, l = t.pendingProps, l = t.elementType === r ? l : Le(r, l), No(e, t, r, l, n);
    case 1:
      return r = t.type, l = t.pendingProps, l = t.elementType === r ? l : Le(r, l), zu(e, t, r, l, n);
    case 3:
      e: {
        if (Ta(t), e === null) throw Error(y(387));
        r = t.pendingProps, o = t.memoizedState, l = o.element, ra(e, t), Kr(t, r, null, n);
        var i = t.memoizedState;
        if (r = i.element, o.isDehydrated) if (o = { element: r, isDehydrated: !1, cache: i.cache, pendingSuspenseBoundaries: i.pendingSuspenseBoundaries, transitions: i.transitions }, t.updateQueue.baseState = o, t.memoizedState = o, t.flags & 256) {
          l = rn(Error(y(423)), t), t = Lu(e, t, r, n, l);
          break e;
        } else if (r !== l) {
          l = rn(Error(y(424)), t), t = Lu(e, t, r, n, l);
          break e;
        } else for (he = it(t.stateNode.containerInfo.firstChild), ye = t, U = !0, Me = null, n = ta(t, null, r, n), t.child = n; n; ) n.flags = n.flags & -3 | 4096, n = n.sibling;
        else {
          if (en(), r === l) {
            t = Xe(e, t, n);
            break e;
          }
          ie(e, t, r, n);
        }
        t = t.child;
      }
      return t;
    case 5:
      return la(t), e === null && So(t), r = t.type, l = t.pendingProps, o = e !== null ? e.memoizedProps : null, i = l.children, vo(r, l) ? i = null : o !== null && vo(r, o) && (t.flags |= 32), La(e, t), ie(e, t, i, n), t.child;
    case 6:
      return e === null && So(t), null;
    case 13:
      return Ma(e, t, n);
    case 4:
      return di(t, t.stateNode.containerInfo), r = t.pendingProps, e === null ? t.child = tn(t, null, r, n) : ie(e, t, r, n), t.child;
    case 11:
      return r = t.type, l = t.pendingProps, l = t.elementType === r ? l : Le(r, l), _u(e, t, r, l, n);
    case 7:
      return ie(e, t, t.pendingProps, n), t.child;
    case 8:
      return ie(e, t, t.pendingProps.children, n), t.child;
    case 12:
      return ie(e, t, t.pendingProps.children, n), t.child;
    case 10:
      e: {
        if (r = t.type._context, l = t.pendingProps, o = t.memoizedProps, i = l.value, j(Hr, r._currentValue), r._currentValue = i, o !== null) if (Oe(o.value, i)) {
          if (o.children === l.children && !de.current) {
            t = Xe(e, t, n);
            break e;
          }
        } else for (o = t.child, o !== null && (o.return = t); o !== null; ) {
          var u = o.dependencies;
          if (u !== null) {
            i = o.child;
            for (var s = u.firstContext; s !== null; ) {
              if (s.context === r) {
                if (o.tag === 1) {
                  s = He(-1, n & -n), s.tag = 2;
                  var f = o.updateQueue;
                  if (f !== null) {
                    f = f.shared;
                    var v = f.pending;
                    v === null ? s.next = s : (s.next = v.next, v.next = s), f.pending = s;
                  }
                }
                o.lanes |= n, s = o.alternate, s !== null && (s.lanes |= n), ko(
                  o.return,
                  n,
                  t
                ), u.lanes |= n;
                break;
              }
              s = s.next;
            }
          } else if (o.tag === 10) i = o.type === t.type ? null : o.child;
          else if (o.tag === 18) {
            if (i = o.return, i === null) throw Error(y(341));
            i.lanes |= n, u = i.alternate, u !== null && (u.lanes |= n), ko(i, n, t), i = o.sibling;
          } else i = o.child;
          if (i !== null) i.return = o;
          else for (i = o; i !== null; ) {
            if (i === t) {
              i = null;
              break;
            }
            if (o = i.sibling, o !== null) {
              o.return = i.return, i = o;
              break;
            }
            i = i.return;
          }
          o = i;
        }
        ie(e, t, l.children, n), t = t.child;
      }
      return t;
    case 9:
      return l = t.type, r = t.pendingProps.children, Zt(t, n), l = Ne(l), r = r(l), t.flags |= 1, ie(e, t, r, n), t.child;
    case 14:
      return r = t.type, l = Le(r, t.pendingProps), l = Le(r.type, l), Pu(e, t, r, l, n);
    case 15:
      return Pa(e, t, t.type, t.pendingProps, n);
    case 17:
      return r = t.type, l = t.pendingProps, l = t.elementType === r ? l : Le(r, l), Pr(e, t), t.tag = 1, pe(r) ? (e = !0, Ar(t)) : e = !1, Zt(t, n), Ca(t, r, l), xo(t, r, l, n), _o(null, t, r, !0, e, n);
    case 19:
      return Ra(e, t, n);
    case 22:
      return za(e, t, n);
  }
  throw Error(y(156, t.tag));
};
function Xa(e, t) {
  return ks(e, t);
}
function hd(e, t, n, r) {
  this.tag = e, this.key = n, this.sibling = this.child = this.return = this.stateNode = this.type = this.elementType = null, this.index = 0, this.ref = null, this.pendingProps = t, this.dependencies = this.memoizedState = this.updateQueue = this.memoizedProps = null, this.mode = r, this.subtreeFlags = this.flags = 0, this.deletions = null, this.childLanes = this.lanes = 0, this.alternate = null;
}
function xe(e, t, n, r) {
  return new hd(e, t, n, r);
}
function Pi(e) {
  return e = e.prototype, !(!e || !e.isReactComponent);
}
function yd(e) {
  if (typeof e == "function") return Pi(e) ? 1 : 0;
  if (e != null) {
    if (e = e.$$typeof, e === Ko) return 11;
    if (e === Yo) return 14;
  }
  return 2;
}
function ct(e, t) {
  var n = e.alternate;
  return n === null ? (n = xe(e.tag, t, e.key, e.mode), n.elementType = e.elementType, n.type = e.type, n.stateNode = e.stateNode, n.alternate = e, e.alternate = n) : (n.pendingProps = t, n.type = e.type, n.flags = 0, n.subtreeFlags = 0, n.deletions = null), n.flags = e.flags & 14680064, n.childLanes = e.childLanes, n.lanes = e.lanes, n.child = e.child, n.memoizedProps = e.memoizedProps, n.memoizedState = e.memoizedState, n.updateQueue = e.updateQueue, t = e.dependencies, n.dependencies = t === null ? null : { lanes: t.lanes, firstContext: t.firstContext }, n.sibling = e.sibling, n.index = e.index, n.ref = e.ref, n;
}
function Tr(e, t, n, r, l, o) {
  var i = 2;
  if (r = e, typeof e == "function") Pi(e) && (i = 1);
  else if (typeof e == "string") i = 5;
  else e: switch (e) {
    case jt:
      return Ct(n.children, l, o, t);
    case Qo:
      i = 8, l |= 8;
      break;
    case Kl:
      return e = xe(12, n, t, l | 2), e.elementType = Kl, e.lanes = o, e;
    case Yl:
      return e = xe(13, n, t, l), e.elementType = Yl, e.lanes = o, e;
    case Xl:
      return e = xe(19, n, t, l), e.elementType = Xl, e.lanes = o, e;
    case ls:
      return fl(n, l, o, t);
    default:
      if (typeof e == "object" && e !== null) switch (e.$$typeof) {
        case ns:
          i = 10;
          break e;
        case rs:
          i = 9;
          break e;
        case Ko:
          i = 11;
          break e;
        case Yo:
          i = 14;
          break e;
        case Je:
          i = 16, r = null;
          break e;
      }
      throw Error(y(130, e == null ? e : typeof e, ""));
  }
  return t = xe(i, n, t, l), t.elementType = e, t.type = r, t.lanes = o, t;
}
function Ct(e, t, n, r) {
  return e = xe(7, e, r, t), e.lanes = n, e;
}
function fl(e, t, n, r) {
  return e = xe(22, e, r, t), e.elementType = ls, e.lanes = n, e.stateNode = { isHidden: !1 }, e;
}
function Wl(e, t, n) {
  return e = xe(6, e, null, t), e.lanes = n, e;
}
function Hl(e, t, n) {
  return t = xe(4, e.children !== null ? e.children : [], e.key, t), t.lanes = n, t.stateNode = { containerInfo: e.containerInfo, pendingChildren: null, implementation: e.implementation }, t;
}
function gd(e, t, n, r, l) {
  this.tag = t, this.containerInfo = e, this.finishedWork = this.pingCache = this.current = this.pendingChildren = null, this.timeoutHandle = -1, this.callbackNode = this.pendingContext = this.context = null, this.callbackPriority = 0, this.eventTimes = Cl(0), this.expirationTimes = Cl(-1), this.entangledLanes = this.finishedLanes = this.mutableReadLanes = this.expiredLanes = this.pingedLanes = this.suspendedLanes = this.pendingLanes = 0, this.entanglements = Cl(0), this.identifierPrefix = r, this.onRecoverableError = l, this.mutableSourceEagerHydrationData = null;
}
function zi(e, t, n, r, l, o, i, u, s) {
  return e = new gd(e, t, n, u, s), t === 1 ? (t = 1, o === !0 && (t |= 8)) : t = 0, o = xe(3, null, null, t), e.current = o, o.stateNode = e, o.memoizedState = { element: r, isDehydrated: n, cache: null, transitions: null, pendingSuspenseBoundaries: null }, fi(o), e;
}
function wd(e, t, n) {
  var r = 3 < arguments.length && arguments[3] !== void 0 ? arguments[3] : null;
  return { $$typeof: Ot, key: r == null ? null : "" + r, children: e, containerInfo: t, implementation: n };
}
function Ga(e) {
  if (!e) return dt;
  e = e._reactInternals;
  e: {
    if (Mt(e) !== e || e.tag !== 1) throw Error(y(170));
    var t = e;
    do {
      switch (t.tag) {
        case 3:
          t = t.stateNode.context;
          break e;
        case 1:
          if (pe(t.type)) {
            t = t.stateNode.__reactInternalMemoizedMergedChildContext;
            break e;
          }
      }
      t = t.return;
    } while (t !== null);
    throw Error(y(171));
  }
  if (e.tag === 1) {
    var n = e.type;
    if (pe(n)) return Gs(e, n, t);
  }
  return t;
}
function Za(e, t, n, r, l, o, i, u, s) {
  return e = zi(n, r, !0, e, l, o, i, u, s), e.context = Ga(null), n = e.current, r = ue(), l = at(n), o = He(r, l), o.callback = t ?? null, ut(n, o, l), e.current.lanes = l, Zn(e, l, r), me(e, r), e;
}
function dl(e, t, n, r) {
  var l = t.current, o = ue(), i = at(l);
  return n = Ga(n), t.context === null ? t.context = n : t.pendingContext = n, t = He(o, i), t.payload = { element: e }, r = r === void 0 ? null : r, r !== null && (t.callback = r), e = ut(l, t, i), e !== null && (De(e, l, i, o), Cr(e, l, i)), i;
}
function el(e) {
  if (e = e.current, !e.child) return null;
  switch (e.child.tag) {
    case 5:
      return e.child.stateNode;
    default:
      return e.child.stateNode;
  }
}
function $u(e, t) {
  if (e = e.memoizedState, e !== null && e.dehydrated !== null) {
    var n = e.retryLane;
    e.retryLane = n !== 0 && n < t ? n : t;
  }
}
function Li(e, t) {
  $u(e, t), (e = e.alternate) && $u(e, t);
}
function Sd() {
  return null;
}
var Ja = typeof reportError == "function" ? reportError : function(e) {
  console.error(e);
};
function Ti(e) {
  this._internalRoot = e;
}
pl.prototype.render = Ti.prototype.render = function(e) {
  var t = this._internalRoot;
  if (t === null) throw Error(y(409));
  dl(e, t, null, null);
};
pl.prototype.unmount = Ti.prototype.unmount = function() {
  var e = this._internalRoot;
  if (e !== null) {
    this._internalRoot = null;
    var t = e.containerInfo;
    Lt(function() {
      dl(null, e, null, null);
    }), t[Ke] = null;
  }
};
function pl(e) {
  this._internalRoot = e;
}
pl.prototype.unstable_scheduleHydration = function(e) {
  if (e) {
    var t = zs();
    e = { blockedOn: null, target: e, priority: t };
    for (var n = 0; n < be.length && t !== 0 && t < be[n].priority; n++) ;
    be.splice(n, 0, e), n === 0 && Ts(e);
  }
};
function Mi(e) {
  return !(!e || e.nodeType !== 1 && e.nodeType !== 9 && e.nodeType !== 11);
}
function ml(e) {
  return !(!e || e.nodeType !== 1 && e.nodeType !== 9 && e.nodeType !== 11 && (e.nodeType !== 8 || e.nodeValue !== " react-mount-point-unstable "));
}
function Vu() {
}
function kd(e, t, n, r, l) {
  if (l) {
    if (typeof r == "function") {
      var o = r;
      r = function() {
        var f = el(i);
        o.call(f);
      };
    }
    var i = Za(t, r, e, 0, null, !1, !1, "", Vu);
    return e._reactRootContainer = i, e[Ke] = i.current, Vn(e.nodeType === 8 ? e.parentNode : e), Lt(), i;
  }
  for (; l = e.lastChild; ) e.removeChild(l);
  if (typeof r == "function") {
    var u = r;
    r = function() {
      var f = el(s);
      u.call(f);
    };
  }
  var s = zi(e, 0, !1, null, null, !1, !1, "", Vu);
  return e._reactRootContainer = s, e[Ke] = s.current, Vn(e.nodeType === 8 ? e.parentNode : e), Lt(function() {
    dl(t, s, n, r);
  }), s;
}
function vl(e, t, n, r, l) {
  var o = n._reactRootContainer;
  if (o) {
    var i = o;
    if (typeof l == "function") {
      var u = l;
      l = function() {
        var s = el(i);
        u.call(s);
      };
    }
    dl(t, i, e, l);
  } else i = kd(n, t, e, l, r);
  return el(i);
}
_s = function(e) {
  switch (e.tag) {
    case 3:
      var t = e.stateNode;
      if (t.current.memoizedState.isDehydrated) {
        var n = kn(t.pendingLanes);
        n !== 0 && (Zo(t, n | 1), me(t, Q()), !(R & 6) && (ln = Q() + 500, vt()));
      }
      break;
    case 13:
      Lt(function() {
        var r = Ye(e, 1);
        if (r !== null) {
          var l = ue();
          De(r, e, 1, l);
        }
      }), Li(e, 1);
  }
};
Jo = function(e) {
  if (e.tag === 13) {
    var t = Ye(e, 134217728);
    if (t !== null) {
      var n = ue();
      De(t, e, 134217728, n);
    }
    Li(e, 134217728);
  }
};
Ps = function(e) {
  if (e.tag === 13) {
    var t = at(e), n = Ye(e, t);
    if (n !== null) {
      var r = ue();
      De(n, e, t, r);
    }
    Li(e, t);
  }
};
zs = function() {
  return O;
};
Ls = function(e, t) {
  var n = O;
  try {
    return O = e, t();
  } finally {
    O = n;
  }
};
lo = function(e, t, n) {
  switch (t) {
    case "input":
      if (Jl(e, n), t = n.name, n.type === "radio" && t != null) {
        for (n = e; n.parentNode; ) n = n.parentNode;
        for (n = n.querySelectorAll("input[name=" + JSON.stringify("" + t) + '][type="radio"]'), t = 0; t < n.length; t++) {
          var r = n[t];
          if (r !== e && r.form === e.form) {
            var l = ol(r);
            if (!l) throw Error(y(90));
            is(r), Jl(r, l);
          }
        }
      }
      break;
    case "textarea":
      ss(e, n);
      break;
    case "select":
      t = n.value, t != null && Kt(e, !!n.multiple, t, !1);
  }
};
vs = Ci;
hs = Lt;
var Ed = { usingClientEntryPoint: !1, Events: [qn, $t, ol, ps, ms, Ci] }, gn = { findFiberByHostInstance: St, bundleType: 0, version: "18.3.1", rendererPackageName: "react-dom" }, xd = { bundleType: gn.bundleType, version: gn.version, rendererPackageName: gn.rendererPackageName, rendererConfig: gn.rendererConfig, overrideHookState: null, overrideHookStateDeletePath: null, overrideHookStateRenamePath: null, overrideProps: null, overridePropsDeletePath: null, overridePropsRenamePath: null, setErrorHandler: null, setSuspenseHandler: null, scheduleUpdate: null, currentDispatcherRef: Ge.ReactCurrentDispatcher, findHostInstanceByFiber: function(e) {
  return e = ws(e), e === null ? null : e.stateNode;
}, findFiberByHostInstance: gn.findFiberByHostInstance || Sd, findHostInstancesForRefresh: null, scheduleRefresh: null, scheduleRoot: null, setRefreshHandler: null, getCurrentFiber: null, reconcilerVersion: "18.3.1-next-f1338f8080-20240426" };
if (typeof __REACT_DEVTOOLS_GLOBAL_HOOK__ < "u") {
  var gr = __REACT_DEVTOOLS_GLOBAL_HOOK__;
  if (!gr.isDisabled && gr.supportsFiber) try {
    tl = gr.inject(xd), Ue = gr;
  } catch {
  }
}
we.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED = Ed;
we.createPortal = function(e, t) {
  var n = 2 < arguments.length && arguments[2] !== void 0 ? arguments[2] : null;
  if (!Mi(t)) throw Error(y(200));
  return wd(e, t, null, n);
};
we.createRoot = function(e, t) {
  if (!Mi(e)) throw Error(y(299));
  var n = !1, r = "", l = Ja;
  return t != null && (t.unstable_strictMode === !0 && (n = !0), t.identifierPrefix !== void 0 && (r = t.identifierPrefix), t.onRecoverableError !== void 0 && (l = t.onRecoverableError)), t = zi(e, 1, !1, null, null, n, !1, r, l), e[Ke] = t.current, Vn(e.nodeType === 8 ? e.parentNode : e), new Ti(t);
};
we.findDOMNode = function(e) {
  if (e == null) return null;
  if (e.nodeType === 1) return e;
  var t = e._reactInternals;
  if (t === void 0)
    throw typeof e.render == "function" ? Error(y(188)) : (e = Object.keys(e).join(","), Error(y(268, e)));
  return e = ws(t), e = e === null ? null : e.stateNode, e;
};
we.flushSync = function(e) {
  return Lt(e);
};
we.hydrate = function(e, t, n) {
  if (!ml(t)) throw Error(y(200));
  return vl(null, e, t, !0, n);
};
we.hydrateRoot = function(e, t, n) {
  if (!Mi(e)) throw Error(y(405));
  var r = n != null && n.hydratedSources || null, l = !1, o = "", i = Ja;
  if (n != null && (n.unstable_strictMode === !0 && (l = !0), n.identifierPrefix !== void 0 && (o = n.identifierPrefix), n.onRecoverableError !== void 0 && (i = n.onRecoverableError)), t = Za(t, null, e, 1, n ?? null, l, !1, o, i), e[Ke] = t.current, Vn(e), r) for (e = 0; e < r.length; e++) n = r[e], l = n._getVersion, l = l(n._source), t.mutableSourceEagerHydrationData == null ? t.mutableSourceEagerHydrationData = [n, l] : t.mutableSourceEagerHydrationData.push(
    n,
    l
  );
  return new pl(t);
};
we.render = function(e, t, n) {
  if (!ml(t)) throw Error(y(200));
  return vl(null, e, t, !1, n);
};
we.unmountComponentAtNode = function(e) {
  if (!ml(e)) throw Error(y(40));
  return e._reactRootContainer ? (Lt(function() {
    vl(null, null, e, !1, function() {
      e._reactRootContainer = null, e[Ke] = null;
    });
  }), !0) : !1;
};
we.unstable_batchedUpdates = Ci;
we.unstable_renderSubtreeIntoContainer = function(e, t, n, r) {
  if (!ml(n)) throw Error(y(200));
  if (e == null || e._reactInternals === void 0) throw Error(y(38));
  return vl(e, t, n, !1, r);
};
we.version = "18.3.1-next-f1338f8080-20240426";
function qa() {
  if (!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__ > "u" || typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE != "function"))
    try {
      __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(qa);
    } catch (e) {
      console.error(e);
    }
}
qa(), qu.exports = we;
var Cd = qu.exports, ba, Au = Cd;
ba = Au.createRoot, Au.hydrateRoot;
let ec = J.createContext(
  /** @type {any} */
  null
);
function Nd() {
  let e = J.useContext(ec);
  if (!e) throw new Error("RenderContext not found");
  return e;
}
function _d() {
  return Nd().model;
}
function Dt(e) {
  let t = _d(), [n, r] = J.useState(t.get(e));
  return J.useEffect(() => {
    let l = () => r(t.get(e));
    return t.on(`change:${e}`, l), () => t.off(`change:${e}`, l);
  }, [t, e]), [
    n,
    (l) => {
      t.set(e, l), t.save_changes();
    }
  ];
}
function Pd(e) {
  return ({ el: t, model: n, experimental: r }) => {
    let l = ba(t);
    return l.render(
      J.createElement(
        J.StrictMode,
        null,
        J.createElement(
          ec.Provider,
          { value: { model: n, experimental: r } },
          J.createElement(e)
        )
      )
    ), () => l.unmount();
  };
}
const tc = ({
  items: e,
  onSelectItem: t,
  selectedItemId: n
}) => /* @__PURE__ */ k.createElement("div", { className: "items-list flex flex-col overflow-auto" }, e.map((r) => /* @__PURE__ */ k.createElement(
  "button",
  {
    key: r.id,
    className: `w-full text-left p-3 hover:bg-gray-50 ${n === r.id ? "bg-blue-100 border-l-4 border-blue-500" : ""}`,
    onClick: () => t(r.id),
    "aria-selected": n === r.id,
    role: "option"
  },
  /* @__PURE__ */ k.createElement("h3", { className: "font-medium" }, r.name)
))), zd = ({
  projects: e,
  onSelectProject: t,
  selectedProjectId: n
}) => /* @__PURE__ */ k.createElement("div", { className: "mt-4" }, /* @__PURE__ */ k.createElement("h3", { className: "text-md font-semibold mb-2" }, "Projects"), /* @__PURE__ */ k.createElement("div", { className: "border rounded", role: "listbox" }, /* @__PURE__ */ k.createElement(
  tc,
  {
    items: e,
    onSelectItem: t,
    selectedItemId: n
  }
))), Ld = ({
  scenarios: e,
  projectId: t,
  onSelectScenario: n,
  selectedScenarioId: r
}) => {
  const l = e.filter(
    (o) => o.projectId === t
  );
  return /* @__PURE__ */ k.createElement("div", { className: "mt-4" }, /* @__PURE__ */ k.createElement("h3", { className: "text-md font-semibold mb-2" }, "Scenarios"), /* @__PURE__ */ k.createElement("div", { className: "border rounded", role: "listbox" }, /* @__PURE__ */ k.createElement(
    tc,
    {
      items: l,
      onSelectItem: n,
      selectedItemId: r
    }
  )));
}, Bu = ({
  name: e,
  description: t,
  title: n,
  onNameChange: r,
  onDescriptionChange: l,
  children: o
}) => /* @__PURE__ */ k.createElement("div", { className: "flex flex-col h-full overflow-hidden" }, /* @__PURE__ */ k.createElement("div", { className: "scrollable-content" }, /* @__PURE__ */ k.createElement("h2", { className: "text-lg font-semibold mb-4" }, n), /* @__PURE__ */ k.createElement("div", { className: "mb-4" }, /* @__PURE__ */ k.createElement("label", { className: "block mb-2" }, "Name"), /* @__PURE__ */ k.createElement(
  "input",
  {
    type: "text",
    value: e,
    onChange: (i) => r(i.target.value),
    className: "w-full border rounded p-2"
  }
)), /* @__PURE__ */ k.createElement("div", { className: "mb-4" }, /* @__PURE__ */ k.createElement("label", { className: "block mb-2" }, "Description"), /* @__PURE__ */ k.createElement(
  "textarea",
  {
    value: t,
    onChange: (i) => l(i.target.value),
    className: "w-full border rounded p-2",
    rows: 4
  }
)), o)), Td = ({
  project: e,
  scenarios: t,
  selectedScenarioId: n,
  onSelectScenario: r,
  onClose: l,
  onSave: o,
  onSaveScenario: i
}) => {
  const [u, s] = J.useState(e.name), [f, v] = J.useState(e.description), [m, p] = J.useState(""), [w, S] = J.useState(""), g = t.find((a) => a.id === n);
  J.useEffect(() => {
    g && (p(g.name), S(g.description || ""));
  }, [g]);
  const D = () => {
    s(e.name), v(e.description), g && (p(g.name), S(g.description || "")), l(!0);
  }, c = () => {
    g ? i == null || i(g.id, m, w) : o(u, f), l(!1);
  };
  return /* @__PURE__ */ k.createElement("div", { className: "h-full flex flex-col" }, /* @__PURE__ */ k.createElement("div", { className: "flex-1 flex gap-6" }, /* @__PURE__ */ k.createElement("div", { className: "flex-1" }, /* @__PURE__ */ k.createElement(
    Bu,
    {
      name: u,
      description: f,
      onNameChange: s,
      onDescriptionChange: v,
      title: "Project Details"
    }
  ), /* @__PURE__ */ k.createElement("div", { className: "mt-6" }, /* @__PURE__ */ k.createElement(
    Ld,
    {
      scenarios: t,
      projectId: e.id,
      onSelectScenario: r,
      selectedScenarioId: n
    }
  ))), /* @__PURE__ */ k.createElement("div", { className: "flex-1" }, g ? /* @__PURE__ */ k.createElement(
    Bu,
    {
      name: m,
      description: w,
      onNameChange: p,
      onDescriptionChange: S,
      title: "Scenario Details"
    }
  ) : /* @__PURE__ */ k.createElement("div", { className: "h-full flex items-center justify-center text-gray-500" }, "Select a scenario to view details"))), /* @__PURE__ */ k.createElement("div", { className: "border-t mt-6 pt-4 flex justify-end gap-2" }, /* @__PURE__ */ k.createElement(
    "button",
    {
      type: "button",
      onClick: D,
      className: "px-4 py-2 border rounded hover:bg-gray-50"
    },
    "Cancel"
  ), /* @__PURE__ */ k.createElement(
    "button",
    {
      type: "button",
      onClick: c,
      disabled: !u || !g,
      className: `px-4 py-2 rounded text-white ${!u || !g ? "bg-blue-300" : "bg-blue-500 hover:bg-blue-600"}`
    },
    "OK"
  )));
}, Md = ({
  isOpen: e,
  onClose: t,
  projects: n,
  scenarios: r,
  onUpdateProject: l,
  onSelectProject: o,
  onSelectScenario: i,
  selectedProjectId: u,
  selectedScenarioId: s
}) => {
  if (!e) return null;
  const f = k.useRef(u), v = k.useRef(s), m = n.find((c) => c.id === u), p = k.useMemo(
    () => r.filter((c) => c.projectId === u),
    [r, u]
  ), w = (c) => {
    c === null ? (o(f.current ?? null), i(v.current), t()) : (o(c), c !== u && i(null));
  }, S = (c) => {
    c && (o(f.current ?? null), i(v.current)), t();
  }, g = (c, a) => {
    u && l(u, c, a);
  }, D = (c) => {
    c.target === c.currentTarget && t();
  };
  return /* @__PURE__ */ k.createElement("div", { className: "modal-overlay", onClick: D }, /* @__PURE__ */ k.createElement("div", { className: "modal-content", style: { width: "80vw", height: "80vh" } }, /* @__PURE__ */ k.createElement("div", { className: "modal-header border-b border-gray-200 p-4" }, /* @__PURE__ */ k.createElement("h1", { className: "text-xl font-semibold" }, "Project Browser"), /* @__PURE__ */ k.createElement("button", { className: "modal-close-button", onClick: t }, /* @__PURE__ */ k.createElement("svg", { className: "w-6 h-6", fill: "none", stroke: "currentColor", viewBox: "0 0 24 24" }, /* @__PURE__ */ k.createElement("path", { strokeLinecap: "round", strokeLinejoin: "round", strokeWidth: 2, d: "M6 18L18 6M6 6l12 12" })))), /* @__PURE__ */ k.createElement("div", { className: "flex h-[calc(100%-4rem)]" }, /* @__PURE__ */ k.createElement("div", { className: "project-list-container w-72 border-r border-gray-200 p-4 overflow-y-auto" }, /* @__PURE__ */ k.createElement(
    zd,
    {
      projects: n,
      onSelectProject: w,
      selectedProjectId: u ?? void 0
    }
  )), /* @__PURE__ */ k.createElement("div", { className: "flex-1 p-4 overflow-y-auto" }, m ? /* @__PURE__ */ k.createElement(
    Td,
    {
      project: m,
      scenarios: p,
      selectedScenarioId: s,
      onSelectScenario: i,
      onClose: S,
      onSave: g
    }
  ) : /* @__PURE__ */ k.createElement("div", { className: "h-full flex items-center justify-center text-gray-500" }, "Select a project to view details")))));
}, Rd = ({
  selectedProjectName: e,
  selectedScenarioName: t,
  projects: n,
  scenarios: r,
  onUpdateProject: l,
  onSelectProject: o,
  onSelectScenario: i,
  changed: u,
  hasSelection: s,
  onSave: f,
  selectedProjectId: v,
  selectedScenarioId: m
}) => {
  const [p, w] = k.useState(!1), [S, g] = k.useState(!1), D = () => {
    w(!1), e ? f() : g(!0);
  };
  return /* @__PURE__ */ k.createElement("div", { className: "inline-block relative" }, /* @__PURE__ */ k.createElement("div", { className: "flex items-center h-9 border rounded-lg bg-white shadow-sm" }, /* @__PURE__ */ k.createElement("div", { className: "flex items-center px-2 h-full border-r" }, /* @__PURE__ */ k.createElement("div", { className: "flex items-center gap-1.5" }, u && /* @__PURE__ */ k.createElement("div", { className: "w-2 h-2 rounded-full bg-blue-500" }), e ? /* @__PURE__ */ k.createElement(k.Fragment, null, /* @__PURE__ */ k.createElement("span", { className: "px-2 py-0.5 bg-blue-100 text-blue-800 rounded-md text-xs font-medium" }, e), t && /* @__PURE__ */ k.createElement(k.Fragment, null, /* @__PURE__ */ k.createElement("span", { className: "text-gray-400 text-sm" }, "/"), /* @__PURE__ */ k.createElement("span", { className: "px-2 py-0.5 bg-green-100 text-green-800 rounded-md text-xs font-medium" }, t))) : /* @__PURE__ */ k.createElement("span", { className: "text-gray-500 italic text-xs" }, "No project selected"))), /* @__PURE__ */ k.createElement(
    "button",
    {
      onClick: () => w(!p),
      className: "h-full px-3 text-gray-600 hover:text-gray-800 hover:bg-gray-50 text-xs font-medium transition-colors"
    },
    /* @__PURE__ */ k.createElement("svg", { className: "w-4 h-4", fill: "none", stroke: "currentColor", viewBox: "0 0 24 24" }, /* @__PURE__ */ k.createElement("path", { strokeLinecap: "round", strokeLinejoin: "round", strokeWidth: 2, d: "M4 6h16M4 12h16M4 18h16" }))
  )), p && /* @__PURE__ */ k.createElement("div", { className: "dropdown-menu" }, /* @__PURE__ */ k.createElement(
    "button",
    {
      onClick: () => {
        g(!0), w(!1);
      },
      className: "dropdown-item"
    },
    "Select"
  ), s && u && /* @__PURE__ */ k.createElement(
    "button",
    {
      onClick: D,
      className: "dropdown-item"
    },
    "Save"
  )), S && /* @__PURE__ */ k.createElement(
    Md,
    {
      isOpen: S,
      onClose: () => g(!1),
      projects: n,
      scenarios: r,
      onUpdateProject: l,
      onSelectProject: o,
      onSelectScenario: i,
      selectedProjectId: v,
      selectedScenarioId: m
    }
  ));
};
function Dd() {
  console.log("ProjectMenuWidget loaded");
  const [e, t] = Dt("projects"), [n, r] = Dt("selected_project_id"), [l, o] = Dt("selected_scenario_id"), [i, u] = Dt("changed"), [s, f] = Dt("scenarios"), [v, m] = Dt("do_save"), [p, w] = J.useState(!1), S = e == null ? void 0 : e.find((h) => h.id === n), g = s == null ? void 0 : s.find((h) => h.id === l), D = (h, E, N) => {
    const _ = e == null ? void 0 : e.map(
      (P) => P.id === h ? { ...P, name: E, description: N } : P
    );
    t(_ || []), w(!1);
  }, c = (h) => {
    r(h);
  }, a = (h) => {
    o(h);
  }, d = () => {
    m(!0), setTimeout(() => m(!1), 100);
  };
  return /* @__PURE__ */ J.createElement("div", { className: "widget" }, /* @__PURE__ */ J.createElement(
    Rd,
    {
      selectedProjectName: S == null ? void 0 : S.name,
      selectedScenarioName: g == null ? void 0 : g.name,
      projects: e || [],
      scenarios: s || [],
      onUpdateProject: D,
      onSelectProject: c,
      onSelectScenario: a,
      onSave: d,
      changed: i || !1,
      hasSelection: !!(n && l),
      selectedProjectId: n,
      selectedScenarioId: l
    }
  ));
}
const Od = {
  render: Pd(Dd)
};
export {
  Od as default
};
